@@ -11,7 +11,7 @@ from lib389._mapped_object import DSLdapObject
 from lib389.utils import *
 from lib389.topologies import topology_st as topo
 
-from lib389._constants import DN_CONFIG_LDBM, DN_USERROOT_LDBM, DEFAULT_SUFFIX
+from lib389._constants import DN_CONFIG_LDBM, DN_CONFIG_LDBM_BDB, DN_USERROOT_LDBM, DEFAULT_SUFFIX
 
 pytestmark = pytest.mark.tier0
 
@@ -48,6 +48,7 @@ def test_threads_invalid_value(topo, invalid_value):
     """Check nsslapd-threadnumber for an invalid values
 
     :id: 1979eddf-8222-4c9d-809d-269c26de636e
+    :parametrized: yes
     :setup: Standalone instance
     :steps:
         1. Set nsslapd-threadnumber to -2, 0, invalid_str
@@ -99,6 +100,7 @@ def test_cache_autosize_non_zero(topo, autosize, autosize_split):
     """Check that autosizing works works properly in different combinations
 
     :id: 83fa099c-a6c9-457a-82db-0982b67e8598
+    :parametrized: yes
     :setup: Standalone instance
     :steps:
         1. Set in the cn=config,cn=ldbm database,cn=plugins,cn=config:
@@ -119,15 +121,22 @@ def test_cache_autosize_non_zero(topo, autosize, autosize_split):
     """
 
     config_ldbm = DSLdapObject(topo.standalone, DN_CONFIG_LDBM)
+    bdb_config_ldbm = DSLdapObject(topo.standalone, DN_CONFIG_LDBM_BDB)
     userroot_ldbm = DSLdapObject(topo.standalone, DN_USERROOT_LDBM)
 
     cachesize = '33333333'
 
-    dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+    if ds_is_older('1.4.2'):
+        dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+        autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
+        autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+    else:
+        dbcachesize_val = bdb_config_ldbm.get_attr_val('nsslapd-dbcachesize')
+        autosize_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize')
+        autosize_split_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+
     cachenensize_val = userroot_ldbm.get_attr_val('nsslapd-cachememsize')
     dncachenensize_val = userroot_ldbm.get_attr_val('nsslapd-dncachememsize')
-    autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
-    autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
 
     log.info("Check nsslapd-dbcachesize and nsslapd-cachememsize before the test")
     log.info("nsslapd-dbcachesize == {}".format(dbcachesize_val))
@@ -164,11 +173,17 @@ def test_cache_autosize_non_zero(topo, autosize, autosize_split):
         config_ldbm.set('nsslapd-dbcachesize ', cachesize)
     topo.standalone.restart()
 
-    dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+    if ds_is_older('1.4.2'):
+        dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+        autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
+        autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+    else:
+        dbcachesize_val = bdb_config_ldbm.get_attr_val('nsslapd-dbcachesize')
+        autosize_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize')
+        autosize_split_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+
     cachenensize_val = userroot_ldbm.get_attr_val('nsslapd-cachememsize')
     dncachenensize_val = userroot_ldbm.get_attr_val('nsslapd-dncachememsize')
-    autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
-    autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
 
     log.info("Check nsslapd-dbcachesize and nsslapd-cachememsize in the appropriate range.")
     log.info("nsslapd-dbcachesize == {}".format(dbcachesize_val))
@@ -186,6 +201,7 @@ def test_cache_autosize_basic_sane(topo, autosize_split):
     """Check that autotuning cachesizes works properly with different values
 
     :id: 9dc363ef-f551-446d-8b83-8ac45dabb8df
+    :parametrized: yes
     :setup: Standalone instance
     :steps:
         1. Set in the cn=config,cn=ldbm database,cn=plugins,cn=config:
@@ -208,16 +224,23 @@ def test_cache_autosize_basic_sane(topo, autosize_split):
     """
 
     config_ldbm = DSLdapObject(topo.standalone, DN_CONFIG_LDBM)
+    bdb_config_ldbm = DSLdapObject(topo.standalone, DN_CONFIG_LDBM_BDB)
     userroot_ldbm = DSLdapObject(topo.standalone, DN_USERROOT_LDBM)
     config_ldbm.set('nsslapd-cache-autosize', '0')
 
     # Test with caches with both real values and 0
     for cachesize in ('0', '33333333'):
-        dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+        if ds_is_older('1.4.2'):
+            dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+            autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
+            autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+        else:
+            dbcachesize_val = bdb_config_ldbm.get_attr_val('nsslapd-dbcachesize')
+            autosize_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize')
+            autosize_split_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+
         cachenensize_val = userroot_ldbm.get_attr_val('nsslapd-cachememsize')
         dncachenensize_val = userroot_ldbm.get_attr_val('nsslapd-dncachememsize')
-        autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
-        autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
 
         log.info("Check nsslapd-dbcachesize and nsslapd-cachememsize before the test")
         log.info("nsslapd-dbcachesize == {}".format(dbcachesize_val))
@@ -241,11 +264,17 @@ def test_cache_autosize_basic_sane(topo, autosize_split):
         userroot_ldbm.set('nsslapd-cachememsize', cachesize)
         topo.standalone.restart()
 
-        dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+        if ds_is_older('1.4.2'):
+            dbcachesize_val = config_ldbm.get_attr_val('nsslapd-dbcachesize')
+            autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
+            autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+        else:
+            dbcachesize_val = bdb_config_ldbm.get_attr_val('nsslapd-dbcachesize')
+            autosize_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize')
+            autosize_split_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+
         cachenensize_val = userroot_ldbm.get_attr_val('nsslapd-cachememsize')
         dncachenensize_val = userroot_ldbm.get_attr_val('nsslapd-dncachememsize')
-        autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
-        autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
 
         log.info("Check nsslapd-dbcachesize and nsslapd-cachememsize in the appropriate range.")
         log.info("nsslapd-dbcachesize == {}".format(dbcachesize_val))
@@ -263,6 +292,7 @@ def test_cache_autosize_invalid_values(topo, invalid_value):
     """Check that we can't set invalid values to autosize attributes
 
     :id: 2f0d01b5-ca91-4dc2-97bc-ad0ac8d08633
+    :parametrized: yes
     :setup: Standalone instance
     :steps:
         1. Stop the instance
@@ -277,8 +307,13 @@ def test_cache_autosize_invalid_values(topo, invalid_value):
     """
 
     config_ldbm = DSLdapObject(topo.standalone, DN_CONFIG_LDBM)
-    autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
-    autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+    bdb_config_ldbm = DSLdapObject(topo.standalone, DN_CONFIG_LDBM_BDB)
+    if ds_is_older('1.4.2'):
+        autosize_val = config_ldbm.get_attr_val('nsslapd-cache-autosize')
+        autosize_split_val = config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
+    else:
+        autosize_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize')
+        autosize_split_val = bdb_config_ldbm.get_attr_val('nsslapd-cache-autosize-split')
 
     log.info("Set nsslapd-cache-autosize-split to {}".format(invalid_value))
     with pytest.raises(ldap.UNWILLING_TO_PERFORM):
