@@ -15,7 +15,7 @@ from lib389.utils import *
 from lib389._constants import DN_CONFIG, DEFAULT_SUFFIX
 from lib389.idm.user import UserAccounts, TEST_USER_PROPERTIES
 from lib389.backend import *
-from lib389.config import LDBMConfig
+from lib389.config import LDBMConfig, BDB_LDBMConfig
 from lib389.cos import CosPointerDefinitions, CosTemplates
 from lib389.backend import Backends
 from lib389.monitor import MonitorLDBM
@@ -124,7 +124,7 @@ def test_config_listen_backport_size(topology_m2):
 def test_config_deadlock_policy(topology_m2):
     """Check that nsslapd-db-deadlock-policy acted as expected
 
-    :ID: a24e25fd-bc15-47fa-b018-372f6a2ec59c
+    :id: a24e25fd-bc15-47fa-b018-372f6a2ec59c
     :setup: MMR with two masters
     :steps:
         1. Search for nsslapd-db-deadlock-policy and check if
@@ -144,13 +144,24 @@ def test_config_deadlock_policy(topology_m2):
     default_val = b'9'
 
     ldbmconfig = LDBMConfig(topology_m2.ms["master1"])
+    bdbconfig = BDB_LDBMConfig(topology_m2.ms["master1"])
+
+    if ds_is_older('1.4.2'):
+        deadlock_policy = ldbmconfig.get_attr_val_bytes('nsslapd-db-deadlock-policy')
+    else:
+        deadlock_policy = bdbconfig.get_attr_val_bytes('nsslapd-db-deadlock-policy')
 
-    deadlock_policy = ldbmconfig.get_attr_val_bytes('nsslapd-db-deadlock-policy')
     assert deadlock_policy == default_val
 
     # Try a range of valid values
-    for val in ('0', '5', '9'):
+    for val in (b'0', b'5', b'9'):
         ldbmconfig.replace('nsslapd-db-deadlock-policy', val)
+        if ds_is_older('1.4.2'):
+            deadlock_policy = ldbmconfig.get_attr_val_bytes('nsslapd-db-deadlock-policy')
+        else:
+            deadlock_policy = bdbconfig.get_attr_val_bytes('nsslapd-db-deadlock-policy')
+
+        assert deadlock_policy == val
 
     # Try a range of invalid values
     for val in ('-1', '10'):
@@ -166,7 +177,7 @@ def test_config_deadlock_policy(topology_m2):
 def test_defaultnamingcontext(topo):
     """Tests configuration attribute defaultNamingContext in the rootdse
 
-    :id: ad57de32-1d118-4323-bbca-5556e5cdb786
+    :id: de9a21d3-00f9-4c6d-bb40-56aa1ba36578
     :setup: Standalone instance
     :steps:
         1. Check the attribute nsslapd-defaultnamingcontext is present in cn=config
@@ -271,7 +282,7 @@ def test_defaultnamingcontext_1(topo):
 def test_allow_add_delete_config_attributes(topo):
     """Tests configuration attributes are allowed to add and delete
 
-    :id: ad57de32-1d167-4323-bbca-5086e5cdb235
+    :id: d9a3f264-4111-406b-9900-a70e5403458a
     :setup: Standalone instance
     :steps:
         1. Add a new valid attribute at runtime to cn=config
