@@ -9,14 +9,17 @@
 import os
 import logging
 import pytest
+import subprocess
+from lib389._mapped_object import DSLdapObject
 from lib389.topologies import topology_st
 from lib389.plugins import AutoMembershipPlugin, ReferentialIntegrityPlugin, AutoMembershipDefinitions
 from lib389.idm.user import UserAccounts
 from lib389.idm.group import Groups
 from lib389.idm.organizationalunit import OrganizationalUnits
-from lib389._constants import DEFAULT_SUFFIX, LOG_ACCESS_LEVEL
+from lib389._constants import DEFAULT_SUFFIX, LOG_ACCESS_LEVEL, DN_CONFIG, HOST_STANDALONE, PORT_STANDALONE, DN_DM, PASSWORD
 from lib389.utils import ds_is_older
 import ldap
+import glob
 
 pytestmark = pytest.mark.tier1
 
@@ -143,6 +146,42 @@ def add_user_log_level_131076(topology_st, enable_plugins, request):
     add_user_log_level(topology_st, access_log_level, request)
 
 
+@pytest.fixture(scope="function")
+def clean_access_logs(topology_st, request):
+    def _clean_access_logs():
+        topo = topology_st.standalone
+        log.info("Stopping the instance")
+        topo.stop()
+        log.info("Deleting the access logs")
+        topo.deleteAccessLogs()
+        log.info("Starting the instance")
+        topo.start()
+
+    request.addfinalizer(_clean_access_logs)
+
+    return clean_access_logs
+
+
+def set_audit_log_config_values(topology_st, request, enabled, logsize):
+    topo = topology_st.standalone
+
+    topo.config.set('nsslapd-auditlog-logging-enabled', enabled)
+    topo.config.set('nsslapd-auditlog-maxlogsize', logsize)
+
+    def fin():
+        topo.start()
+        log.info('Setting audit log config back to default values')
+        topo.config.set('nsslapd-auditlog-logging-enabled', 'off')
+        topo.config.set('nsslapd-auditlog-maxlogsize', '100')
+
+    request.addfinalizer(fin)
+
+
+@pytest.fixture(scope="function")
+def set_audit_log_config_values_to_rotate(topology_st, request):
+    set_audit_log_config_values(topology_st, request, 'on', '1')
+
+
 @pytest.mark.bz1273549
 def test_check_default(topology_st):
     """Check the default value of nsslapd-logging-hr-timestamps-enabled,
@@ -275,9 +314,10 @@ def test_log_plugin_off(topology_st):
     assert not topology_st.standalone.ds_access_log.match(r'^\[.+\d{9}.+\].+')
 
 
+@pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_server_level_0(topology_st):
+def test_internal_log_server_level_0(topology_st, clean_access_logs):
     """Tests server-initiated internal operations
     :id: 798d06fe-92e8-4648-af66-21349c20638e
     :setup: Standalone instance
@@ -294,8 +334,6 @@ def test_internal_log_server_level_0(topology_st):
     topo = topology_st.standalone
     default_log_level = topo.config.get_attr_val_utf8(LOG_ACCESS_LEVEL)
 
-    log.info('Delete the previous access logs')
-    topo.deleteAccessLogs()
 
     log.info('Set nsslapd-plugin-logging to on')
     topo.config.set(PLUGIN_LOGGING, 'ON')
@@ -319,13 +357,12 @@ def test_internal_log_server_level_0(topology_st):
     assert not topo.ds_access_log.match(r'.*conn=Internal\([0-9]+\) op=[0-9]+\([0-9]+\)\([0-9]+\).*')
 
     topo.config.set(LOG_ACCESS_LEVEL, default_log_level)
-    log.info('Delete the previous access logs for the next test')
-    topo.deleteAccessLogs()
 
 
+@pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
-def test_internal_log_server_level_4(topology_st):
+def test_internal_log_server_level_4(topology_st, clean_access_logs):
     """Tests server-initiated internal operations
     :id: a3500e47-d941-4575-b399-e3f4b49bc4b6
     :setup: Standalone instance
@@ -346,9 +383,6 @@ def test_internal_log_server_level_4(topology_st):
     topo = topology_st.standalone
     default_log_level = topo.config.get_attr_val_utf8(LOG_ACCESS_LEVEL)
 
-    log.info('Delete the previous access logs for the next test')
-    topo.deleteAccessLogs()
-
     log.info('Set nsslapd-plugin-logging to on')
     topo.config.set(PLUGIN_LOGGING, 'ON')
 
@@ -359,22 +393,22 @@ def test_internal_log_server_level_4(topology_st):
     log.info('Restart the server to flush the logs')
     topo.restart()
 
-    # These comments contain lines we are trying to find without regex (the op numbers are just examples)
-    log.info("Check if access log contains internal MOD operation in correct format")
-    # (Internal) op=2(2)(1) SRCH base="cn=config
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="cn=config.*')
-    # (Internal) op=2(2)(1) RESULT err=0 tag=48 nentries=1
-    assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
+    try:
+        # These comments contain lines we are trying to find without regex (the op numbers are just examples)
+        log.info("Check if access log contains internal MOD operation in correct format")
+        # (Internal) op=2(2)(1) SRCH base="cn=config
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) SRCH base="cn=config.*')
+        # (Internal) op=2(2)(1) RESULT err=0 tag=48 nentries=1
+        assert topo.ds_access_log.match(r'.*\(Internal\) op=[0-9]+\([0-9]+\)\([0-9]+\) RESULT err=0 tag=48 nentries=1.*')
 
-    log.info("Check if the other internal operations have the correct format")
-    # conn=Internal(0) op=0
-    assert topo.ds_access_log.match(r'.*conn=Internal\([0-9]+\) op=[0-9]+\([0-9]+\)\([0-9]+\).*')
-
-    topo.config.set(LOG_ACCESS_LEVEL, default_log_level)
-    log.info('Delete the previous access logs for the next test')
-    topo.deleteAccessLogs()
+        log.info("Check if the other internal operations have the correct format")
+        # conn=Internal(0) op=0
+        assert topo.ds_access_log.match(r'.*conn=Internal\([0-9]+\) op=[0-9]+\([0-9]+\)\([0-9]+\).*')
+    finally:
+        topo.config.set(LOG_ACCESS_LEVEL, default_log_level)
 
 
+@pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
 def test_internal_log_level_260(topology_st, add_user_log_level_260):
@@ -455,6 +489,7 @@ def test_internal_log_level_260(topology_st, add_user_log_level_260):
     assert topo.ds_access_log.match(r'.*conn=Internal\([0-9]+\) op=[0-9]+\([0-9]+\)\([0-9]+\).*')
 
 
+@pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
 def test_internal_log_level_131076(topology_st, add_user_log_level_131076):
@@ -536,6 +571,7 @@ def test_internal_log_level_131076(topology_st, add_user_log_level_131076):
     assert topo.ds_access_log.match(r'.*conn=Internal\([0-9]+\) op=[0-9]+\([0-9]+\)\([0-9]+\).*')
 
 
+@pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 @pytest.mark.bz1358706
 @pytest.mark.ds49029
 def test_internal_log_level_516(topology_st, add_user_log_level_516):
@@ -626,10 +662,10 @@ def test_internal_log_level_516(topology_st, add_user_log_level_516):
     assert topo.ds_access_log.match(r'.*conn=Internal\([0-9]+\) op=[0-9]+\([0-9]+\)\([0-9]+\).*')
 
 
-@pytest.mark.skipif(ds_is_older('1.4.1.4'), reason="Not implemented")
+@pytest.mark.skipif(ds_is_older('1.4.2.0'), reason="Not implemented")
 @pytest.mark.bz1358706
 @pytest.mark.ds49232
-def test_access_log_truncated_search_message(topology_st):
+def test_access_log_truncated_search_message(topology_st, clean_access_logs):
     """Tests that the access log message is properly truncated when the message is too long
 
     :id: 0a9af37d-3311-4a2f-ac0a-9a1c631aaf27
@@ -661,8 +697,157 @@ def test_access_log_truncated_search_message(topology_st):
     assert not topo.ds_access_log.match(r'.*cn=ending.*')
     assert not topo.ds_access_log.match(r'.*cn500.*')
 
-    log.info('Delete the previous access logs for the next test')
-    topo.deleteAccessLogs()
+
+
+@pytest.mark.xfail(ds_is_older('1.4.2.0'), reason="May fail because of bug 1732053")
+@pytest.mark.bz1732053
+@pytest.mark.ds50510
+def test_etime_at_border_of_second(topology_st, clean_access_logs):
+    topo = topology_st.standalone
+
+
+    prog = os.path.join(topo.ds_paths.bin_dir, 'rsearch')
+
+    cmd = [prog]
+
+    # base search
+    cmd.extend(['-s', DN_CONFIG])
+
+    # scope of the search
+    cmd.extend(['-S', '0'])
+
+    # host / port
+    cmd.extend(['-h', HOST_STANDALONE])
+    cmd.extend(['-p', str(PORT_STANDALONE)])
+
+    # bound as DM to make it faster
+    cmd.extend(['-D', DN_DM])
+    cmd.extend(['-w', PASSWORD])
+
+    # filter
+    cmd.extend(['-f', "(cn=config)"])
+
+    # 2 samples SRCH
+    cmd.extend(['-C', "2"])
+
+    output = subprocess.check_output(cmd)
+    topo.stop()
+
+    # No etime with 0.199xxx (everything should be few ms)
+    invalid_etime = topo.ds_access_log.match(r'.*etime=0\.19.*')
+    if invalid_etime:
+        for i in range(len(invalid_etime)):
+            log.error('It remains invalid or weird etime: %s' % invalid_etime[i])
+    assert not invalid_etime
+
+
+@pytest.mark.xfail(ds_is_older('1.3.10.1'), reason="May fail because of bug 1662461")
+@pytest.mark.bz1662461
+@pytest.mark.ds50428
+@pytest.mark.ds49969
+def test_log_base_dn_when_invalid_attr_request(topology_st):
+    """Test that DS correctly logs the base dn when a search with invalid attribute request is performed
+
+    :id: 859de962-c261-4ffb-8705-97bceab1ba2c
+    :setup: Standalone instance
+    :steps:
+         1. Disable the accesslog-logbuffering config parameter
+         2. Delete the previous access log
+         3. Perform a base search on the DEFAULT_SUFFIX, using invalid "" "" attribute request
+         4. Check the access log file for 'invalid attribute request'
+         5. Check the access log file for 'SRCH base="\(null\)"'
+         6. Check the access log file for 'SRCH base="DEFAULT_SUFFIX"'
+    :expectedresults:
+         1. Operations are visible in the access log in real time
+         2. Fresh new access log is created
+         3. The search operation raises a Protocol error
+         4. The access log should have an 'invalid attribute request' message
+         5. The access log should not have "\(null\)" as value for the Search base dn
+         6. The access log should have the value of DEFAULT_SUFFIX as Search base dn
+    """
+
+    entry = DSLdapObject(topology_st.standalone, DEFAULT_SUFFIX)
+
+    log.info('Set accesslog logbuffering to off to get the log in real time')
+    topology_st.standalone.config.set('nsslapd-accesslog-logbuffering', 'off')
+
+    log.info('delete the previous access logs to get a fresh new one')
+    topology_st.standalone.deleteAccessLogs()
+
+    log.info("Search the default suffix, with invalid '\"\" \"\"' attribute request")
+    log.info("A Protocol error exception should be raised, see https://pagure.io/389-ds-base/issue/49969")
+    # A ldap.PROTOCOL_ERROR exception is expected
+    with pytest.raises(ldap.PROTOCOL_ERROR):
+        assert entry.get_attrs_vals_utf8(['', ''])
+
+    # Search for appropriate messages in the access log
+    log.info('Check the access logs for correct messages')
+    # We should find the 'invalid attribute request' information
+    assert topology_st.standalone.ds_access_log.match(r'.*invalid attribute request.*')
+    # We should not find a "(null)" base dn mention
+    assert not topology_st.standalone.ds_access_log.match(r'.*SRCH base="\(null\)".*')
+    # We should find the base dn for the search
+    assert topology_st.standalone.ds_access_log.match(r'.*SRCH base="{}".*'.format(DEFAULT_SUFFIX))
+
+
+@pytest.mark.xfail(ds_is_older('1.3.8', '1.4.2'), reason="May fail because of bug 1676948")
+@pytest.mark.bz1676948
+@pytest.mark.ds50536
+def test_audit_log_rotate_and_check_string(topology_st, clean_access_logs, set_audit_log_config_values_to_rotate):
+    """Version string should be logged only once at the top of audit log
+    after it is rotated.
+
+    :id: 14dffb22-2f9c-11e9-8a03-54e1ad30572c
+
+    :setup: Standalone instance
+
+    :steps:
+         1. Set nsslapd-auditlog-logging-enabled: on
+         2. Set nsslapd-auditlog-maxlogsize: 1
+         3. Do modifications to the entry, until audit log file is rotated
+         4. Check audit logs
+
+    :expectedresults:
+         1. Attribute nsslapd-auditlog-logging-enabled should be set to on
+         2. Attribute nsslapd-auditlog-maxlogsize should be set to 1
+         3. Audit file should grow till 1MB and then should be rotated
+         4. Audit file log should contain version string only once at the top
+    """
+
+    standalone = topology_st.standalone
+    search_ds = '389-Directory'
+
+    users = UserAccounts(standalone, DEFAULT_SUFFIX)
+    user = users.create(properties={
+            'uid': 'test_audit_log',
+            'cn': 'test',
+            'sn': 'user',
+            'uidNumber': '1000',
+            'gidNumber': '1000',
+            'homeDirectory': '/home/test',
+        })
+
+    log.info('Doing modifications to rotate audit log')
+    audit_log = standalone.ds_paths.audit_log
+    while len(glob.glob(audit_log + '*')) == 2:
+        user.replace('description', 'test'*100)
+
+    log.info('Doing one more modification just in case')
+    user.replace('description', 'test2'*100)
+
+    standalone.stop()
+
+    count = 0
+    with open(audit_log) as f:
+        log.info('Check that DS string is present on first line')
+        assert search_ds in f.readline()
+        f.seek(0)
+
+        log.info('Check that DS string is present only once')
+        for line in f.readlines():
+            if search_ds in line:
+                count += 1
+        assert count == 1
 
 
 if __name__ == '__main__':
