@@ -15,9 +15,11 @@ from lib389.agreement import Agreements
 from lib389.idm.user import (TEST_USER_PROPERTIES, UserAccounts)
 
 from lib389.dbgen import dbgen
+from lib389.utils import ds_is_older
 
 pytestmark = pytest.mark.tier1
 
+@pytest.mark.skipif(ds_is_older("1.4.0.0"), reason="Not implemented")
 def test_referral_during_tot(topology_m2):
 
     master1 = topology_m2.ms["master1"]
