@@ -17,7 +17,6 @@ from lib389.utils import *
 from lib389.tasks import *
 from lib389.tools import DirSrvTools
 from lib389.topologies import topology_st
-from lib389._constants import DEFAULT_SUFFIX, DN_DM, PASSWORD
 from lib389.idm.directorymanager import DirectoryManager
 from lib389.plugins import RootDNAccessControlPlugin
 
@@ -127,8 +126,13 @@ def test_rootdn_access_specific_time(topology_st, rootdn_setup, rootdn_cleanup,
         raise Exception ("rootdn-open-time and rootdn-close-time were not updated")
 
     # Bind as Root DN - should fail
-    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
-        dm.bind()
+    for i in range(0, timeout):
+        try:
+            dm.bind()
+        except ldap.UNWILLING_TO_PERFORM:
+            break
+        else:
+            time.sleep(.5)
 
 
     # Set config to allow the entire day
@@ -149,7 +153,12 @@ def test_rootdn_access_specific_time(topology_st, rootdn_setup, rootdn_cleanup,
         raise Exception ("rootdn-open-time and rootdn-close-time were not updated")
 
     # Bind as Root DN - should succeed
-    dm.bind()
+    for i in range(0, timeout):
+        try:
+            dm.bind()
+            break
+        except:
+            time.sleep(.5)
 
     # Cleanup - undo the changes we made so the next test has a clean slate
     assert plugin.apply_mods([(ldap.MOD_DELETE, 'rootdn-open-time'),
@@ -209,8 +218,13 @@ def test_rootdn_access_day_of_week(topology_st, rootdn_setup, rootdn_cleanup, ti
         raise Exception ("rootdn-days-allowed was not updated")
 
     # Bind as Root DN - should fail
-    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
-        dm.bind()
+    for i in range(0, timeout):
+        try:
+            dm.bind()
+        except ldap.UNWILLING_TO_PERFORM:
+            break
+        else:
+            time.sleep(.5)
 
     # Set the allow days
     plugin.set_days_allowed(allow_days)
@@ -227,8 +241,12 @@ def test_rootdn_access_day_of_week(topology_st, rootdn_setup, rootdn_cleanup, ti
         raise Exception ("rootdn-days-allowed was not updated")
 
     # Bind as Root DN - should succeed
-    dm.bind()
-
+    for i in range(0, timeout):
+        try:
+            dm.bind()
+            break
+        except:
+            time.sleep(.5)
 
 def test_rootdn_access_denied_ip(topology_st, rootdn_setup, rootdn_cleanup, timeout=5):
     """Test denied IP feature - we can just test denying 127.0.0.1
@@ -264,12 +282,17 @@ def test_rootdn_access_denied_ip(topology_st, rootdn_setup, rootdn_cleanup, time
 
     # Bind as Root DN - should fail
     uri = 'ldap://{}:{}'.format('127.0.0.1', topology_st.standalone.port)
-    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
-        rootdn_bind(topology_st.standalone, uri=uri)
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+        except ldap.UNWILLING_TO_PERFORM:
+            break
+        else:
+            time.sleep(.5)
 
     # Change the denied IP so root DN succeeds
     plugin.apply_mods([(ldap.MOD_REPLACE, 'rootdn-deny-ip', '255.255.255.255')])
-     
+
     attr_updated = 0
     for i in range(0, timeout):
         if ('255.255.255.255' in str(plugin.get_deny_ip())):
@@ -282,7 +305,12 @@ def test_rootdn_access_denied_ip(topology_st, rootdn_setup, rootdn_cleanup, time
         raise Exception ("rootdn-deny-ip was not updated")
 
     # Bind as Root DN - should succeed
-    rootdn_bind(topology_st.standalone, uri=uri)
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+            break
+        except:
+            time.sleep(.5)
 
 
 def test_rootdn_access_denied_host(topology_st, rootdn_setup, rootdn_cleanup, timeout=5):
@@ -321,8 +349,13 @@ def test_rootdn_access_denied_host(topology_st, rootdn_setup, rootdn_cleanup, ti
 
     # Bind as Root DN - should fail
     uri = 'ldap://{}:{}'.format(localhost, topology_st.standalone.port)
-    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
-        rootdn_bind(topology_st.standalone, uri=uri)
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+        except ldap.UNWILLING_TO_PERFORM:
+            break
+        else:
+            time.sleep(.5)
 
     # Change the denied host so root DN bind succeeds
     rand_host = 'i.dont.exist.{}'.format(uuid.uuid4())
@@ -340,8 +373,12 @@ def test_rootdn_access_denied_host(topology_st, rootdn_setup, rootdn_cleanup, ti
         raise Exception ("rootdn-deny-host was not updated")
 
     # Bind as Root DN - should succeed
-    rootdn_bind(topology_st.standalone, uri=uri)
-
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+            break
+        except:
+            time.sleep(.5)
 
 def test_rootdn_access_allowed_ip(topology_st, rootdn_setup, rootdn_cleanup, timeout=5):
     """Test allowed ip feature
@@ -378,8 +415,13 @@ def test_rootdn_access_allowed_ip(topology_st, rootdn_setup, rootdn_cleanup, tim
 
     # Bind as Root DN - should fail
     uri = 'ldap://{}:{}'.format(localhost, topology_st.standalone.port)
-    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
-        rootdn_bind(topology_st.standalone, uri=uri)
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+        except ldap.UNWILLING_TO_PERFORM:
+            break
+        else:
+            time.sleep(.5)
 
     # Allow localhost
     plugin.add_allow_ip('127.0.0.1')
@@ -397,8 +439,12 @@ def test_rootdn_access_allowed_ip(topology_st, rootdn_setup, rootdn_cleanup, tim
         raise Exception ("rootdn-allow-ip was not updated")
 
     # Bind as Root DN - should succeed
-    rootdn_bind(topology_st.standalone, uri=uri)
-
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+            break
+        except:
+            time.sleep(.5)
 
 def test_rootdn_access_allowed_host(topology_st, rootdn_setup, rootdn_cleanup, timeout=5):
     """Test allowed host feature
@@ -436,8 +482,13 @@ def test_rootdn_access_allowed_host(topology_st, rootdn_setup, rootdn_cleanup, t
 
     # Bind as Root DN - should fail
     uri = 'ldap://{}:{}'.format(localhost, topology_st.standalone.port)
-    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
-        rootdn_bind(topology_st.standalone, uri=uri)
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+        except ldap.UNWILLING_TO_PERFORM:
+            break
+        else:
+            time.sleep(.5)
 
     # Allow localhost
     plugin.remove_all_allow_host()
@@ -457,8 +508,12 @@ def test_rootdn_access_allowed_host(topology_st, rootdn_setup, rootdn_cleanup, t
         raise Exception ("rootdn-allow-host was not updated")
 
     # Bind as Root DN - should succeed
-    rootdn_bind(topology_st.standalone, uri=uri)
-
+    for i in range(0, timeout):
+        try:
+            rootdn_bind(topology_st.standalone, uri=uri)
+            break
+        except:
+            time.sleep(.5)
 
 def test_rootdn_config_validate(topology_st, rootdn_setup, rootdn_cleanup):
     """Test plugin configuration validation
@@ -588,6 +643,77 @@ def test_rootdn_config_validate(topology_st, rootdn_setup, rootdn_cleanup):
         plugin.apply_mods([(ldap.MOD_REPLACE, 'rootdn-deny-host', 'host.####.com')])
 
 
+def test_rootdn_access_denied_ip_wildcard(topology_st, rootdn_setup, rootdn_cleanup):
+    """Test denied IP feature with a wildcard
+
+    :id: 73c74f62-9ac2-4bb6-8a63-bacc8d8bbf93
+    :setup: Standalone instance, rootdn plugin set up
+    :steps:
+        1. Set rootdn-deny-ip to '127.*'
+        2. Bind as Root DN
+        3. Change the denied IP so root DN succeeds
+        4. Bind as Root DN
+    :expectedresults:
+        1. Success
+        2. Should fail
+        3. Success
+        4. Success
+    """
+
+    log.info('Running test_rootdn_access_denied_ip_wildcard...')
+
+    plugin.add_deny_ip('127.*')
+    time.sleep(.5)
+
+    # Bind as root DN - should fail
+    uri = 'ldap://{}:{}'.format('127.0.0.1', topology_st.standalone.port)
+    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
+        rootdn_bind(topology_st.standalone, uri=uri)
+
+    # Change the denied IP so root DN succeeds
+    plugin.apply_mods([(ldap.MOD_REPLACE, 'rootdn-deny-ip', '255.255.255.255')])
+    time.sleep(.5)
+
+    # Bind should succeed
+    rootdn_bind(topology_st.standalone, uri=uri)
+
+
+def test_rootdn_access_allowed_ip_wildcard(topology_st, rootdn_setup, rootdn_cleanup):
+    """Test allowed ip feature
+
+    :id: c3e22c61-9ed2-4e89-8243-6ff686ecad9b
+    :setup: Standalone instance, rootdn plugin set up
+    :steps:
+        1. Set allowed ip to 255.255.255.255 - blocks the Root DN
+        2. Bind as Root DN
+        3. Allow 127.*
+        4. Bind as Root DN
+    :expectedresults:
+        1. Success
+        2. Should fail
+        3. Success
+        4. Success
+    """
+
+    log.info('Running test_rootdn_access_allowed_ip...')
+
+    # Set allowed ip to 255.255.255.255 - blocks the Root DN
+    plugin.add_allow_ip('255.255.255.255')
+    time.sleep(.5)
+
+    # Bind as Root DN - should fail
+    uri = 'ldap://{}:{}'.format("127.0.0.1", topology_st.standalone.port)
+    with pytest.raises(ldap.UNWILLING_TO_PERFORM):
+        rootdn_bind(topology_st.standalone, uri=uri)
+
+    # Allow localhost
+    plugin.add_allow_ip('127.*')
+    time.sleep(.5)
+
+    # Bind should succeed
+    rootdn_bind(topology_st.standalone, uri=uri)
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
