@@ -4,11 +4,11 @@
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
- * See LICENSE for details. 
+ * See LICENSE for details.
  * END COPYRIGHT BLOCK **/
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #ifndef BASE_SYSTEMS_H
@@ -20,8 +20,8 @@
 
 /*
  * systems.h: Lists of defines for systems
- * 
- * This sets what general flavor the system is (UNIX, etc.), 
+ *
+ * This sets what general flavor the system is (UNIX, etc.),
  * and defines what extra functions your particular system needs.
  */
 
@@ -58,11 +58,11 @@
 #define JAVA_STATIC_LINK
 #undef NEED_CRYPT_H
 #define NET_SOCKETS
-#define SA_HANDLER_T(x) (void (*)(int))x
+#define SA_HANDLER_T(x) (void (*)(int)) x
 /* warning: mmap doesn't work under 9.04 */
 #define SHMEM_MMAP_FLAGS MAP_FILE | MAP_VARIABLE | MAP_SHARED
 
-#elif defined(Linux)
+#elif defined(LINUX)
 
 #define ACCELERATOR_CACHE
 #define DNS_CACHE
@@ -114,8 +114,8 @@
 #define NEED_GHN_PROTO
 #endif
 #define NET_SOCKETS
-#if OSVERSION > 504 
-#define SA_HANDLER_T(x) x 
+#if OSVERSION > 504
+#define SA_HANDLER_T(x) x
 #endif
 #define SHMEM_MMAP_FLAGS MAP_SHARED
 
@@ -142,6 +142,32 @@
 #define NET_SOCKETS
 #define SHMEM_MMAP_FLAGS MAP_SHARED
 
+#elif defined(__FreeBSD__)
+
+#define ACCELERATOR_CACHE
+#define DNS_CACHE
+#define FILE_INHERIT_FCNTL
+#define DAEMON_UNIX_MOBRULE
+#define BSD_RLIMIT
+#define BSD_SIGNALS
+#define FILE_UNIX_MMAP
+#define FILE_MMAP_FLAGS (MAP_FILE | MAP_SHARED)
+#define SHMEM_UNIX_MMAP
+#define SHMEM_MMAP_FLAGS MAP_SHARED
+#define AUTH_DBM
+#define SEM_FLOCK
+#define DLL_CAPABLE
+#define DLL_DLOPEN
+#define DLL_DLOPEN_FLAGS RTLD_NOW
+#define HAVE_ATEXIT
+#define HAS_STATFS
+#define JAVA_STATIC_LINK
+#undef NEED_CRYPT_PROTO
+#define NET_SOCKETS
+#ifndef NO_DOMAINNAME
+#define NO_DOMAINNAME
+#endif
+
 #else
 #error "Missing defines in ns/netsite/include/base/systems.h"
 #endif
@@ -156,10 +182,11 @@
 
 #ifndef DAEMON_LISTEN_SIZE
 #define DAEMON_LISTEN_SIZE 128
+#define DAEMON_LISTEN_SIZE_STR "128"
 #endif /* !DAEMON_LISTEN_SIZE */
 
 #ifndef SA_HANDLER_T
-#define SA_HANDLER_T(x) (void (*)())x 
+#define SA_HANDLER_T(x) (void (*)()) x
 #endif
 
 #ifdef HAS_CONSTVALUED_STRFUNCS
