@@ -311,8 +311,8 @@ typedef struct aci
 #define ATTR_ACLPB_MAX_SELECTED_ACLS    "nsslapd-aclpb-max-selected-acls"
 #define DEFAULT_ACLPB_MAX_SELECTED_ACLS 200
 
-int aclpb_max_selected_acls; /* initialized from plugin config entry */
-int aclpb_max_cache_results; /* initialized from plugin config entry */
+extern int aclpb_max_selected_acls; /* initialized from plugin config entry */
+extern int aclpb_max_cache_results; /* initialized from plugin config entry */
 
 typedef struct result_cache
 {
@@ -758,9 +758,6 @@ int acl_create_aclpb_pool(void);
 void acl_destroy_aclpb_pool(void);
 int acl_skip_access_check(Slapi_PBlock *pb, Slapi_Entry *e, int access);
 
-int aclext_alloc_lockarray(void);
-void aclext_free_lockarray(void);
-
 int aclutil_str_append(char **str1, const char *str2);
 void aclutil_print_err(int rv, const Slapi_DN *sdn, const struct berval *val, char **errbuf);
 void aclutil_print_aci(aci_t *aci_item, char *type);
