@@ -147,7 +147,7 @@ acl_parse(Slapi_PBlock *pb, char *str, aci_t *aci_item, char **errbuf)
                     slapi_search_internal_pb(temppb);
                     slapi_pblock_get(temppb, SLAPI_PLUGIN_INTOP_RESULT, &rc);
                     if (rc != LDAP_SUCCESS) {
-                        slapi_log_err(SLAPI_LOG_ERR, plugin_name,
+                        slapi_log_err(SLAPI_LOG_WARNING, plugin_name,
                                       "acl_parse - The ACL target %s does not exist\n", slapi_sdn_get_dn(&targdn));
                     }
 
@@ -219,6 +219,7 @@ __aclp__parse_aci(char *str, aci_t *aci_item, char **errbuf)
     char *tmpstr;
     char *s = NULL;
     char *value = NULL;
+    char *single_space = " ";
     Slapi_Filter *f = NULL;
     int targetattrlen = strlen(aci_targetattr);
     int targetdnlen = strlen(aci_targetdn);
@@ -262,7 +263,7 @@ __aclp__parse_aci(char *str, aci_t *aci_item, char **errbuf)
 
             if ((s = strstr(str, "!=")) != NULL) {
                 type |= ACI_TARGET_ATTR_NOT;
-                strncpy(s, " ", 1);
+                strncpy(s, single_space, 1);
             }
             /* Get individual components of the targetattr.
              * (targetattr = "cn || u* || phone ||tel:add:(tel=1234)
@@ -344,7 +345,7 @@ __aclp__parse_aci(char *str, aci_t *aci_item, char **errbuf)
             }
             if ((s = strstr(str, "!=")) != NULL) {
                 type |= ACI_TARGET_NOT;
-                strncpy(s, " ", 1);
+                strncpy(s, single_space, 1);
             }
             if ((s = strchr(str, '=')) != NULL) {
                 value = s + 1;
@@ -397,7 +398,7 @@ __aclp__parse_aci(char *str, aci_t *aci_item, char **errbuf)
             }
             if ((s = strstr(str, "!=")) != NULL) {
                 type |= ACI_TARGET_NOT;
-                strncpy(s, " ", 1);
+                strncpy(s, single_space, 1);
             }
             if ((s = strchr(str, '=')) != NULL) {
                 value = s + 1;
