@@ -88,7 +88,7 @@ pam_passthruauth_init(Slapi_PBlock *pb)
 {
     int status = 0;
     Slapi_Entry *plugin_entry = NULL;
-    char *plugin_type = NULL;
+    const char *plugin_type = NULL;
     int is_betxn = 0;
     int preadd = SLAPI_PLUGIN_PRE_ADD_FN;
     int premod = SLAPI_PLUGIN_PRE_MODIFY_FN;
@@ -105,8 +105,7 @@ pam_passthruauth_init(Slapi_PBlock *pb)
 
     if ((slapi_pblock_get(pb, SLAPI_PLUGIN_CONFIG_ENTRY, &plugin_entry) == 0) &&
         plugin_entry &&
-        (plugin_type = slapi_entry_attr_get_charptr(plugin_entry,
-                                                    "nsslapd-plugintype")) &&
+        (plugin_type = slapi_entry_attr_get_ref(plugin_entry, "nsslapd-plugintype")) &&
         plugin_type && strstr(plugin_type, "betxn")) {
         is_betxn = 1;
         preadd = SLAPI_PLUGIN_BE_TXN_PRE_ADD_FN;
@@ -114,7 +113,6 @@ pam_passthruauth_init(Slapi_PBlock *pb)
         predel = SLAPI_PLUGIN_BE_TXN_PRE_DELETE_FN;
         premdn = SLAPI_PLUGIN_BE_TXN_PRE_MODRDN_FN;
     }
-    slapi_ch_free_string(&plugin_type);
 
     if (is_betxn) {
         if (slapi_pblock_set(pb, SLAPI_PLUGIN_VERSION,
@@ -256,7 +254,7 @@ pam_passthru_postop_init(Slapi_PBlock *pb)
 {
     int status = 0;
     Slapi_Entry *plugin_entry = NULL;
-    char *plugin_type = NULL;
+    const char *plugin_type = NULL;
     int is_betxn = 0;
     int postadd = SLAPI_PLUGIN_POST_ADD_FN;
     int postmod = SLAPI_PLUGIN_POST_MODIFY_FN;
@@ -265,8 +263,7 @@ pam_passthru_postop_init(Slapi_PBlock *pb)
 
     if ((slapi_pblock_get(pb, SLAPI_PLUGIN_CONFIG_ENTRY, &plugin_entry) == 0) &&
         plugin_entry &&
-        (plugin_type = slapi_entry_attr_get_charptr(plugin_entry,
-                                                    "nsslapd-plugintype")) &&
+        (plugin_type = slapi_entry_attr_get_ref(plugin_entry, "nsslapd-plugintype")) &&
         plugin_type && strstr(plugin_type, "betxn")) {
         postadd = SLAPI_PLUGIN_BE_TXN_POST_ADD_FN;
         postmod = SLAPI_PLUGIN_BE_TXN_POST_MODIFY_FN;
@@ -274,7 +271,6 @@ pam_passthru_postop_init(Slapi_PBlock *pb)
         postdel = SLAPI_PLUGIN_BE_TXN_POST_DELETE_FN;
         is_betxn = 1;
     }
-    slapi_ch_free_string(&plugin_type);
 
     if (slapi_pblock_set(pb, SLAPI_PLUGIN_VERSION, SLAPI_PLUGIN_VERSION_01) ||
         slapi_pblock_set(pb, SLAPI_PLUGIN_DESCRIPTION, (void *)&pdesc) ||
@@ -436,8 +432,9 @@ pam_passthru_bindpreop(Slapi_PBlock *pb)
      * We only handle simple bind requests that include non-NULL binddn and
      * credentials.  Let the Directory Server itself handle everything else.
      */
-    if ((method != LDAP_AUTH_SIMPLE) || (*normbinddn == '\0') ||
-        (creds->bv_len == 0)) {
+    if (method != LDAP_AUTH_SIMPLE || normbinddn == NULL ||
+        *normbinddn == '\0' || creds->bv_len == 0)
+    {
         slapi_log_err(SLAPI_LOG_PLUGIN, PAM_PASSTHRU_PLUGIN_SUBSYSTEM,
                       "pam_passthru_bindpreop - Not handled (not simple bind or NULL dn/credentials)\n");
         return retcode;
