@@ -547,6 +547,7 @@ clcache_refresh_consumer_maxcsns(CLC_Buffer *buf)
     int i;
 
     for (i = 0; i < buf->buf_num_cscbs; i++) {
+        csn_free(&buf->buf_cscbs[i]->consumer_maxcsn);
         ruv_get_largest_csn_for_replica(
             buf->buf_consumer_ruv,
             buf->buf_cscbs[i]->rid,
@@ -842,8 +843,8 @@ clcache_skip_change(CLC_Buffer *buf)
          * are not sure if current_csn is the neighbor.
          */
         if (csn_time_difference(buf->buf_current_csn, cscb->local_maxcsn) == 0 &&
-            (csn_get_seqnum(buf->buf_current_csn) ==
-             csn_get_seqnum(cscb->local_maxcsn) + 1)) {
+            (csn_get_seqnum(buf->buf_current_csn) == csn_get_seqnum(cscb->local_maxcsn) + 1))
+        {
             csn_init_by_csn(cscb->local_maxcsn, buf->buf_current_csn);
             if (cscb->consumer_maxcsn) {
                 csn_init_by_csn(cscb->consumer_maxcsn, buf->buf_current_csn);
