@@ -80,6 +80,8 @@
 #define CLEANRUV_FINISHED  "finished"
 #define CLEANRUV_CLEANING  "cleaning"
 #define CLEANRUV_NO_MAXCSN "no maxcsn"
+#define CLEANALLRUV_ID "CleanAllRUV Task"
+#define ABORT_CLEANALLRUV_ID "Abort CleanAllRUV Task"
 
 /* DS 5.0 replication protocol error codes */
 #define NSDS50_REPL_REPLICA_READY             0x00  /* Replica ready, go ahead */
@@ -519,7 +521,7 @@ void consumer_operation_extension_destructor(void *ext, void *object, void *pare
 typedef struct consumer_connection_extension
 {
     int repl_protocol_version; /* the replication protocol version number the supplier is talking. */
-    void *replica_acquired;    /* Object* for replica */
+    Replica *replica_acquired;    /* replica */
     void *supplier_ruv;        /* RUV* */
     int isreplicationsession;
     Slapi_Connection *connection;
@@ -539,6 +541,7 @@ int consumer_connection_extension_relinquish_exclusive_access(void *conn, uint64
 typedef struct multimaster_mtnode_extension
 {
     Object *replica;
+    Objset *removed_replicas;
 } multimaster_mtnode_extension;
 void *multimaster_mtnode_extension_constructor(void *object, void *parent);
 void multimaster_mtnode_extension_destructor(void *ext, void *object, void *parent);
@@ -636,7 +639,7 @@ void prot_notify_update(Repl_Protocol *rp);
 void prot_notify_agmt_changed(Repl_Protocol *rp, char *agmt_name);
 void prot_notify_window_opened(Repl_Protocol *rp);
 void prot_notify_window_closed(Repl_Protocol *rp);
-Object *prot_get_replica_object(Repl_Protocol *rp);
+Replica *prot_get_replica(Repl_Protocol *rp);
 void prot_replicate_now(Repl_Protocol *rp);
 
 Repl_Protocol *agmt_get_protocol(Repl_Agmt *ra);
@@ -694,15 +697,16 @@ void replica_set_flag(Replica *r, uint32_t flag, PRBool clear);
 void replica_replace_flags(Replica *r, uint32_t flags);
 void replica_dump(Replica *r);
 void replica_set_enabled(Replica *r, PRBool enable);
-Object *replica_get_replica_from_dn(const Slapi_DN *dn);
+Replica *replica_get_replica_from_dn(const Slapi_DN *dn);
+Replica *replica_get_replica_from_root(const char *repl_root);
 int replica_update_ruv(Replica *replica, const CSN *csn, const char *replica_purl);
-Object *replica_get_replica_for_op(Slapi_PBlock *pb);
+Replica *replica_get_replica_for_op(Slapi_PBlock *pb);
 /* the functions below manipulate replica hash */
 int replica_init_name_hash(void);
 void replica_destroy_name_hash(void);
-int replica_add_by_name(const char *name, Object *replica);
+int replica_add_by_name(const char *name, Replica *replica);
 int replica_delete_by_name(const char *name);
-Object *replica_get_by_name(const char *name);
+Replica *replica_get_by_name(const char *name);
 void replica_flush(Replica *r);
 void replica_set_csn_assigned(Replica *r);
 void replica_get_referrals(const Replica *r, char ***referrals);
@@ -721,7 +725,7 @@ int replica_add_by_dn(const char *dn);
 int replica_delete_by_dn(const char *dn);
 int replica_is_being_configured(const char *dn);
 void consumer5_set_mapping_tree_state_for_replica(const Replica *r, RUV *supplierRuv);
-Object *replica_get_for_backend(const char *be_name);
+Replica *replica_get_for_backend(const char *be_name);
 void replica_set_purge_delay(Replica *r, uint32_t purge_delay);
 void replica_set_tombstone_reap_interval(Replica *r, long interval);
 void replica_update_ruv_consumer(Replica *r, RUV *supplier_ruv);
@@ -769,7 +773,7 @@ PRBool replica_is_state_flag_set(Replica *r, int32_t flag);
 void replica_set_state_flag(Replica *r, uint32_t flag, PRBool clear);
 void replica_set_tombstone_reap_stop(Replica *r, PRBool val);
 void replica_enable_replication(Replica *r);
-void replica_disable_replication(Replica *r, Object *r_obj);
+void replica_disable_replication(Replica *r);
 int replica_start_agreement(Replica *r, Repl_Agmt *ra);
 int windows_replica_start_agreement(Replica *r, Repl_Agmt *ra);
 
@@ -784,10 +788,10 @@ void multimaster_mtnode_construct_replicas(void);
 void multimaster_be_state_change(void *handle, char *be_name, int old_be_state, int new_be_state);
 
 #define CLEANRIDSIZ 64 /* maximum number for concurrent CLEANALLRUV tasks */
+#define CLEANRID_BUFSIZ 128
 
 typedef struct _cleanruv_data
 {
-    Object *repl_obj;
     Replica *replica;
     ReplicaId rid;
     Slapi_Task *task;
@@ -812,9 +816,11 @@ typedef struct _cleanruv_purge_data
 int replica_config_init(void);
 void replica_config_destroy(void);
 int get_replica_type(Replica *r);
-int replica_execute_cleanruv_task_ext(Object *r, ReplicaId rid);
+int replica_execute_cleanruv_task_ext(Replica *r, ReplicaId rid);
 void add_cleaned_rid(cleanruv_data *data);
 int is_cleaned_rid(ReplicaId rid);
+int32_t check_and_set_cleanruv_task_count(ReplicaId rid);
+int32_t check_and_set_abort_cleanruv_task_count(void);
 int replica_cleanall_ruv_abort(Slapi_PBlock *pb, Slapi_Entry *e, Slapi_Entry *eAfter, int *returncode, char *returntext, void *arg);
 void replica_cleanallruv_thread_ext(void *arg);
 void stop_ruv_cleaning(void);
@@ -833,8 +839,6 @@ void set_cleaned_rid(ReplicaId rid);
 void cleanruv_log(Slapi_Task *task, int rid, char *task_type, int sev_level, char *fmt, ...);
 char *replica_cleanallruv_get_local_maxcsn(ReplicaId rid, char *base_dn);
 
-
-
 /* replutil.c */
 LDAPControl *create_managedsait_control(void);
 LDAPControl *create_backend_control(Slapi_DN *sdn);
