@@ -136,7 +136,6 @@ add_new_agreement(Slapi_Entry *e)
     Repl_Agmt *ra = agmt_new_from_entry(e);
     Slapi_DN *replarea_sdn = NULL;
     Replica *replica = NULL;
-    Object *repl_obj = NULL;
     Object *ro = NULL;
 
     /* tell search result handler callback this entry was not sent */
@@ -152,17 +151,11 @@ add_new_agreement(Slapi_Entry *e)
     if (!replarea_sdn) {
         return 1;
     }
-    repl_obj = replica_get_replica_from_dn(replarea_sdn);
+    replica = replica_get_replica_from_dn(replarea_sdn);
     slapi_sdn_free(&replarea_sdn);
-    if (repl_obj) {
-        replica = (Replica *)object_get_data(repl_obj);
-    }
 
     rc = replica_start_agreement(replica, ra);
 
-    if (repl_obj)
-        object_release(repl_obj);
-
     return rc;
 }
 
@@ -523,9 +516,8 @@ agmtlist_modify_callback(Slapi_PBlock *pb,
             }
         } else if (slapi_attr_types_equivalent(mods[i]->mod_type,
                                                "nsds5debugreplicatimeout")) {
-            char *val = slapi_entry_attr_get_charptr(e, "nsds5debugreplicatimeout");
+            char *val = (char *)slapi_entry_attr_get_ref(e, "nsds5debugreplicatimeout");
             repl5_set_debug_timeout(val);
-            slapi_ch_free_string(&val);
         } else if (slapi_attr_is_last_mod(mods[i]->mod_type) ||
                    strcasecmp(mods[i]->mod_type, "description") == 0) {
             /* ignore modifier's name and timestamp attributes and the description. */
@@ -799,11 +791,11 @@ agmtlist_get_next_agreement_for_replica(Replica *r, Object *prev)
 
     replica_root = replica_get_root(r);
 
-    if (prev)
+    if (prev) {
         obj = objset_next_obj(agmt_set, prev);
-    else
+    } else {
         obj = objset_first_obj(agmt_set);
-
+    }
     for (; obj; obj = objset_next_obj(agmt_set, obj)) {
         agmt = (Repl_Agmt *)object_get_data(obj);
         if (!agmt) {
