@@ -283,6 +283,51 @@ repl5_tot_waitfor_async_results(callback_data *cb_data)
     }
 }
 
+/* This routine checks that the entry id of the suffix is
+ * stored in the parentid index
+ * The entry id of the suffix is stored with the equality key 0 (i.e. '=0')
+ * It first checks if the key '=0' exists. If it does not exists or if the first value
+ * stored with that key, does not match the suffix entryid (stored in the suffix entry
+ * from id2entry.db then it updates the value
+ */
+static void
+check_suffix_entryID(Slapi_Backend *be, Slapi_Entry *suffix)
+{
+    u_int32_t entryid;
+    char *entryid_str;
+    struct _back_info_index_key bck_info;
+
+    /* we are using a specific key in parentid to store the suffix entry id: '=0' */
+    bck_info.index = SLAPI_ATTR_PARENTID;
+    bck_info.key = "0";
+
+    /* First try to retrieve from parentid index the suffix entryID */
+    if (slapi_back_get_info(be, BACK_INFO_INDEX_KEY, (void **) &bck_info)) {
+        slapi_log_err(SLAPI_LOG_REPL, "check_suffix_entryID", "Total update: fail to retrieve suffix entryID. Let's try to write it\n");
+    }
+
+    /* Second retrieve the suffix entryid from the suffix entry itself */
+    entryid_str = (char*)slapi_entry_attr_get_ref(suffix, "entryid");
+    if (entryid_str == NULL) {
+        char *dn;
+        dn = slapi_entry_get_ndn(suffix);
+        slapi_log_err(SLAPI_LOG_ERR, "check_suffix_entryID", "Unable to retrieve entryid of the suffix entry %s\n", dn ? dn : "<unknown>");
+        return;
+    }
+    entryid = (u_int32_t) atoi(entryid_str);
+
+    if (!bck_info.key_found || bck_info.id != entryid) {
+        /* The suffix entryid is not present in parentid index
+         *  or differs from what is in id2entry (entry 'suffix')
+         * So write it to the parentid so that the range index used
+         * during total init will know the entryid of the suffix
+         */
+        bck_info.id = entryid;
+        if (slapi_back_set_info(be, BACK_INFO_INDEX_KEY, (void **) &bck_info)) {
+            slapi_log_err(SLAPI_LOG_ERR, "check_suffix_entryID", "Total update: fail to register suffix entryid, continue assuming suffix is the first entry\n");
+        }
+    }
+}
 
 /*
  * Completely refresh a replica. The basic protocol interaction goes
@@ -306,9 +351,7 @@ repl5_tot_run(Private_Repl_Protocol *prp)
     Slapi_DN *area_sdn = NULL;
     CSN *remote_schema_csn = NULL;
     int init_retry = 0;
-    Replica *replica;
     ReplicaId rid = 0; /* Used to create the replica keep alive subentry */
-    Slapi_Entry *suffix = NULL;
     char **instances = NULL;
     Slapi_Backend *be = NULL;
     int is_entryrdn = 0;
@@ -398,7 +441,6 @@ retry:
 
     pb = slapi_pblock_new();
 
-    replica = (Replica *)object_get_data(prp->replica_object);
     /*
      * Get the info about the entryrdn vs. entrydn from the backend.
      * If NOT is_entryrdn, its ancestor entries are always found prior to an entry.
@@ -411,6 +453,8 @@ retry:
         goto done;
     }
     be = slapi_be_select_by_instance_name(instances[0]);
+    slapi_ch_array_free(instances);
+
     if (!be) {
         slapi_log_err(SLAPI_LOG_ERR, repl_plugin_name, "repl5_tot_run - Unable to "
                                                        "get the instance for the suffix \"%s\".\n",
@@ -424,6 +468,7 @@ retry:
          * Entires are retireved sorted by parentid without the allid threshold.
          */
         /* Get suffix */
+        Slapi_Entry *suffix = NULL;
         rc = slapi_search_internal_get_entry(area_sdn, NULL, &suffix, repl_get_plugin_identity(PLUGIN_MULTIMASTER_REPLICATION));
         if (rc) {
             slapi_log_err(SLAPI_LOG_ERR, repl_plugin_name, "repl5_tot_run -  Unable to "
@@ -461,16 +506,18 @@ retry:
         ctrls[1] = create_backend_control(area_sdn);
 
         /* Time to make sure it exists a keep alive subentry for that replica */
-        if (replica) {
-            rid = replica_get_rid(replica);
+        if (prp->replica) {
+            rid = replica_get_rid(prp->replica);
         }
         replica_subentry_check(area_sdn, rid);
 
         /* Send the subtree of the suffix in the order of parentid index plus ldapsubentry and nstombstone. */
+        check_suffix_entryID(be, suffix);
         slapi_search_internal_set_pb(pb, slapi_sdn_get_dn(area_sdn),
                                      LDAP_SCOPE_SUBTREE, "(parentid>=1)", NULL, 0, ctrls, NULL,
                                      repl_get_plugin_identity(PLUGIN_MULTIMASTER_REPLICATION), OP_FLAG_BULK_IMPORT);
         cb_data.num_entries = 0UL;
+        slapi_entry_free(suffix);
     } else {
         /* Original total update */
         /* we need to provide managedsait control so that referral entries can
@@ -480,9 +527,8 @@ retry:
         ctrls[1] = create_backend_control(area_sdn);
 
         /* Time to make sure it exists a keep alive subentry for that replica */
-        replica = (Replica *)object_get_data(prp->replica_object);
-        if (replica) {
-            rid = replica_get_rid(replica);
+        if (prp->replica) {
+            rid = replica_get_rid(prp->replica);
         }
         replica_subentry_check(area_sdn, rid);
 
@@ -598,13 +644,11 @@ repl5_tot_stop(Private_Repl_Protocol *prp)
     int return_value;
     PRIntervalTime start, maxwait, now;
     PRUint64 timeout = DEFAULT_PROTOCOL_TIMEOUT;
-    Replica *replica = NULL;
 
     if ((timeout = agmt_get_protocol_timeout(prp->agmt)) == 0) {
         timeout = DEFAULT_PROTOCOL_TIMEOUT;
-        if (prp->replica_object) {
-            replica = object_get_data(prp->replica_object);
-            if ((timeout = replica_get_protocol_timeout(replica)) == 0) {
+        if (prp->replica) {
+            if ((timeout = replica_get_protocol_timeout(prp->replica)) == 0) {
                 timeout = DEFAULT_PROTOCOL_TIMEOUT;
             }
         }
@@ -683,7 +727,7 @@ Repl_5_Tot_Protocol_new(Repl_Protocol *rp)
     prp->repl50consumer = 0;
     prp->repl71consumer = 0;
     prp->repl90consumer = 0;
-    prp->replica_object = prot_get_replica_object(rp);
+    prp->replica = prot_get_replica(rp);
     return prp;
 loser:
     repl5_tot_delete(&prp);
