@@ -1470,7 +1470,7 @@ NSUniqueAttr_Init(Slapi_PBlock *pb)
 {
     int err = 0;
     Slapi_Entry *plugin_entry = NULL;
-    char *plugin_type = NULL;
+    const char *plugin_type = NULL;
     int preadd = SLAPI_PLUGIN_PRE_ADD_FN;
     int premod = SLAPI_PLUGIN_PRE_MODIFY_FN;
     int premdn = SLAPI_PLUGIN_PRE_MODRDN_FN;
@@ -1493,13 +1493,12 @@ NSUniqueAttr_Init(Slapi_PBlock *pb)
 
     if ((slapi_pblock_get(pb, SLAPI_PLUGIN_CONFIG_ENTRY, &plugin_entry) == 0) &&
         plugin_entry &&
-        (plugin_type = slapi_entry_attr_get_charptr(plugin_entry, "nsslapd-plugintype")) &&
+        (plugin_type = slapi_entry_attr_get_ref(plugin_entry, "nsslapd-plugintype")) &&
         plugin_type && strstr(plugin_type, "betxn")) {
         preadd = SLAPI_PLUGIN_BE_TXN_PRE_ADD_FN;
         premod = SLAPI_PLUGIN_BE_TXN_PRE_MODIFY_FN;
         premdn = SLAPI_PLUGIN_BE_TXN_PRE_MODRDN_FN;
     }
-    slapi_ch_free_string(&plugin_type);
 
     /* Provide descriptive information */
     err = slapi_pblock_set(pb, SLAPI_PLUGIN_DESCRIPTION,
