@@ -19,22 +19,17 @@ int
 ldbm_back_archive2ldbm(Slapi_PBlock *pb)
 {
     struct ldbminfo *li;
+    Slapi_Task *task;
+    ldbm_instance *inst = NULL;
     char *rawdirectory = NULL; /* -a <directory> */
     char *directory = NULL;    /* normalized */
-    char *backendname = NULL;
-    int return_value = -1;
-    int task_flags = 0;
-    int run_from_cmdline = 0;
-    Slapi_Task *task;
-    int is_old_to_new = 0;
-    ldbm_instance *inst = NULL;
-    char *dbversion = NULL;
-    char *dataversion = NULL;
-    int value = 0;
+    int32_t return_value = -1;
+    int32_t task_flags = 0;
+    int32_t run_from_cmdline = 0;
+    int32_t is_old_to_new = 0;
 
     slapi_pblock_get(pb, SLAPI_PLUGIN_PRIVATE, &li);
     slapi_pblock_get(pb, SLAPI_SEQ_VAL, &rawdirectory);
-    slapi_pblock_get(pb, SLAPI_BACKEND_INSTANCE_NAME, &backendname);
     slapi_pblock_get(pb, SLAPI_BACKEND_TASK, &task);
     slapi_pblock_get(pb, SLAPI_TASK_FLAGS, &task_flags);
     li->li_flags = run_from_cmdline = (task_flags & SLAPI_TASK_RUNNING_FROM_COMMANDLINE);
@@ -45,6 +40,7 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
     }
 
     directory = rel2abspath(rawdirectory);
+    /* skip check for version and idl upgrade
     return_value = dbversion_read(li, directory, &dbversion, &dataversion);
     if (return_value) {
         if (ENOENT == return_value) {
@@ -55,8 +51,8 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
         slapi_log_err(SLAPI_LOG_WARNING, "ldbm_back_archive2ldbm",
                       "Unable to read dbversion file in %s\n", directory);
     }
-
-    /* check the current idl format vs backup DB version */
+*/
+    /* check the current idl format vs backup DB version
     if (idl_get_idl_new()) {
         value = lookup_dbversion(dbversion, DBVERSION_TYPE);
         if (value & DBVERSION_OLD_IDL) {
@@ -65,11 +61,16 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
     }
     slapi_ch_free_string(&dbversion);
     slapi_ch_free_string(&dataversion);
+*/
 
     /* No ldbm be's exist until we process the config information. */
     if (run_from_cmdline) {
         mapping_tree_init();
-        ldbm_config_load_dse_info(li);
+
+        if (dblayer_setup(li)) {
+            slapi_log_err(SLAPI_LOG_CRIT, "ldbm_back_init", "dblayer_setup failed\n");
+            return -1;
+        }
 
         /* initialize a restore file to be able to detect a startup after restore */
         if (dblayer_restore_file_init(li)) {
@@ -77,14 +78,6 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
             return -1;
         }
     }
-    if (backendname) {
-        inst = ldbm_instance_find_by_name(li, backendname);
-        if (NULL == inst) {
-            slapi_log_err(SLAPI_LOG_ERR, "ldbm_back_archive2ldbm", "Backend \"%s\" does not exist.\n",
-                          backendname);
-            return -1;
-        }
-    }
     if (!run_from_cmdline) {
         Object *inst_obj, *inst_obj2;
 
@@ -162,7 +155,7 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
     }
 
     /* tell the database to restore */
-    return_value = dblayer_restore(li, directory, task, backendname);
+    return_value = dblayer_restore(li, directory, task);
     if (0 != return_value) {
         slapi_log_err(SLAPI_LOG_ERR,
                       "ldbm_back_archive2ldbm", "Failed to read backup file set. "
@@ -172,8 +165,7 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
                                                 "the backup set.  error=%d (%s)\n",
                       return_value, dblayer_strerror(return_value));
         if (task) {
-            slapi_task_log_notice(task, "Failed to read the backup file set "
-                                        "from %s",
+            slapi_task_log_notice(task, "Failed to read the backup file set from %s",
                                   directory);
         }
     }
@@ -184,7 +176,7 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
             char *p;
             char c;
             char *bakup_dir = NULL;
-            int skipinit = SLAPI_UPGRADEDB_SKIPINIT;
+            int32_t skipinit = SLAPI_UPGRADEDB_SKIPINIT;
 
             p = strrchr(directory, '/');
             if (NULL == p) {
@@ -211,25 +203,26 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
             return_value = ldbm_back_upgradedb(pb);
         }
     } else {
-        ldbm_instance *inst;
         Object *inst_obj;
-        int ret;
+        int32_t ret;
 
         if (0 != return_value) {
-            /* error case (607331)
-             * just to go back to the previous state if possible */
-            if ((return_value = dblayer_start(li, DBLAYER_NORMAL_MODE))) {
+            /*
+             * error case (607331)
+             * just to go back to the previous state if possible (preserve
+             * original error for now)
+             */
+            if ((ret = dblayer_start(li, DBLAYER_NORMAL_MODE))) {
                 slapi_log_err(SLAPI_LOG_ERR,
                               "ldbm_back_archive2ldbm", "Unable to to start database in [%s]\n",
                               li->li_directory);
                 if (task) {
-                    slapi_task_log_notice(task, "Failed to start the database in "
-                                                "%s",
+                    slapi_task_log_notice(task, "Failed to start the database in %s",
                                           li->li_directory);
                 }
-                goto out;
             }
         }
+
         /* bring all backends and changelog back online */
         plugin_call_plugins(pb, SLAPI_PLUGIN_BE_POST_OPEN_FN);
         for (inst_obj = objset_first_obj(li->li_instance_set); inst_obj;
@@ -241,8 +234,7 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
                               "ldbm_back_archive2ldbm", "Unable to restart '%s'\n",
                               inst->inst_name);
                 if (task) {
-                    slapi_task_log_notice(task, "Unable to restart '%s'",
-                                          inst->inst_name);
+                    slapi_task_log_notice(task, "Unable to restart '%s'", inst->inst_name);
                 }
             } else {
                 slapi_mtn_be_enable(inst->inst_be);
@@ -250,6 +242,7 @@ ldbm_back_archive2ldbm(Slapi_PBlock *pb)
             }
         }
     }
+
 out:
     if (run_from_cmdline && (0 == return_value)) {
         dblayer_restore_file_update(li, directory);
@@ -286,8 +279,16 @@ ldbm_back_ldbm2archive(Slapi_PBlock *pb)
     /* start the database code up, do not attempt to perform recovery */
     if (run_from_cmdline) {
         /* No ldbm be's exist until we process the config information. */
+
+    /* copied here, need better solution */
+    /* initialize dblayer  */
+        if (dblayer_setup(li)) {
+            slapi_log_err(SLAPI_LOG_CRIT, "ldbm_back_init", "dblayer_setup failed\n");
+            goto out;
+        }
+
         mapping_tree_init();
-        ldbm_config_load_dse_info(li);
+
         if (0 != (return_value =
                       dblayer_start(li,
                                     DBLAYER_ARCHIVE_MODE | DBLAYER_NO_DBTHREADS_MODE))) {
