@@ -407,10 +407,9 @@ index_addordel_entry(
         /*
          * add the entryusn to the list of indexed attributes, even if it's a tombstone
          */
-        entryusn_str = slapi_entry_attr_get_charptr(e->ep_entry, SLAPI_ATTR_ENTRYUSN);
+        entryusn_str = (char *)slapi_entry_attr_get_ref(e->ep_entry, SLAPI_ATTR_ENTRYUSN);
         if (entryusn_str != NULL) {
             result = index_addordel_string(be, SLAPI_ATTR_ENTRYUSN, entryusn_str, e->ep_id, flags, txn);
-            slapi_ch_free_string(&entryusn_str);
             if (result != 0) {
                 ldbm_nasty("index_addordel_entry", errmsg, 1021, result);
                 return result;
@@ -1454,10 +1453,7 @@ index_range_read_ext(
     if (!is_indexed(indextype, ai->ai_indexmask, ai->ai_index_rules)) {
 
         /* Mark that the search has an unindexed component */
-        uint32_t opnote = 0;
-        slapi_pblock_get(pb, SLAPI_OPERATION_NOTES, &opnote);
-        opnote |= SLAPI_OP_NOTE_UNINDEXED;
-        slapi_pblock_set(pb, SLAPI_OPERATION_NOTES, &opnote);
+        slapi_pblock_set_flag_operation_notes(pb, SLAPI_OP_NOTE_UNINDEXED);
 
         idl = idl_allids(be);
         slapi_log_err(SLAPI_LOG_TRACE,
