@@ -580,7 +580,7 @@ ldbm_back_add(Slapi_PBlock *pb)
                         slapi_log_err(SLAPI_LOG_REPL, "ldbm_back_add", "Resurrection of %s - Added Conflict reason %s\n",
                                       dn, reason);
                     }
-                    slapi_ch_free((void **)&reason);
+                    slapi_ch_free_string(&reason);
                 }
                 /* Clear the Tombstone Flag in the entry */
                 slapi_entry_clear_flag(addingentry->ep_entry, SLAPI_ENTRY_FLAG_TOMBSTONE);
@@ -746,6 +746,7 @@ ldbm_back_add(Slapi_PBlock *pb)
                                                SLAPI_ATTR_VALUE_PARENT_UNIQUEID,
                                                operation->o_params.p.p_add.parentuniqueid);
                     }
+                    slapi_sdn_done(&nscpEntrySDN);
                 } else {
                         /* if an entry is explicitely added as tombstone the entry flag has to be set */
                         if (slapi_entry_attr_hasvalue(addingentry->ep_entry,
