@@ -49,6 +49,7 @@ ldbm_index_parse_entry(ldbm_instance *inst, Slapi_Entry *e, const char *trace_st
     }
 
     if (index_name != NULL) {
+        slapi_ch_free_string(index_name);
         *index_name = slapi_ch_strdup(attrValue->bv_val);
     }
 
@@ -113,7 +114,7 @@ ldbm_instance_index_config_add_callback(Slapi_PBlock *pb __attribute__((unused))
                                         void *arg)
 {
     ldbm_instance *inst = (ldbm_instance *)arg;
-    char *index_name;
+    char *index_name = NULL;
 
     returntext[0] = '\0';
     *returncode = ldbm_index_parse_entry(inst, e, "from DSE add", &index_name);
@@ -129,7 +130,7 @@ ldbm_instance_index_config_add_callback(Slapi_PBlock *pb __attribute__((unused))
             PR_ASSERT(ai != NULL);
             ai->ai_indexmask |= INDEX_OFFLINE;
         }
-        slapi_ch_free((void **)&index_name);
+        slapi_ch_free_string(&index_name);
         return SLAPI_DSE_CALLBACK_OK;
     } else {
         return SLAPI_DSE_CALLBACK_ERROR;
@@ -185,7 +186,7 @@ ldbm_instance_index_config_delete_callback(Slapi_PBlock *pb,
         *returncode = LDAP_UNAVAILABLE;
         rc = SLAPI_DSE_CALLBACK_ERROR;
     } else {
-        if (dblayer_erase_index_file(inst->inst_be, ainfo, 0 /* do chkpt */)) {
+        if (dblayer_erase_index_file(inst->inst_be, ainfo, PR_TRUE, 0 /* do chkpt */)) {
             *returncode = LDAP_UNWILLING_TO_PERFORM;
             rc = SLAPI_DSE_CALLBACK_ERROR;
         }
