@@ -1008,7 +1008,13 @@ dse_write_file_nolock(struct dse *pdse)
                  * We have now written to the tmp location, and renamed it
                  * we need to open and fsync the dir to make the rename stick.
                  */
-                int fp_configdir = open(pdse->dse_configdir, O_PATH | O_DIRECTORY);
+                int fp_configdir =
+#ifdef O_PATH
+                    open(pdse->dse_configdir, O_PATH | O_DIRECTORY)
+#else
+                    open(pdse->dse_configdir, O_RDONLY | O_DIRECTORY)
+#endif
+                    ;
                 if (fp_configdir != -1) {
                     fsync(fp_configdir);
                     close(fp_configdir);
