@@ -302,15 +302,11 @@ do_modify(Slapi_PBlock *pb)
         goto free_and_return;
     }
 
-/* check for decoding error */
-/*
-      if using mozldap - will return LBER_END_OF_SEQORSET if loop
-      completed successfully, otherwise, other value
-      if using openldap - will return LBER_DEFAULT in either case
+    /* check for decoding error */
+    /* will return LBER_DEFAULT in either case
         if there was at least one element read, len will be -1
         if there were no elements read (empty modify) len will be 0
     */
-#if defined(USE_OPENLDAP)
     if (tag != LBER_END_OF_SEQORSET) {
         if ((len == 0) && (0 == smods.num_elements) && !ignored_some_mods) {
             /* ok - empty modify - allow empty modifies */
@@ -321,13 +317,6 @@ do_modify(Slapi_PBlock *pb)
         }
         /* else ok */
     }
-#else
-    if (tag != LBER_END_OF_SEQORSET) {
-        op_shared_log_error_access(pb, "MOD", rawdn, "decoding error");
-        send_ldap_result(pb, LDAP_PROTOCOL_ERROR, NULL, "decoding error", 0, NULL);
-        goto free_and_return;
-    }
-#endif
 
     /* decode the optional controls - put them in the pblock */
     if ((err = get_ldapmessage_controls(pb, ber, NULL)) != 0) {
@@ -1455,9 +1444,11 @@ optimize_mods(Slapi_Mods *smods)
 
     prev_mod = slapi_mods_get_first_mod(smods);
     while ((mod = slapi_mods_get_next_mod(smods))) {
-        if ((SLAPI_IS_MOD_ADD(prev_mod->mod_op) || SLAPI_IS_MOD_DELETE(prev_mod->mod_op)) &&
+        if (prev_mod &&
+            (SLAPI_IS_MOD_ADD(prev_mod->mod_op) || SLAPI_IS_MOD_DELETE(prev_mod->mod_op)) &&
             (prev_mod->mod_op == mod->mod_op) &&
-            (!strcasecmp(prev_mod->mod_type, mod->mod_type))) {
+            (!strcasecmp(prev_mod->mod_type, mod->mod_type)))
+        {
             /* Get the current number of mod values from the previous mod.  Do it once per attr */
             if (mod_count == 0) {
                 for (; prev_mod->mod_bvalues != NULL && prev_mod->mod_bvalues[mod_count] != NULL; mod_count++)
