@@ -304,7 +304,9 @@ int config_set_pw_syntax(const char *attrname, char *value, char *errorbuf, int
 int32_t config_set_pw_palindrome(const char *attrname, char *value, char *errorbuf, int apply);
 int32_t config_set_pw_dict_check(const char *attrname, char *value, char *errorbuf, int apply);
 int32_t config_set_pw_dict_path(const char *attrname, char *value, char *errorbuf, int apply);
+char **config_get_pw_user_attrs_array(void);
 int32_t config_set_pw_user_attrs(const char *attrname, char *value, char *errorbuf, int apply);
+char **config_get_pw_bad_words_array(void);
 int32_t config_set_pw_bad_words(const char *attrname, char *value, char *errorbuf, int apply);
 int32_t config_set_pw_max_seq_sets(const char *attrname, char *value, char *errorbuf, int apply);
 int32_t config_set_pw_max_seq(const char *attrname, char *value, char *errorbuf, int apply);
@@ -376,6 +378,7 @@ int config_set_entryusn_global(const char *attrname, char *value, char *errorbuf
 int config_set_entryusn_import_init(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_default_naming_context(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_disk_monitoring(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_disk_threshold_readonly(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_disk_threshold(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_disk_grace_period(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_disk_logging_critical(const char *attrname, char *value, char *errorbuf, int apply);
@@ -541,6 +544,7 @@ void config_set_auditlog_enabled(int value);
 void config_set_auditfaillog_enabled(int value);
 int config_get_accesslog_logging_enabled(void);
 int config_get_disk_monitoring(void);
+int config_get_disk_threshold_readonly(void);
 PRInt64 config_get_disk_threshold(void);
 int config_get_disk_grace_period(void);
 int config_get_disk_logging_critical(void);
@@ -595,6 +599,15 @@ int config_get_extract_pem(void);
 int32_t config_get_enable_upgrade_hash(void);
 int32_t config_set_enable_upgrade_hash(const char *attrname, char *value, char *errorbuf, int apply);
 
+
+int32_t config_get_enable_ldapssotoken();
+int32_t config_set_enable_ldapssotoken(const char *attrname, char *value, char *errorbuf, int apply);
+char * config_get_ldapssotoken_secret();
+int32_t config_set_ldapssotoken_secret(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_ldapssotoken_ttl(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_get_ldapssotoken_ttl();
+
+
 int is_abspath(const char *);
 char *rel2abspath(char *);
 char *rel2abspath_ext(char *, char *);
@@ -851,6 +864,7 @@ void slapd_nasty(char *str, int c, int err);
 int strarray2str(char **a, char *buf, size_t buflen, int include_quotes);
 int slapd_chown_if_not_owner(const char *filename, uid_t uid, gid_t gid);
 int slapd_comp_path(char *p0, char *p1);
+void replace_char(char *name, char c, char c2);
 
 
 /*
@@ -1088,6 +1102,7 @@ void do_search(Slapi_PBlock *pb);
 /*
  * ssl.c
  */
+char *check_private_certdir();
 int slapd_nss_init(int init_ssl, int config_available);
 int slapd_ssl_init(void);
 int slapd_ssl_init2(PRFileDesc **fd, int startTLS);
@@ -1496,6 +1511,7 @@ void slapd_do_nothing(int);
 void slapd_wait4child(int);
 void disk_mon_get_dirs(char ***list);
 int32_t disk_get_info(char *dir, uint64_t *total_space, uint64_t *avail_space, uint64_t *used_space);
+char *disk_mon_check_diskspace(char **dirs, uint64_t threshold, uint64_t *disk_space);
 
 /*
  * main.c
