@@ -346,11 +346,18 @@ send_ldap_result_ext(
     ber_tag_t bind_method = 0;
     int internal_op;
     int i, rc, logit = 0;
+    char *pbtext;
 
     slapi_pblock_get(pb, SLAPI_BIND_METHOD, &bind_method);
     slapi_pblock_get(pb, SLAPI_OPERATION, &operation);
     slapi_pblock_get(pb, SLAPI_CONNECTION, &conn);
 
+    if (text) {
+        pbtext = text;
+    } else {
+        slapi_pblock_get(pb, SLAPI_PB_RESULT_TEXT, &pbtext);
+    }
+
     if (operation == NULL) {
         slapi_log_err(SLAPI_LOG_ERR, "send_ldap_result_ext", "No operation found: slapi_search_internal_set_pb was incomplete (invalid 'base' ?)\n");
         return;
@@ -497,7 +504,7 @@ send_ldap_result_ext(
             err = LDAP_PARTIAL_RESULTS;
         }
         rc = ber_printf(ber, "{it{ess", operation->o_msgid, tag, err,
-                        matched ? matched : "", text ? text : "");
+                        matched ? matched : "", pbtext ? pbtext : "");
 
         /*
          * if this is an LDAPv3 ExtendedResponse to an ExtendedRequest,
@@ -1546,6 +1553,8 @@ send_ldap_search_entry_ext(
      * "+" means all operational attributes (rfc3673)
      * operational attributes are only retrieved if they are named
      * specifically or when "+" is specified.
+     * In the case of "1.1", if there are other requested attributes
+     * then "1.1" should be ignored.
      */
 
     /* figure out if we want all user attributes or no attributes at all */
@@ -1560,7 +1569,10 @@ send_ldap_search_entry_ext(
             if (strcmp(LDAP_ALL_USER_ATTRS, attrs[i]) == 0) {
                 alluserattrs = 1;
             } else if (strcmp(LDAP_NO_ATTRS, attrs[i]) == 0) {
-                noattrs = 1;
+                /* "1.1" is only valid if it's the only requested attribute */
+                if (i == 0 && attrs[1] == NULL) {
+                    noattrs = 1;
+                }
             } else if (strcmp(LDAP_ALL_OPERATIONAL_ATTRS, attrs[i]) == 0) {
                 alloperationalattrs = 1;
             } else {
@@ -1839,12 +1851,15 @@ struct slapi_note_map
 {
     unsigned int snp_noteid;
     char *snp_string;
+    char *snp_detail;
 };
 
 static struct slapi_note_map notemap[] = {
-    {SLAPI_OP_NOTE_UNINDEXED, "U"},
-    {SLAPI_OP_NOTE_SIMPLEPAGED, "P"},
-    {SLAPI_OP_NOTE_FULL_UNINDEXED, "A"}};
+    {SLAPI_OP_NOTE_UNINDEXED, "U", "Partially Unindexed Filter"},
+    {SLAPI_OP_NOTE_SIMPLEPAGED, "P", "Paged Search"},
+    {SLAPI_OP_NOTE_FULL_UNINDEXED, "A", "Fully Unindexed Filter"},
+    {SLAPI_OP_NOTE_FILTER_INVALID, "F", "Filter Element Missing From Schema"},
+};
 
 #define SLAPI_NOTEMAP_COUNT (sizeof(notemap) / sizeof(struct slapi_note_map))
 
@@ -1875,24 +1890,75 @@ notes2str(unsigned int notes, char *buf, size_t buflen)
 
     p = buf;
     for (i = 0; i < SLAPI_NOTEMAP_COUNT; ++i) {
+        /* Check if the flag is present in the operation notes */
         if ((notemap[i].snp_noteid & notes) != 0) {
-            if (p > buf && buflen > 0) {
+            len = strlen(notemap[i].snp_string);
+            if (p > buf) {
+                if (buflen < (len + 1)) {
+                    break;
+                }
+                // Check buflen
                 *p++ = ',';
-                *p = '\0';
                 --buflen;
             } else {
+                if (buflen < (len + 6)) {
+                    break;
+                }
+                // Check buflen
                 strcpy(p, "notes=");
                 p += 6;
                 buflen -= 6;
             }
-            len = strlen(notemap[i].snp_string);
-            if (buflen < len) {
-                break; /* bail out (result is truncated) */
-            }
             memcpy(p, notemap[i].snp_string, len);
             buflen -= len;
             p += len;
-            *p = '\0';
+        }
+    }
+
+    /* Get a pointer to the "start" of where we'll write the details. */
+    char *note_end = p;
+
+    /* Now add the details (if possible) */
+    for (i = 0; i < SLAPI_NOTEMAP_COUNT; ++i) {
+        if ((notemap[i].snp_noteid & notes) != 0) {
+            len = strlen(notemap[i].snp_detail);
+            if (p > note_end) {
+                /*
+                 * len of detail + , + "
+                 */
+                if (buflen < (len + 2)) {
+                    break;
+                }
+                /*
+                 * If the working pointer is past the start
+                 * position, add a comma now before the next term.
+                 */
+                *p++ = ',';
+                --buflen;
+            } else {
+                /*
+                 * len of detail + details=" + "
+                 */
+                if (buflen < (len + 11)) {
+                    break;
+                }
+                /* This is the first iteration, so add " details=\"" */
+                strcpy(p, " details=\"");
+                p += 10;
+                buflen -= 10;
+            }
+            memcpy(p, notemap[i].snp_detail, len);
+            /*
+             * We don't account for the ", because on the next loop we may
+             * backtrack over it, so it doesn't count to the len calculation.
+             */
+            buflen -= len;
+            p += len;
+            /*
+             * Put in the end quote. If another snp_detail is append a comma
+             * will overwrite the quote.
+             */
+            *(p + 1) = '"';
         }
     }
 
@@ -1903,11 +1969,12 @@ notes2str(unsigned int notes, char *buf, size_t buflen)
 static void
 log_result(Slapi_PBlock *pb, Operation *op, int err, ber_tag_t tag, int nentries)
 {
-    char *notes_str, notes_buf[256];
+    char *notes_str = NULL;
+    char notes_buf[256] = {0};
     int internal_op;
     CSN *operationcsn = NULL;
     char csn_str[CSN_STRSIZE + 5];
-    char etime[ETIME_BUFSIZ];
+    char etime[ETIME_BUFSIZ] = {0};
     int pr_idx = -1;
     int pr_cookie = -1;
     uint32_t operation_notes;
@@ -1926,9 +1993,10 @@ log_result(Slapi_PBlock *pb, Operation *op, int err, ber_tag_t tag, int nentries
     struct timespec o_hr_time_end;
     slapi_operation_time_elapsed(op, &o_hr_time_end);
 
-    snprintf(etime, ETIME_BUFSIZ, "%" PRId64 ".%010" PRId64 "", (int64_t)o_hr_time_end.tv_sec, (int64_t)o_hr_time_end.tv_nsec);
 
-    slapi_pblock_get(pb, SLAPI_OPERATION_NOTES, &operation_notes);
+    snprintf(etime, ETIME_BUFSIZ, "%" PRId64 ".%.09" PRId64 "", (int64_t)o_hr_time_end.tv_sec, (int64_t)o_hr_time_end.tv_nsec);
+
+    operation_notes = slapi_pblock_get_operation_notes(pb);
 
     if (0 == operation_notes) {
         notes_str = "";
