@@ -30,6 +30,10 @@
 #include "pratom.h"
 #include "snmp_collator.h"
 
+#ifdef SYSTEMTAP
+#include <sys/sdt.h>
+#endif
+
 static void log_search_access(Slapi_PBlock *pb, const char *base, int scope, const char *filter, const char *msg);
 
 void
@@ -57,6 +61,9 @@ do_search(Slapi_PBlock *pb)
     Connection *pb_conn = NULL;
 
     slapi_log_err(SLAPI_LOG_TRACE, "do_search", "=>\n");
+#ifdef SYSTEMTAP
+    STAP_PROBE(ns-slapd, do_search__entry);
+#endif
 
     slapi_pblock_get(pb, SLAPI_OPERATION, &operation);
     ber = operation->o_ber;
@@ -90,7 +97,7 @@ do_search(Slapi_PBlock *pb)
 
     /* baseObject, scope, derefAliases, sizelimit, timelimit, attrsOnly */
     if (ber_scanf(ber, "{aiiiib", &rawbase, &scope, &deref, &sizelimit, &timelimit, &attrsonly) == LBER_ERROR) {
-        slapi_ch_free((void **)&rawbase);
+        slapi_ch_free_string(&rawbase);
         log_search_access(pb, "???", -1, "???", "decoding error");
         send_ldap_result(pb, LDAP_PROTOCOL_ERROR, NULL, NULL, 0, NULL);
         return;
@@ -106,11 +113,20 @@ do_search(Slapi_PBlock *pb)
                                        rawbase ? rawbase : "", "strict: invalid dn");
             send_ldap_result(pb, LDAP_INVALID_DN_SYNTAX,
                              NULL, "invalid dn", 0, NULL);
-            slapi_ch_free((void **)&rawbase);
+            slapi_ch_free_string(&rawbase);
             return;
         }
     }
 
+    if (rawbase && strlen(rawbase) == 0 && scope != LDAP_SCOPE_BASE) {
+        /* This is not a Root DSE search, so map it to the default naming context */
+        const char *default_basedn = config_get_default_naming_context();
+        if (default_basedn) {
+            slapi_ch_free_string(&rawbase);
+            rawbase = slapi_ch_strdup(default_basedn);
+        }
+    }
+
     /* If anonymous access is only allowed for searching the root DSE,
      * we need to reject any other anonymous search attempts. */
     if ((slapi_sdn_get_dn(&(operation->o_sdn)) == NULL) &&
@@ -198,6 +214,20 @@ do_search(Slapi_PBlock *pb)
         goto free_and_return;
     }
 
+    /*
+     * Scan the filters syntax - depending on settings, this will do nothing, warn
+     * or reject. A question is the location of this and if we should try to work with
+     * internal searches too ...
+     */
+    Slapi_Filter_Result r = slapi_filter_schema_check(pb, filter, config_get_verify_filter_schema());
+    if (r == FILTER_SCHEMA_FAILURE) {
+        char *errtxt = "The filter provided contains invalid attributes not found in schema";
+        err = LDAP_UNWILLING_TO_PERFORM;
+        log_search_access(pb, base, scope, "???", errtxt);
+        send_ldap_result(pb, err, NULL, errtxt, 0, NULL);
+        goto free_and_return;
+    }
+
     /* attributes */
     attrs = NULL;
     if (ber_scanf(ber, "{v}}", &attrs) == LBER_ERROR) {
@@ -350,6 +380,11 @@ do_search(Slapi_PBlock *pb)
     slapi_pblock_set(pb, SLAPI_SEARCH_SIZELIMIT, &sizelimit);
     slapi_pblock_set(pb, SLAPI_SEARCH_TIMELIMIT, &timelimit);
 
+
+    /*
+     * op_shared_search defines STAP_PROBE for __entry and __return,
+     * so these can be used to delineate the start and end here.
+     */
     op_shared_search(pb, psearch ? 0 : 1 /* send result */);
 
     slapi_pblock_get(pb, SLAPI_PLUGIN_OPRETURN, &rc);
@@ -379,6 +414,10 @@ free_and_return:
         }
         slapi_ch_free_string(&rawbase);
     }
+
+#ifdef SYSTEMTAP
+    STAP_PROBE(ns-slapd, do_search__return);
+#endif
 }
 
 static void
