@@ -415,21 +415,15 @@ addErrorStat(
 /*
    * Update the counters
    */
-#if defined(USE_OPENLDAP)
     if ((err <= NEGATIVE_MAX_ERROR_NB) || (err >= MAX_ERROR_NB))
-#else
-    if ((err <= 0) || (err >= MAX_ERROR_NB))
-#endif
     {
         fprintf(stderr, "ldclt[%d]: Illegal error number %d\n", mctx.pid, err);
         fflush(stderr);
         mctx.errorsBad++;
     }
-#if defined(USE_OPENLDAP)
     else if (err < 0) {
         mctx.negativeErrors[abs(err)]++;
     }
-#endif
     else {
         mctx.errors[err]++;
     }
@@ -453,11 +447,7 @@ addErrorStat(
      * Ok, we should not ignore this error...
      * Maybe the limit is reached ?
      */
-#if defined(USE_OPENLDAP)
         if ((err <= NEGATIVE_MAX_ERROR_NB) || (err >= MAX_ERROR_NB))
-#else
-        if ((err <= 0) || (err >= MAX_ERROR_NB))
-#endif
         {
             if (mctx.errorsBad > mctx.maxErrors) {
                 printf("ldclt[%d]: Max error limit reached - exiting.\n", mctx.pid);
@@ -467,7 +457,6 @@ addErrorStat(
                 ldcltExit(EXIT_MAX_ERRORS); /*JLS 25-08-00*/
             }
         }
-#if defined(USE_OPENLDAP)
         else if (err < 0) {
             if (mctx.negativeErrors[abs(err)] > mctx.maxErrors) {
                 printf("ldclt[%d]: Max error limit reached - exiting.\n", mctx.pid);
@@ -477,7 +466,6 @@ addErrorStat(
                 ldcltExit(EXIT_MAX_ERRORS); /*JLS 25-08-00*/
             }
         }
-#endif
         else {
             if (mctx.errors[err] > mctx.maxErrors) {
                 printf("ldclt[%d]: Max error limit reached - exiting.\n", mctx.pid);
