@@ -24,7 +24,6 @@
 int ldap_syslog;
 int ldap_syslog_level;
 
-#if defined(USE_OPENLDAP)
 static char *
 ldif_type_and_value(const char *type, const char *val, int vlen)
 {
@@ -41,7 +40,6 @@ ldif_type_and_value(const char *type, const char *val, int vlen)
 
     return (buf);
 }
-#endif
 
 static void
 display_usage(char *name)
@@ -94,11 +92,13 @@ main(int argc, char **argv)
             }
             if (nread + cur > max) {
                 max += BUFSIZ;
-                if ((val = (char *)realloc(val, max)) ==
-                    NULL) {
+                char *tmp = NULL;
+                if ((tmp = (char *)realloc(val, max)) == NULL) {
+                    free(val);
                     perror("realloc");
                     return (1);
                 }
+                val = tmp;
             }
             memcpy(val + cur, buf, nread);
             cur += nread;
@@ -127,12 +127,14 @@ main(int argc, char **argv)
             /* if buffer was filled, expand and keep reading unless last char
             is linefeed, in which case it is OK for buffer to be full */
             while (((curlen = strlen(buf)) == (maxlen - 1)) && buf[curlen - 1] != '\n') {
+                char *tmp = NULL;
                 maxlen *= 2;
-                if ((buf = (char *)realloc(buf, maxlen)) == NULL) {
+                if ((tmp = (char *)realloc(buf, maxlen)) == NULL) {
                     perror("realloc");
                     free(buf);
                     return (1);
                 }
+                buf = tmp;
                 if (NULL == fgets(buf + curlen, maxlen / 2 + 1, stdin)) {
                     /* no more input to read. */
                     break;
