@@ -4,18 +4,23 @@
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
- * See LICENSE for details. 
+ * See LICENSE for details.
  * END COPYRIGHT BLOCK **/
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 
 #ifndef _RSEARCH_H
 #define _RSEARCH_H
 
-typedef enum { op_search, op_modify, op_idxmodify, op_add, op_delete, op_compare } Operation;
+typedef enum { op_search,
+               op_modify,
+               op_idxmodify,
+               op_add,
+               op_delete,
+               op_compare } Operation;
 #include "nametable.h"
 #include "sdattable.h"
 
