@@ -1,6 +1,5 @@
 import cockpit from "cockpit";
 import React from "react";
-import { NotificationController } from "./lib/notifications.jsx";
 import { log_cmd } from "./lib/tools.jsx";
 import {
     ChainingConfig,
@@ -9,6 +8,8 @@ import {
 import { GlobalDatabaseConfig } from "./lib/database/databaseConfig.jsx";
 import { Suffix } from "./lib/database/suffix.jsx";
 import { Backups } from "./lib/database/backups.jsx";
+import { GlobalPwPolicy } from "./lib/database/globalPwp.jsx";
+import { LocalPwPolicy } from "./lib/database/localPwp.jsx";
 import {
     Modal,
     Icon,
@@ -28,6 +29,8 @@ import "./css/ds.css";
 const DB_CONFIG = "dbconfig";
 const CHAINING_CONFIG = "chaining-config";
 const BACKUP_CONFIG = "backups";
+const PWP_CONFIG = "pwpolicy";
+const LOCAL_PWP_CONFIG = "localpwpolicy";
 const treeViewContainerStyles = {
     width: '295px',
 };
@@ -36,7 +39,7 @@ export class Database extends React.Component {
     constructor(props) {
         super(props);
         this.state = {
-            notifications: [],
+            firstLoad: true,
             errObj: {},
             nodes: [],
             node_name: "",
@@ -72,8 +75,6 @@ export class Database extends React.Component {
 
         // General
         this.selectNode = this.selectNode.bind(this);
-        this.removeNotification = this.removeNotification.bind(this);
-        this.addNotification = this.addNotification.bind(this);
         this.handleChange = this.handleChange.bind(this);
         this.handleRadioChange = this.handleRadioChange.bind(this);
         this.loadGlobalConfig = this.loadGlobalConfig.bind(this);
@@ -105,23 +106,22 @@ export class Database extends React.Component {
         this.enableTree = this.enableTree.bind(this);
     }
 
-    componentWillMount () {
-        if (!this.state.loaded) {
-            this.loadGlobalConfig();
-            this.loadChainingConfig();
-            this.loadLDIFs();
-            this.loadBackups();
-            this.loadSuffixList();
-        }
-    }
-
-    componentDidMount() {
-        this.loadSuffixTree(false);
-    }
-
     componentDidUpdate(prevProps) {
-        if (this.props.serverId !== prevProps.serverId) {
-            this.loadSuffixTree(false);
+        if (this.props.wasActiveList.includes(2)) {
+            if (this.state.firstLoad) {
+                if (!this.state.loaded) {
+                    this.loadGlobalConfig();
+                    this.loadChainingConfig();
+                    this.loadLDIFs();
+                    this.loadBackups();
+                    this.loadSuffixList();
+                }
+                this.loadSuffixTree(false);
+            } else {
+                if (this.props.serverId !== prevProps.serverId) {
+                    this.loadSuffixTree(false);
+                }
+            }
         }
     }
 
@@ -142,6 +142,9 @@ export class Database extends React.Component {
     }
 
     loadGlobalConfig () {
+        if (this.state.firstLoad) {
+            this.setState({ firstLoad: false });
+        }
         const cmd = [
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             "backend", "config", "get"
@@ -189,13 +192,12 @@ export class Database extends React.Component {
                                     importcacheauto: attrs['nsslapd-import-cache-autosize'],
                                     importcachesize: attrs['nsslapd-import-cachesize'],
                                 },
-                            loaded: true,
                             configUpdated: 1
                         }), this.setState({configUpdated: 0}));
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading database configuration - ${errMsg.desc}`
                     );
@@ -282,7 +284,7 @@ export class Database extends React.Component {
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading default chaining configuration - ${errMsg.desc}`
                     );
@@ -360,18 +362,38 @@ export class Database extends React.Component {
                             id: "backups",
                         },
                         {
-                            "text": "Suffixes",
-                            "icon": "pficon-catalog",
-                            "state": {"expanded": true},
+                            text: "Password Policies",
+                            icon: "pficon-key",
                             selectable: false,
-                            "nodes": []
+                            state: {"expanded": true},
+                            "nodes": [
+                                {
+                                    text: "Global Policy",
+                                    icon: "glyphicon glyphicon-globe",
+                                    selectable: true,
+                                    id: "pwpolicy",
+                                },
+                                {
+                                    text: "Local Policies",
+                                    icon: "pficon-home",
+                                    selectable: true,
+                                    id: "localpwpolicy",
+                                },
+                            ]
+                        },
+                        {
+                            text: "Suffixes",
+                            icon: "pficon-catalog",
+                            state: {"expanded": true},
+                            selectable: false,
+                            nodes: []
                         }
                     ];
                     let current_node = this.state.node_name;
                     if (fullReset) {
                         current_node = DB_CONFIG;
                     }
-                    basicData[3].nodes = treeData;
+                    basicData[4].nodes = treeData;
 
                     this.setState(() => ({
                         nodes: basicData,
@@ -446,7 +468,7 @@ export class Database extends React.Component {
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error getting chaining link configuration - ${errMsg.desc}`
                     );
@@ -463,6 +485,8 @@ export class Database extends React.Component {
 
         if (selectedNode.id == "dbconfig" ||
             selectedNode.id == "chaining-config" ||
+            selectedNode.id == "pwpolicy" ||
+            selectedNode.id == "localpwpolicy" ||
             selectedNode.id == "backups") {
             // Nothing special to do, these configurations have already been loaded
             this.setState(prevState => {
@@ -526,29 +550,6 @@ export class Database extends React.Component {
         });
     }
 
-    addNotification(type, message, timerdelay, persistent) {
-        this.setState(prevState => ({
-            notifications: [
-                ...prevState.notifications,
-                {
-                    key: prevState.notifications.length + 1,
-                    type: type,
-                    persistent: persistent,
-                    timerdelay: timerdelay,
-                    message: message,
-                }
-            ]
-        }));
-    }
-
-    removeNotification(notificationToRemove) {
-        this.setState({
-            notifications: this.state.notifications.filter(
-                notification => notificationToRemove.key !== notification.key
-            )
-        });
-    }
-
     update_tree_nodes() {
         // Set title to the text value of each suffix node.  We need to do this
         // so we can read long suffixes in the UI tree div
@@ -557,8 +558,8 @@ export class Database extends React.Component {
             el.setAttribute('title', el.innerText);
         }
         this.setState({
-            disableTree: false
-        });
+            disableTree: false,
+        }, this.loadAttrs());
     }
 
     showSuffixModal () {
@@ -619,7 +620,7 @@ export class Database extends React.Component {
         };
 
         if (this.state.createSuffix == "") {
-            this.addNotification(
+            this.props.addNotification(
                 "warning",
                 `Missing the suffix DN`
             );
@@ -627,7 +628,7 @@ export class Database extends React.Component {
             errors = true;
         }
         if (this.state.createBeName == "") {
-            this.addNotification(
+            this.props.addNotification(
                 "warning",
                 `Missing the suffix backend name`
             );
@@ -658,7 +659,7 @@ export class Database extends React.Component {
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
                     this.closeSuffixModal();
-                    this.addNotification(
+                    this.props.addNotification(
                         "success",
                         `Successfully create new suffix`
                     );
@@ -668,7 +669,7 @@ export class Database extends React.Component {
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error creating suffix - ${errMsg.desc}`
                     );
@@ -828,7 +829,7 @@ export class Database extends React.Component {
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading indexes for ${suffix} - ${errMsg.desc}`
                     );
@@ -983,7 +984,7 @@ export class Database extends React.Component {
                                                     })
                                                     .fail(err => {
                                                         let errMsg = JSON.parse(err);
-                                                        this.addNotification(
+                                                        this.props.addNotification(
                                                             "error",
                                                             `Error loading indexes for ${suffix} - ${errMsg.desc}`
                                                         );
@@ -994,7 +995,7 @@ export class Database extends React.Component {
                                         })
                                         .fail(err => {
                                             let errMsg = JSON.parse(err);
-                                            this.addNotification(
+                                            this.props.addNotification(
                                                 "error",
                                                 `Error attribute encryption for ${suffix} - ${errMsg.desc}`
                                             );
@@ -1005,7 +1006,7 @@ export class Database extends React.Component {
                             })
                             .fail(err => {
                                 let errMsg = JSON.parse(err);
-                                this.addNotification(
+                                this.props.addNotification(
                                     "error",
                                     `Error loading VLV indexes for ${suffix} - ${errMsg.desc}`
                                 );
@@ -1016,7 +1017,7 @@ export class Database extends React.Component {
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading config for ${suffix} - ${errMsg.desc}`
                     );
@@ -1049,7 +1050,7 @@ export class Database extends React.Component {
         const cmd = [
             "dsctl", "-j", this.props.serverId, "backups"
         ];
-        log_cmd("loadBackups", "Load Backups", cmd);
+        log_cmd("loadBackupsDatabase", "Load Backups", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
@@ -1070,22 +1071,23 @@ export class Database extends React.Component {
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
             "schema", "attributetypes", "list"
         ];
-        log_cmd("Suffixes", "Get attrs", attr_cmd);
+        log_cmd("loadAttrs", "Get attrs", attr_cmd);
         cockpit
                 .spawn(attr_cmd, { superuser: true, err: "message" })
                 .done(content => {
                     let attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent['items']) {
-                        attrs.push(content.name);
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs,
+                        loaded: true
                     });
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Failed to get attributes - ${errMsg.desc}`
                     );
@@ -1101,6 +1103,7 @@ export class Database extends React.Component {
     render() {
         const { nodes } = this.state;
         let db_element = "";
+        let body = "";
         let disabled = "tree-view-container";
         if (this.state.disableTree) {
             disabled = "tree-view-container ds-disabled";
@@ -1111,7 +1114,7 @@ export class Database extends React.Component {
                 db_element =
                     <GlobalDatabaseConfig
                         serverId={this.props.serverId}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         reload={this.loadGlobalConfig}
                         data={this.state.globalDBConfig}
                         enableTree={this.enableTree}
@@ -1121,17 +1124,33 @@ export class Database extends React.Component {
                 db_element =
                     <ChainingDatabaseConfig
                         serverId={this.props.serverId}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         reload={this.loadChainingConfig}
                         data={this.state.chainingConfig}
                         enableTree={this.enableTree}
                         key={this.state.chainingUpdated}
                     />;
+            } else if (this.state.node_name == PWP_CONFIG) {
+                db_element =
+                    <GlobalPwPolicy
+                        serverId={this.props.serverId}
+                        addNotification={this.props.addNotification}
+                        attrs={this.state.attributes}
+                        enableTree={this.enableTree}
+                    />;
+            } else if (this.state.node_name == LOCAL_PWP_CONFIG) {
+                db_element =
+                    <LocalPwPolicy
+                        serverId={this.props.serverId}
+                        addNotification={this.props.addNotification}
+                        attrs={this.state.attributes}
+                        enableTree={this.enableTree}
+                    />;
             } else if (this.state.node_name == BACKUP_CONFIG) {
                 db_element =
                     <Backups
                         serverId={this.props.serverId}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         backups={this.state.BackupRows}
                         suffixes={this.state.suffixList}
                         ldifs={this.state.LDIFRows}
@@ -1159,7 +1178,7 @@ export class Database extends React.Component {
                                 reloadIndexes={this.loadIndexes}
                                 reloadVLV={this.loadVLV}
                                 reloadAttrEnc={this.loadAttrEncrypt}
-                                addNotification={this.addNotification}
+                                addNotification={this.props.addNotification}
                                 reloadLDIFs={this.loadLDIFs}
                                 LDIFRows={this.state.LDIFRows}
                                 dbtype={this.state.dbtype}
@@ -1184,7 +1203,7 @@ export class Database extends React.Component {
                                 suffix={this.state.node_text}
                                 bename={this.state.bename}
                                 loadSuffixTree={this.loadSuffixTree}
-                                addNotification={this.addNotification}
+                                addNotification={this.props.addNotification}
                                 data={this.state[this.state.node_text]}
                                 enableTree={this.enableTree}
                                 reload={this.loadChainingLink}
@@ -1192,14 +1211,7 @@ export class Database extends React.Component {
                     }
                 }
             }
-        }
-
-        return (
-            <div className="container-fluid">
-                <NotificationController
-                    notifications={this.state.notifications}
-                    removeNotificationAction={this.removeNotification}
-                />
+            body =
                 <div className="ds-container">
                     <div>
                         <div className="ds-tree">
@@ -1221,7 +1233,18 @@ export class Database extends React.Component {
                     <div className="ds-tree-content">
                         {db_element}
                     </div>
-                </div>
+                </div>;
+        } else {
+            body =
+                <div className="ds-loading-spinner ds-margin-top ds-center">
+                    <h4>Loading database configuration ...</h4>
+                    <Spinner className="ds-margin-top" loading size="md" />
+                </div>;
+        }
+
+        return (
+            <div className="container-fluid">
+                {body}
                 <CreateSuffixModal
                     showModal={this.state.showSuffixModal}
                     closeHandler={this.closeSuffixModal}
@@ -1330,10 +1353,12 @@ class CreateSuffixModal extends React.Component {
 // Property types and defaults
 
 Database.propTypes = {
+    addNotification: PropTypes.func,
     serverId: PropTypes.string
 };
 
 Database.defaultProps = {
+    addNotification: noop,
     serverId: ""
 };
 
