@@ -16,6 +16,7 @@ import {
 } from "patternfly-react";
 import { Typeahead } from "react-bootstrap-typeahead";
 import { AttrUniqConfigTable } from "./pluginTables.jsx";
+import { DoubleConfirmModal } from "../notifications.jsx";
 import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import PropTypes from "prop-types";
 import { log_cmd } from "../tools.jsx";
@@ -23,15 +24,22 @@ import "../../css/ds.css";
 
 class AttributeUniqueness extends React.Component {
     componentWillMount() {
-        this.loadConfigs();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.loadConfigs();
+            }
+        }
     }
 
     constructor(props) {
         super(props);
         this.state = {
+            firstLoad: true,
             configRows: [],
             attributes: [],
             objectClasses: [],
+            modalChecked: false,
+            modalSpinning: false,
 
             configName: "",
             configEnabled: false,
@@ -43,12 +51,13 @@ class AttributeUniqueness extends React.Component {
 
             newEntry: false,
             showConfigModal: false,
-            showConfirmDeleteConfig: false
+            showConfirmDelete: false
         };
 
         this.handleSwitchChange = this.handleSwitchChange.bind(this);
         this.handleCheckboxChange = this.handleCheckboxChange.bind(this);
         this.handleFieldChange = this.handleFieldChange.bind(this);
+        this.handleTypeaheadChange = this.handleTypeaheadChange.bind(this);
         this.loadConfigs = this.loadConfigs.bind(this);
         this.showEditConfigModal = this.showEditConfigModal.bind(this);
         this.showAddConfigModal = this.showAddConfigModal.bind(this);
@@ -57,6 +66,8 @@ class AttributeUniqueness extends React.Component {
         this.closeModal = this.closeModal.bind(this);
         this.openModal = this.openModal.bind(this);
         this.cmdOperation = this.cmdOperation.bind(this);
+        this.closeConfirmDelete = this.closeConfirmDelete.bind(this);
+        this.showConfirmDelete = this.showConfirmDelete.bind(this);
         this.deleteConfig = this.deleteConfig.bind(this);
         this.addConfig = this.addConfig.bind(this);
         this.editConfig = this.editConfig.bind(this);
@@ -80,7 +91,22 @@ class AttributeUniqueness extends React.Component {
         });
     }
 
+    handleTypeaheadChange(values) {
+        // When typaheads allow new values, an object is returned
+        // instead of string.  Grab the "label" in this case
+        let new_values = [];
+        for (let val of values) {
+            new_values.push(val.label);
+        }
+        this.setState({
+            subtrees: new_values
+        });
+    }
+
     loadConfigs() {
+        this.setState({
+            firstLoad: false
+        });
         // Get all the attributes and matching rules now
         const cmd = [
             "dsconf",
@@ -90,23 +116,20 @@ class AttributeUniqueness extends React.Component {
             "attr-uniq",
             "list"
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadConfigs", "Get Attribute Uniqueness Plugin configs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
                     let myObject = JSON.parse(content);
                     this.setState({
-                        configRows: myObject.items.map(item => JSON.parse(item).attrs)
+                        configRows: myObject.items.map(item => item.attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     if (err != 0) {
                         let errMsg = JSON.parse(err);
                         console.log("loadConfigs failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -145,7 +168,6 @@ class AttributeUniqueness extends React.Component {
                 name
             ];
 
-            this.props.toggleLoadingHandler();
             log_cmd("openModal", "Fetch the Attribute Uniqueness Plugin config entry", cmd);
             cockpit
                     .spawn(cmd, {
@@ -169,31 +191,18 @@ class AttributeUniqueness extends React.Component {
                             topEntryOc:
                             configEntry["uniqueness-top-entry-oc"] === undefined
                                 ? []
-                                : [
-                                    {
-                                        id: configEntry["uniqueness-top-entry-oc"][0],
-                                        label: configEntry["uniqueness-top-entry-oc"][0]
-                                    }
-                                ],
+                                : [configEntry["uniqueness-top-entry-oc"][0]],
                             subtreeEnriesOc:
                             configEntry["uniqueness-subtree-entries-oc"] === undefined
                                 ? []
-                                : [
-                                    {
-                                        id: configEntry["uniqueness-subtree-entries-oc"][0],
-                                        label: configEntry["uniqueness-subtree-entries-oc"][0]
-                                    }
-                                ]
+                                : [configEntry["uniqueness-subtree-entries-oc"][0]]
                         });
 
                         if (configEntry["uniqueness-attribute-name"] === undefined) {
                             this.setState({ attrNames: [] });
                         } else {
                             for (let value of configEntry["uniqueness-attribute-name"]) {
-                                configAttrNamesList = [
-                                    ...configAttrNamesList,
-                                    { id: value, label: value }
-                                ];
+                                configAttrNamesList = [...configAttrNamesList, value];
                             }
                             this.setState({ attrNames: configAttrNamesList });
                         }
@@ -201,14 +210,10 @@ class AttributeUniqueness extends React.Component {
                             this.setState({ subtrees: [] });
                         } else {
                             for (let value of configEntry["uniqueness-subtrees"]) {
-                                configSubtreesList = [
-                                    ...configSubtreesList,
-                                    { id: value, label: value }
-                                ];
+                                configSubtreesList = [...configSubtreesList, value];
                             }
                             this.setState({ subtrees: configSubtreesList });
                         }
-                        this.props.toggleLoadingHandler();
                     })
                     .fail(_ => {
                         this.setState({
@@ -221,7 +226,6 @@ class AttributeUniqueness extends React.Component {
                             topEntryOc: [],
                             subtreeEnriesOc: []
                         });
-                        this.props.toggleLoadingHandler();
                     });
         }
     }
@@ -255,12 +259,21 @@ class AttributeUniqueness extends React.Component {
             acrossAllSubtrees ? "on" : "off"
         ];
 
+        if (subtrees.length == 0 && subtreeEnriesOc.length == 0) {
+            // There me a subtree or entry OC sets
+            this.props.addNotification(
+                "error",
+                `There must be at least one Subtree or Subtree Entries OC set`
+            );
+            return;
+        }
+
         // Delete attributes if the user set an empty value to the field
         if (!(action == "add" && attrNames.length == 0)) {
             cmd = [...cmd, "--attr-name"];
             if (attrNames.length != 0) {
                 for (let value of attrNames) {
-                    cmd = [...cmd, value.label];
+                    cmd = [...cmd, value];
                 }
             } else if (action == "add") {
                 cmd = [...cmd, ""];
@@ -273,7 +286,7 @@ class AttributeUniqueness extends React.Component {
             cmd = [...cmd, "--subtree"];
             if (subtrees.length != 0) {
                 for (let value of subtrees) {
-                    cmd = [...cmd, value.label];
+                    cmd = [...cmd, value];
                 }
             } else if (action == "add") {
                 cmd = [...cmd, ""];
@@ -284,7 +297,7 @@ class AttributeUniqueness extends React.Component {
 
         cmd = [...cmd, "--top-entry-oc"];
         if (topEntryOc.length != 0) {
-            cmd = [...cmd, topEntryOc[0].label];
+            cmd = [...cmd, topEntryOc[0]];
         } else if (action == "add") {
             cmd = [...cmd, ""];
         } else {
@@ -293,7 +306,7 @@ class AttributeUniqueness extends React.Component {
 
         cmd = [...cmd, "--subtree-entries-oc"];
         if (subtreeEnriesOc.length != 0) {
-            cmd = [...cmd, subtreeEnriesOc[0].label];
+            cmd = [...cmd, subtreeEnriesOc[0]];
         } else if (action == "add") {
             cmd = [...cmd, ""];
         } else {
@@ -328,13 +341,29 @@ class AttributeUniqueness extends React.Component {
                         `Error during the config entry ${action} operation - ${errMsg.desc}`
                     );
                     this.loadConfigs();
-                    this.closeModal();
                     this.props.toggleLoadingHandler();
                 });
     }
 
-    deleteConfig(rowData) {
-        let configName = rowData.cn[0];
+    showConfirmDelete (name) {
+        this.setState({
+            showConfirmDelete: true,
+            modalChecked: false,
+            modalSpinning: false,
+            deleteName: name
+        });
+    }
+
+    closeConfirmDelete () {
+        this.setState({
+            showConfirmDelete: false,
+            modalChecked: false,
+            modalSpinning: false,
+            deleteName: ""
+        });
+    }
+
+    deleteConfig() {
         let cmd = [
             "dsconf",
             "-j",
@@ -342,10 +371,13 @@ class AttributeUniqueness extends React.Component {
             "plugin",
             "attr-uniq",
             "delete",
-            configName
+            this.state.deleteName
         ];
 
-        this.props.toggleLoadingHandler();
+        this.setState({
+            modalSpinning: true
+        });
+
         log_cmd("deleteConfig", "Delete the Attribute Uniqueness Plugin config entry", cmd);
         cockpit
                 .spawn(cmd, {
@@ -356,11 +388,11 @@ class AttributeUniqueness extends React.Component {
                     console.info("deleteConfig", "Result", content);
                     this.props.addNotification(
                         "success",
-                        `Config entry ${configName} was successfully deleted`
+                        `Config entry ${this.state.deleteName} was successfully deleted`
                     );
                     this.loadConfigs();
                     this.closeModal();
-                    this.props.toggleLoadingHandler();
+                    this.closeConfirmDelete();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
@@ -369,8 +401,8 @@ class AttributeUniqueness extends React.Component {
                         `Error during the config entry removal operation - ${errMsg.desc}`
                     );
                     this.loadConfigs();
+                    this.closeConfirmDelete();
                     this.closeModal();
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -398,10 +430,7 @@ class AttributeUniqueness extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -429,10 +458,7 @@ class AttributeUniqueness extends React.Component {
                     const ocContent = JSON.parse(content);
                     let ocs = [];
                     for (let content of ocContent["items"]) {
-                        ocs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        ocs.push(content.name[0]);
                     }
                     this.setState({
                         objectClasses: ocs
@@ -481,12 +507,14 @@ class AttributeUniqueness extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup controlId="configName">
-                                            <Col sm={3}>
-                                                <ControlLabel title='Sets the name of the plug-in configuration record. (cn) You can use any string, but "attribute_name Attribute Uniqueness" is recommended.'>
-                                                    Config Name
-                                                </ControlLabel>
+                                            <Col
+                                                componentClass={ControlLabel}
+                                                sm={4}
+                                                title='Sets the name of the plug-in configuration record. (cn) You can use any string, but "attribute_name Attribute Uniqueness" is recommended.'
+                                            >
+                                                Config Name
                                             </Col>
-                                            <Col sm={9}>
+                                            <Col sm={8}>
                                                 <FormControl
                                                     type="text"
                                                     value={configName}
@@ -502,12 +530,12 @@ class AttributeUniqueness extends React.Component {
                                         >
                                             <Col
                                                 componentClass={ControlLabel}
-                                                sm={3}
+                                                sm={4}
                                                 title="Sets the name of the attribute whose values must be unique. This attribute is multi-valued. (uniqueness-attribute-name)"
                                             >
                                                 Attribute Names
                                             </Col>
-                                            <Col sm={9}>
+                                            <Col sm={8}>
                                                 <Typeahead
                                                     allowNew
                                                     multiple
@@ -530,19 +558,17 @@ class AttributeUniqueness extends React.Component {
                                         >
                                             <Col
                                                 componentClass={ControlLabel}
-                                                sm={3}
+                                                sm={4}
                                                 title="Sets the DN under which the plug-in checks for uniqueness of the attributes value. This attribute is multi-valued (uniqueness-subtrees)"
                                             >
                                                 Subtrees
                                             </Col>
-                                            <Col sm={9}>
+                                            <Col sm={8}>
                                                 <Typeahead
                                                     allowNew
                                                     multiple
                                                     onChange={values => {
-                                                        this.setState({
-                                                            subtrees: values
-                                                        });
+                                                        this.handleTypeaheadChange(values);
                                                     }}
                                                     selected={subtrees}
                                                     options={[""]}
@@ -564,12 +590,12 @@ class AttributeUniqueness extends React.Component {
                                         >
                                             <Col
                                                 componentClass={ControlLabel}
-                                                sm={3}
+                                                sm={4}
                                                 title="Verifies that the value of the attribute set in uniqueness-attribute-name is unique in this subtree (uniqueness-top-entry-oc)"
                                             >
                                                 Top Entry OC
                                             </Col>
-                                            <Col sm={9}>
+                                            <Col sm={8}>
                                                 <Typeahead
                                                     allowNew
                                                     onChange={value => {
@@ -591,12 +617,12 @@ class AttributeUniqueness extends React.Component {
                                         >
                                             <Col
                                                 componentClass={ControlLabel}
-                                                sm={3}
+                                                sm={4}
                                                 title="Verifies if an attribute is unique, if the entry contains the object class set in this parameter (uniqueness-subtree-entries-oc)"
                                             >
                                                 Subtree Entries OC
                                             </Col>
-                                            <Col sm={6}>
+                                            <Col sm={5}>
                                                 <Typeahead
                                                     allowNew
                                                     onChange={value => {
@@ -628,7 +654,7 @@ class AttributeUniqueness extends React.Component {
                                         >
                                             <Col
                                                 componentClass={ControlLabel}
-                                                sm={3}
+                                                sm={4}
                                                 title="Identifies whether or not the config is enabled."
                                             >
                                                 Enable config
@@ -684,7 +710,7 @@ class AttributeUniqueness extends React.Component {
                             <AttrUniqConfigTable
                                 rows={this.state.configRows}
                                 editConfig={this.showEditConfigModal}
-                                deleteConfig={this.deleteConfig}
+                                deleteConfig={this.showConfirmDelete}
                             />
                             <Button
                                 className="ds-margin-top"
@@ -696,6 +722,19 @@ class AttributeUniqueness extends React.Component {
                         </Col>
                     </Row>
                 </PluginBasicConfig>
+                <DoubleConfirmModal
+                    showModal={this.state.showConfirmDelete}
+                    closeHandler={this.closeConfirmDelete}
+                    handleChange={this.handleCheckboxChange}
+                    actionHandler={this.deleteConfig}
+                    spinning={this.state.modalSpinning}
+                    item={this.state.deleteName}
+                    checked={this.state.modalChecked}
+                    mTitle="Delete Attribute Uniqueness Configuration"
+                    mMsg="Are you sure you want to delete this configuration?"
+                    mSpinningMsg="Deleting attribute uniqueness configuration..."
+                    mBtnName="Delete Configuration"
+                />
             </div>
         );
     }
