@@ -21,12 +21,17 @@ import "../../css/ds.css";
 
 class AutoMembership extends React.Component {
     componentWillMount() {
-        this.loadDefinitions();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.loadDefinitions();
+            }
+        }
     }
 
     constructor(props) {
         super(props);
         this.state = {
+            firstLoad: true,
             definitionRows: [],
             regexRows: [],
             regexesToDelete: [],
@@ -82,6 +87,9 @@ class AutoMembership extends React.Component {
     }
 
     loadDefinitions() {
+        this.setState({
+            firstLoad: false
+        });
         const cmd = [
             "dsconf",
             "-j",
@@ -91,7 +99,6 @@ class AutoMembership extends React.Component {
             "list",
             "definitions"
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadDefinitions", "Get Auto Membership Plugin definitions", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -100,14 +107,12 @@ class AutoMembership extends React.Component {
                     this.setState({
                         definitionRows: myObject.items.map(item => JSON.parse(item).attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
                     if (err != 0) {
                         console.log("loadDefinitions failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -213,12 +218,7 @@ class AutoMembership extends React.Component {
                         } else {
                             let groupingAttr = definitionEntry["automembergroupingattr"][0];
                             this.setState({
-                                groupingAttrMember: [
-                                    {
-                                        id: groupingAttr.split(":")[0],
-                                        label: groupingAttr.split(":")[0]
-                                    }
-                                ],
+                                groupingAttrMember: [groupingAttr.split(":")[0]],
                                 groupingAttrEntry: groupingAttr.split(":")[1]
                             });
                         }
@@ -546,7 +546,7 @@ class AutoMembership extends React.Component {
                 this.setState({ regexExclusive: [] });
             } else {
                 for (let value of regexEntry["automemberexclusiveregex"]) {
-                    exclusiveRegexList = [...exclusiveRegexList, { id: value, label: value }];
+                    exclusiveRegexList = [...exclusiveRegexList, value];
                 }
                 this.setState({ regexExclusive: exclusiveRegexList });
             }
@@ -554,7 +554,7 @@ class AutoMembership extends React.Component {
                 this.setState({ regexInclusive: [] });
             } else {
                 for (let value of regexEntry["automemberinclusiveregex"]) {
-                    inclusiveRegexList = [...inclusiveRegexList, { id: value, label: value }];
+                    inclusiveRegexList = [...inclusiveRegexList, value];
                 }
                 this.setState({ regexInclusive: inclusiveRegexList });
             }
@@ -606,11 +606,11 @@ class AutoMembership extends React.Component {
                                 automembertargetgroup: [regexTargetGroup],
                                 automemberexclusiveregex:
                                     regexExclusive.length !== 0
-                                        ? regexExclusive.map(regex => regex.label)
+                                        ? regexExclusive.map(regex => regex)
                                         : [],
                                 automemberinclusiveregex:
                                     regexInclusive.length !== 0
-                                        ? regexInclusive.map(regex => regex.label)
+                                        ? regexInclusive.map(regex => regex)
                                         : [],
                                 needsadd: true
                             }
@@ -633,11 +633,11 @@ class AutoMembership extends React.Component {
                                 automembertargetgroup: [regexTargetGroup],
                                 automemberexclusiveregex:
                                     regexExclusive.length !== 0
-                                        ? regexExclusive.map(regex => regex.label)
+                                        ? regexExclusive.map(regex => regex)
                                         : [],
                                 automemberinclusiveregex:
                                     regexInclusive.length !== 0
-                                        ? regexInclusive.map(regex => regex.label)
+                                        ? regexInclusive.map(regex => regex)
                                         : [],
                                 needsupdate: true
                             }
@@ -697,10 +697,7 @@ class AutoMembership extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -771,8 +768,8 @@ class AutoMembership extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup key="definitionName" controlId="definitionName">
-                                            <Col sm={3}>
-                                                <ControlLabel>Definition Name</ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3}>
+                                                Definition Name
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
@@ -787,10 +784,8 @@ class AutoMembership extends React.Component {
                                         {Object.entries(modalDefinitionFields).map(
                                             ([id, content]) => (
                                                 <FormGroup key={id} controlId={id}>
-                                                    <Col sm={3}>
-                                                        <ControlLabel title={content.help}>
-                                                            {content.name}
-                                                        </ControlLabel>
+                                                    <Col componentClass={ControlLabel} sm={3} title={content.help}>
+                                                        {content.name}
                                                     </Col>
                                                     <Col sm={9}>
                                                         <FormControl
@@ -806,12 +801,8 @@ class AutoMembership extends React.Component {
                                             key="groupingAttrEntry"
                                             controlId="groupingAttrEntry"
                                         >
-                                            <Col sm={3}>
-                                                <ControlLabel
-                                                    title={`Specifies the name of the member attribute in the group entry and the attribute in the object entry that supplies the member attribute value, in the format group_member_attr:entry_attr (autoMemberGroupingAttr)`}
-                                                >
-                                                    Grouping Attributes
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Specifies the name of the member attribute in the group entry and the attribute in the object entry that supplies the member attribute value, in the format group_member_attr:entry_attr (autoMemberGroupingAttr)">
+                                                Grouping Attributes
                                             </Col>
                                             <Col sm={4}>
                                                 <Typeahead
@@ -840,6 +831,7 @@ class AutoMembership extends React.Component {
                                     </Form>
                                 </Col>
                             </Row>
+                            <hr />
                             <Row>
                                 <Col sm={12}>
                                     <AutoMembershipRegexTable
@@ -898,8 +890,8 @@ class AutoMembership extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup key="regexName" controlId="regexName">
-                                            <Col sm={3}>
-                                                <ControlLabel>Regex Name</ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3}>
+                                                Regex Name
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
@@ -912,12 +904,8 @@ class AutoMembership extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup key="regexExclusive" controlId="regexExclusive">
-                                            <Col sm={3}>
-                                                <ControlLabel
-                                                    title={`Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)`}
-                                                >
-                                                    Exclusive Regex
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)">
+                                                Exclusive Regex
                                             </Col>
                                             <Col sm={9}>
                                                 <Typeahead
@@ -936,12 +924,8 @@ class AutoMembership extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup key="regexInclusive" controlId="regexInclusive">
-                                            <Col sm={3}>
-                                                <ControlLabel
-                                                    title={`Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)`}
-                                                >
-                                                    Inclusive Regex
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Sets a single regular expression to use to identify entries to exclude (autoMemberExclusiveRegex)">
+                                                Inclusive Regex
                                             </Col>
                                             <Col sm={9}>
                                                 <Typeahead
@@ -963,12 +947,8 @@ class AutoMembership extends React.Component {
                                             key="regexTargetGroup"
                                             controlId="regexTargetGroup"
                                         >
-                                            <Col sm={3}>
-                                                <ControlLabel
-                                                    title={`Sets which group to add the entry to as a member, if it meets the regular expression conditions (autoMemberTargetGroup)`}
-                                                >
-                                                    Target Group
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Sets which group to add the entry to as a member, if it meets the regular expression conditions (autoMemberTargetGroup)">
+                                                Target Group
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
