@@ -22,12 +22,17 @@ import "../../css/ds.css";
 
 class DNA extends React.Component {
     componentWillMount() {
-        this.loadConfigs();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.loadConfigs();
+            }
+        }
     }
 
     constructor(props) {
         super(props);
         this.state = {
+            firstLoad: true,
             configRows: [],
             sharedConfigRows: [],
             attributes: [],
@@ -121,6 +126,9 @@ class DNA extends React.Component {
     }
 
     loadConfigs() {
+        this.setState({
+            firstLoad: false
+        });
         const cmd = [
             "dsconf",
             "-j",
@@ -130,7 +138,6 @@ class DNA extends React.Component {
             "list",
             "configs"
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadConfigs", "Get DNA Plugin configs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -139,14 +146,12 @@ class DNA extends React.Component {
                     this.setState({
                         configRows: myObject.items.map(item => JSON.parse(item).attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
                     if (err != 0) {
                         console.log("loadConfigs failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -161,7 +166,6 @@ class DNA extends React.Component {
             "shared-configs",
             basedn
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadSharedConfigs", "Get DNA Plugin shared configs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -170,14 +174,12 @@ class DNA extends React.Component {
                     this.setState({
                         sharedConfigRows: myObject.items.map(item => JSON.parse(item).attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
                     if (err != 0) {
                         console.log("loadSharedConfigs failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -292,7 +294,7 @@ class DNA extends React.Component {
                             this.setState({ type: [] });
                         } else {
                             for (let value of configEntry["dnatype"]) {
-                                dnaTypeList = [...dnaTypeList, { id: value, label: value }];
+                                dnaTypeList = [...dnaTypeList, value];
                             }
                             this.setState({ type: dnaTypeList });
                         }
@@ -401,7 +403,7 @@ class DNA extends React.Component {
             cmd = [...cmd, "--type"];
             if (type.length != 0) {
                 for (let value of type) {
-                    cmd = [...cmd, value.label];
+                    cmd = [...cmd, value];
                 }
             } else if (action == "add") {
                 cmd = [...cmd, ""];
@@ -726,10 +728,7 @@ class DNA extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -875,8 +874,8 @@ class DNA extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup key="configName" controlId="configName">
-                                            <Col sm={4}>
-                                                <ControlLabel>Config Name</ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={4}>
+                                                Config Name
                                             </Col>
                                             <Col sm={8}>
                                                 <FormControl
@@ -916,10 +915,8 @@ class DNA extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup key="type" controlId="type">
-                                            <Col sm={4}>
-                                                <ControlLabel title="Sets which attributes have unique numbers being generated for them (dnaType)">
-                                                    Type
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={4} title="Sets which attributes have unique numbers being generated for them (dnaType)">
+                                                Type
                                             </Col>
                                             <Col sm={8}>
                                                 <Typeahead
@@ -939,10 +936,8 @@ class DNA extends React.Component {
                                         </FormGroup>
                                         {Object.entries(modalConfigFields).map(([id, content]) => (
                                             <FormGroup key={id} controlId={id}>
-                                                <Col sm={4}>
-                                                    <ControlLabel title={content.help}>
-                                                        {content.name}
-                                                    </ControlLabel>
+                                                <Col componentClass={ControlLabel} sm={4} title={content.help}>
+                                                    {content.name}
                                                 </Col>
                                                 <Col sm={8}>
                                                     <FormControl
