@@ -21,12 +21,17 @@ import "../../css/ds.css";
 
 class LinkedAttributes extends React.Component {
     componentWillMount() {
-        this.loadConfigs();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.loadConfigs();
+            }
+        }
     }
 
     constructor(props) {
         super(props);
         this.state = {
+            firstLoad: true,
             configRows: [],
             attributes: [],
 
@@ -60,6 +65,9 @@ class LinkedAttributes extends React.Component {
     }
 
     loadConfigs() {
+        this.setState({
+            firstLoad: false
+        });
         // Get all the attributes and matching rules now
         const cmd = [
             "dsconf",
@@ -69,7 +77,6 @@ class LinkedAttributes extends React.Component {
             "linked-attr",
             "list"
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadConfigs", "Get Linked Attributes Plugin configs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -78,14 +85,12 @@ class LinkedAttributes extends React.Component {
                     this.setState({
                         configRows: myObject.items.map(item => JSON.parse(item).attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
                     if (err != 0) {
                         console.log("loadConfigs failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -136,21 +141,11 @@ class LinkedAttributes extends React.Component {
                             linkType:
                             configEntry["linktype"] === undefined
                                 ? []
-                                : [
-                                    {
-                                        id: configEntry["linktype"][0],
-                                        label: configEntry["linktype"][0]
-                                    }
-                                ],
+                                : [configEntry["linktype"][0]],
                             managedType:
                             configEntry["managedtype"] === undefined
                                 ? []
-                                : [
-                                    {
-                                        id: configEntry["managedtype"][0],
-                                        label: configEntry["managedtype"][0]
-                                    }
-                                ],
+                                : [configEntry["managedtype"][0]],
                             linkScope:
                             configEntry["linkscope"] === undefined
                                 ? ""
@@ -195,7 +190,7 @@ class LinkedAttributes extends React.Component {
 
         cmd = [...cmd, "--link-type"];
         if (linkType.length != 0) {
-            cmd = [...cmd, linkType[0].label];
+            cmd = [...cmd, linkType[0]];
         } else if (action == "add") {
             cmd = [...cmd, ""];
         } else {
@@ -204,7 +199,7 @@ class LinkedAttributes extends React.Component {
 
         cmd = [...cmd, "--managed-type"];
         if (managedType.length != 0) {
-            cmd = [...cmd, managedType[0].label];
+            cmd = [...cmd, managedType[0]];
         } else if (action == "add") {
             cmd = [...cmd, ""];
         } else {
@@ -310,10 +305,7 @@ class LinkedAttributes extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -358,10 +350,8 @@ class LinkedAttributes extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup controlId="configName">
-                                            <Col sm={3}>
-                                                <ControlLabel title="The Linked Attributes configuration name">
-                                                    Config Name
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="The Linked Attributes configuration name">
+                                                Config Name
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
@@ -373,10 +363,8 @@ class LinkedAttributes extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup controlId="linkType">
-                                            <Col sm={3}>
-                                                <ControlLabel title="Sets the attribute that is managed manually by administrators (linkType)">
-                                                    Link Type
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Sets the attribute that is managed manually by administrators (linkType)">
+                                                Link Type
                                             </Col>
                                             <Col sm={9}>
                                                 <Typeahead
@@ -394,10 +382,8 @@ class LinkedAttributes extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup controlId="managedType">
-                                            <Col sm={3}>
-                                                <ControlLabel title="Sets the attribute that is created dynamically by the plugin (managedType)">
-                                                    Managed Type
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Sets the attribute that is created dynamically by the plugin (managedType)">
+                                                Managed Type
                                             </Col>
                                             <Col sm={9}>
                                                 <Typeahead
@@ -415,10 +401,8 @@ class LinkedAttributes extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup controlId="linkScope">
-                                            <Col sm={3}>
-                                                <ControlLabel title="Sets the base DN that restricts the plugin to a specific part of the directory tree (linkScope)">
-                                                    Link Scope
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Sets the base DN that restricts the plugin to a specific part of the directory tree (linkScope)">
+                                                Link Scope
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
