@@ -93,7 +93,6 @@ class ManagedEntries extends React.Component {
             "list",
             "configs"
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadConfigs", "Get Managed Entries Plugin configs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -102,14 +101,12 @@ class ManagedEntries extends React.Component {
                     this.setState({
                         configRows: myObject.items.map(item => JSON.parse(item).attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
                     if (err != 0) {
                         console.log("loadConfigs failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -351,19 +348,13 @@ class ManagedEntries extends React.Component {
                             configEntry["meprdnattr"] === undefined
                                 ? []
                                 : [
-                                    {
-                                        id: configEntry["meprdnattr"][0],
-                                        label: configEntry["meprdnattr"][0]
-                                    }
+                                    configEntry["meprdnattr"][0]
                                 ],
                             templateStaticAttr:
                             configEntry["mepstaticattr"] === undefined
                                 ? []
                                 : [
-                                    {
-                                        id: configEntry["mepstaticattr"][0],
-                                        label: configEntry["mepstaticattr"][0]
-                                    }
+                                    configEntry["mepstaticattr"][0]
                                 ]
                         });
                         if (configEntry["mepmappedattr"] === undefined) {
@@ -372,7 +363,7 @@ class ManagedEntries extends React.Component {
                             for (let value of configEntry["mepmappedattr"]) {
                                 templateMappedAttrObjectList = [
                                     ...templateMappedAttrObjectList,
-                                    { id: value, label: value }
+                                    value
                                 ];
                             }
                             this.setState({
@@ -415,7 +406,7 @@ class ManagedEntries extends React.Component {
 
         cmd = [...cmd, "--rdn-attr"];
         if (templateRDNAttr.length != 0) {
-            cmd = [...cmd, templateRDNAttr[0].label];
+            cmd = [...cmd, templateRDNAttr[0]];
         } else if (action == "add") {
             cmd = [...cmd, ""];
         } else {
@@ -424,7 +415,7 @@ class ManagedEntries extends React.Component {
 
         cmd = [...cmd, "--static-attr"];
         if (templateStaticAttr.length != 0) {
-            cmd = [...cmd, templateStaticAttr[0].label];
+            cmd = [...cmd, templateStaticAttr[0]];
         } else if (action == "add") {
             cmd = [...cmd, ""];
         } else {
@@ -434,7 +425,7 @@ class ManagedEntries extends React.Component {
         cmd = [...cmd, "--mapped-attr"];
         if (templateMappedAttr.length != 0) {
             for (let value of templateMappedAttr) {
-                cmd = [...cmd, value.label];
+                cmd = [...cmd, value];
             }
         } else {
             cmd = [...cmd, "delete"];
@@ -536,10 +527,7 @@ class ManagedEntries extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -623,8 +611,8 @@ class ManagedEntries extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup key="configName" controlId="configName">
-                                            <Col sm={3}>
-                                                <ControlLabel>Config Name</ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3}>
+                                                Config Name
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
@@ -638,10 +626,8 @@ class ManagedEntries extends React.Component {
                                         </FormGroup>
                                         {Object.entries(modalConfigFields).map(([id, content]) => (
                                             <FormGroup key={id} controlId={id}>
-                                                <Col sm={3}>
-                                                    <ControlLabel title={content.help}>
-                                                        {content.name}
-                                                    </ControlLabel>
+                                                <Col componentClass={ControlLabel} sm={3} title={content.help}>
+                                                    {content.name}
                                                 </Col>
                                                 <Col sm={9}>
                                                     <FormControl
@@ -718,10 +704,8 @@ class ManagedEntries extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup controlId="templateDN">
-                                            <Col sm={4}>
-                                                <ControlLabel title="DN of the template entry">
-                                                    Template DN
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={4} title="DN of the template entry">
+                                                Template DN
                                             </Col>
                                             <Col sm={8}>
                                                 <FormControl
@@ -770,10 +754,8 @@ class ManagedEntries extends React.Component {
                                             controlId="templateStaticAttr"
                                             disabled={false}
                                         >
-                                            <Col sm={4}>
-                                                <ControlLabel title="Sets an attribute with a defined value that must be added to the automatically-generated entry (mepStaticAttr)">
-                                                    Static Attribute
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={4} title="Sets an attribute with a defined value that must be added to the automatically-generated entry (mepStaticAttr)">
+                                                Static Attribute
                                             </Col>
                                             <Col sm={8}>
                                                 <Typeahead
@@ -795,10 +777,8 @@ class ManagedEntries extends React.Component {
                                             controlId="templateMappedAttr"
                                             disabled={false}
                                         >
-                                            <Col sm={4}>
-                                                <ControlLabel title="Sets attributes in the Managed Entries template entry which must exist in the generated entry (mepMappedAttr)">
-                                                    Mapped Attributes
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={4} title="Sets attributes in the Managed Entries template entry which must exist in the generated entry (mepMappedAttr)">
+                                                Mapped Attributes
                                             </Col>
                                             <Col sm={8}>
                                                 <Typeahead
