@@ -21,9 +21,13 @@ import "../../css/ds.css";
 
 class MemberOf extends React.Component {
     componentWillMount(prevProps) {
-        this.getObjectClasses();
-        this.getAttributes();
-        this.updateFields();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.getObjectClasses();
+                this.getAttributes();
+                this.updateFields();
+            }
+        }
     }
 
     componentDidUpdate(prevProps) {
@@ -50,6 +54,7 @@ class MemberOf extends React.Component {
         this.toggleFixupModal = this.toggleFixupModal.bind(this);
 
         this.state = {
+            firstLoad: true,
             objectClasses: [],
             attributeTypes: [],
 
@@ -182,12 +187,7 @@ class MemberOf extends React.Component {
                             configAutoAddOC:
                             configEntry["memberofautoaddoc"] === undefined
                                 ? []
-                                : [
-                                    {
-                                        id: configEntry["memberofautoaddoc"][0],
-                                        label: configEntry["memberofautoaddoc"][0]
-                                    }
-                                ],
+                                : [configEntry["memberofautoaddoc"][0]],
                             configAllBackends: !(
                                 configEntry["memberofallbackends"] === undefined ||
                             configEntry["memberofallbackends"][0] == "off"
@@ -213,10 +213,7 @@ class MemberOf extends React.Component {
                             this.setState({ configAttr: [] });
                         } else {
                             for (let value of configEntry["memberofattr"]) {
-                                configAttrObjectList = [
-                                    ...configAttrObjectList,
-                                    { id: value, label: value }
-                                ];
+                                configAttrObjectList = [...configAttrObjectList, value];
                             }
                             this.setState({ configAttr: configAttrObjectList });
                         }
@@ -224,10 +221,7 @@ class MemberOf extends React.Component {
                             this.setState({ configGroupAttr: [] });
                         } else {
                             for (let value of configEntry["memberofgroupattr"]) {
-                                configGroupAttrObjectList = [
-                                    ...configGroupAttrObjectList,
-                                    { id: value, label: value }
-                                ];
+                                configGroupAttrObjectList = [...configGroupAttrObjectList, value];
                             }
                             this.setState({
                                 configGroupAttr: configGroupAttrObjectList
@@ -298,7 +292,7 @@ class MemberOf extends React.Component {
 
             cmd = [...cmd, "--autoaddoc"];
             if (configAutoAddOC.length != 0) {
-                cmd = [...cmd, configAutoAddOC[0].label];
+                cmd = [...cmd, configAutoAddOC[0]];
             } else if (action == "add") {
                 cmd = [...cmd, ""];
             } else {
@@ -309,13 +303,13 @@ class MemberOf extends React.Component {
             cmd = [...cmd, "--attr"];
             if (configAttr.length != 0) {
                 for (let value of configAttr) {
-                    cmd = [...cmd, value.label];
+                    cmd = [...cmd, value];
                 }
             }
             cmd = [...cmd, "--groupattr"];
             if (configGroupAttr.length != 0) {
                 for (let value of configGroupAttr) {
-                    cmd = [...cmd, value.label];
+                    cmd = [...cmd, value];
                 }
             }
 
@@ -421,12 +415,7 @@ class MemberOf extends React.Component {
                 memberOfAutoAddOC:
                     pluginRow["memberofautoaddoc"] === undefined
                         ? []
-                        : [
-                            {
-                                id: pluginRow["memberofautoaddoc"][0],
-                                label: pluginRow["memberofautoaddoc"][0]
-                            }
-                        ],
+                        : [pluginRow["memberofautoaddoc"][0]],
                 memberOfAllBackends: !(
                     pluginRow["memberofallbackends"] === undefined ||
                     pluginRow["memberofallbackends"][0] == "off"
@@ -452,10 +441,7 @@ class MemberOf extends React.Component {
                 this.setState({ memberOfAttr: [] });
             } else {
                 for (let value of pluginRow["memberofattr"]) {
-                    memberOfAttrObjectList = [
-                        ...memberOfAttrObjectList,
-                        { id: value, label: value }
-                    ];
+                    memberOfAttrObjectList = [...memberOfAttrObjectList, value];
                 }
                 this.setState({ memberOfAttr: memberOfAttrObjectList });
             }
@@ -463,10 +449,7 @@ class MemberOf extends React.Component {
                 this.setState({ memberOfGroupAttr: [] });
             } else {
                 for (let value of pluginRow["memberofgroupattr"]) {
-                    memberOfGroupAttrObjectList = [
-                        ...memberOfGroupAttrObjectList,
-                        { id: value, label: value }
-                    ];
+                    memberOfGroupAttrObjectList = [...memberOfGroupAttrObjectList, value];
                 }
                 this.setState({
                     memberOfGroupAttr: memberOfGroupAttrObjectList
@@ -476,6 +459,9 @@ class MemberOf extends React.Component {
     }
 
     getObjectClasses() {
+        this.setState({
+            firstLoad: false
+        });
         const oc_cmd = [
             "dsconf",
             "-j",
@@ -491,10 +477,7 @@ class MemberOf extends React.Component {
                     const ocContent = JSON.parse(content);
                     let ocs = [];
                     for (let content of ocContent["items"]) {
-                        ocs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        ocs.push(content.name[0]);
                     }
                     this.setState({
                         objectClasses: ocs
@@ -522,10 +505,7 @@ class MemberOf extends React.Component {
                     const atContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of atContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributeTypes: attrs
@@ -585,7 +565,7 @@ class MemberOf extends React.Component {
 
         specificPluginCMD = [...specificPluginCMD, "--autoaddoc"];
         if (memberOfAutoAddOC.length != 0) {
-            specificPluginCMD = [...specificPluginCMD, memberOfAutoAddOC[0].label];
+            specificPluginCMD = [...specificPluginCMD, memberOfAutoAddOC[0]];
         } else {
             specificPluginCMD = [...specificPluginCMD, "delete"];
         }
@@ -594,7 +574,7 @@ class MemberOf extends React.Component {
         specificPluginCMD = [...specificPluginCMD, "--attr"];
         if (memberOfAttr.length != 0) {
             for (let value of memberOfAttr) {
-                specificPluginCMD = [...specificPluginCMD, value.label];
+                specificPluginCMD = [...specificPluginCMD, value];
             }
         } else {
             specificPluginCMD = [...specificPluginCMD, "delete"];
@@ -603,7 +583,7 @@ class MemberOf extends React.Component {
         specificPluginCMD = [...specificPluginCMD, "--groupattr"];
         if (memberOfGroupAttr.length != 0) {
             for (let value of memberOfGroupAttr) {
-                specificPluginCMD = [...specificPluginCMD, value.label];
+                specificPluginCMD = [...specificPluginCMD, value];
             }
         } else {
             specificPluginCMD = [...specificPluginCMD, "delete"];
@@ -729,12 +709,7 @@ class MemberOf extends React.Component {
                                                     }}
                                                     selected={configAttr}
                                                     newSelectionPrefix="Add a member: "
-                                                    options={[
-                                                        {
-                                                            id: "memberOf",
-                                                            label: "memberOf"
-                                                        }
-                                                    ]}
+                                                    options={["memberOf"]}
                                                     placeholder="Type a member attribute..."
                                                 />
                                             </Col>
@@ -840,10 +815,8 @@ class MemberOf extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup controlId="configAutoAddOC" disabled={false}>
-                                            <Col sm={3}>
-                                                <ControlLabel title="If an entry does not have an object class that allows the memberOf attribute then the memberOf plugin will automatically add the object class listed in the memberOfAutoAddOC parameter">
-                                                    Auto Add OC
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="If an entry does not have an object class that allows the memberOf attribute then the memberOf plugin will automatically add the object class listed in the memberOfAutoAddOC parameter">
+                                                Auto Add OC
                                             </Col>
                                             <Col sm={9}>
                                                 <Typeahead
@@ -927,18 +900,9 @@ class MemberOf extends React.Component {
                                             selected={memberOfAttr}
                                             newSelectionPrefix="Add a member attrbiute: "
                                             options={[
-                                                {
-                                                    id: "member",
-                                                    label: "member"
-                                                },
-                                                {
-                                                    id: "memberCertificate",
-                                                    label: "memberCertificate"
-                                                },
-                                                {
-                                                    id: "uniqueMember",
-                                                    label: "uniqueMember"
-                                                }
+                                                "member",
+                                                "memberCertificate",
+                                                "uniqueMember"
                                             ]}
                                             placeholder="Type a member attribute..."
                                         />
@@ -1063,10 +1027,7 @@ class MemberOf extends React.Component {
                                         />
                                     </Col>
                                     <Col sm={3}>
-                                        <Button
-                                            bsStyle="primary"
-                                            onClick={this.openModal}
-                                        >
+                                        <Button bsStyle="primary" onClick={this.openModal}>
                                             Manage
                                         </Button>
                                     </Col>
@@ -1079,10 +1040,11 @@ class MemberOf extends React.Component {
                             <Form horizontal>
                                 <FormGroup controlId="memberOfAutoAddOC" disabled={false}>
                                     <Col
+                                        componentClass={ControlLabel}
                                         sm={3}
                                         title="If an entry does not have an object class that allows the memberOf attribute then the memberOf plugin will automatically add the object class listed in the memberOfAutoAddOC parameter"
                                     >
-                                        <ControlLabel>Auto Add OC</ControlLabel>
+                                        Auto Add OC
                                     </Col>
                                     <Col sm={8}>
                                         <Typeahead
@@ -1104,10 +1066,7 @@ class MemberOf extends React.Component {
                     </Row>
                     <Row>
                         <Col sm={12}>
-                            <Button
-                                bsStyle="primary"
-                                onClick={this.toggleFixupModal}
-                            >
+                            <Button bsStyle="primary" onClick={this.toggleFixupModal}>
                                 Run Fixup Task
                             </Button>
                         </Col>
