@@ -22,14 +22,19 @@ import { log_cmd } from "../tools.jsx";
 import "../../css/ds.css";
 
 class PassthroughAuthentication extends React.Component {
-    componentWillMount() {
-        this.loadPAMConfigs();
-        this.loadURLs();
+    componentDidUpdate() {
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.loadPAMConfigs();
+                this.loadURLs();
+            }
+        }
     }
 
     constructor(props) {
         super(props);
         this.state = {
+            firstLoad: true,
             pamConfigRows: [],
             urlRows: [],
             attributes: [],
@@ -101,6 +106,9 @@ class PassthroughAuthentication extends React.Component {
     }
 
     loadPAMConfigs() {
+        this.setState({
+            firstLoad: false
+        });
         const cmd = [
             "dsconf",
             "-j",
@@ -110,7 +118,6 @@ class PassthroughAuthentication extends React.Component {
             "list",
             "pam-configs"
         ];
-        this.props.toggleLoadingHandler();
         log_cmd("loadPAMConfigs", "Get PAM Passthough Authentication Plugin pamConfigs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -119,14 +126,12 @@ class PassthroughAuthentication extends React.Component {
                     this.setState({
                         pamConfigRows: myObject.items.map(item => JSON.parse(item).attrs)
                     });
-                    this.props.toggleLoadingHandler();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
                     if (err != 0) {
                         console.log("loadPAMConfigs failed", errMsg.desc);
                     }
-                    this.props.toggleLoadingHandler();
                 });
     }
 
@@ -247,10 +252,7 @@ class PassthroughAuthentication extends React.Component {
                             this.setState({ pamExcludeSuffix: [] });
                         } else {
                             for (let value of pamConfigEntry["pamexcludesuffix"]) {
-                                pamExcludeSuffixList = [
-                                    ...pamExcludeSuffixList,
-                                    { id: value, label: value }
-                                ];
+                                pamExcludeSuffixList = [...pamExcludeSuffixList, value];
                             }
                             this.setState({
                                 pamExcludeSuffix: pamExcludeSuffixList
@@ -261,10 +263,7 @@ class PassthroughAuthentication extends React.Component {
                             this.setState({ pamIncludeSuffix: [] });
                         } else {
                             for (let value of pamConfigEntry["pamincludesuffix"]) {
-                                pamIncludeSuffixList = [
-                                    ...pamIncludeSuffixList,
-                                    { id: value, label: value }
-                                ];
+                                pamIncludeSuffixList = [...pamIncludeSuffixList, value];
                             }
                             this.setState({
                                 pamIncludeSuffix: pamIncludeSuffixList
@@ -275,7 +274,7 @@ class PassthroughAuthentication extends React.Component {
                             this.setState({ pamIDAttr: [] });
                         } else {
                             for (let value of pamConfigEntry["pamidattr"]) {
-                                pamIDAttrList = [...pamIDAttrList, { id: value, label: value }];
+                                pamIDAttrList = [...pamIDAttrList, value];
                             }
                             this.setState({ pamIDAttr: pamIDAttrList });
                         }
@@ -399,7 +398,7 @@ class PassthroughAuthentication extends React.Component {
         cmd = [...cmd, "--exclude-suffix"];
         if (pamExcludeSuffix.length != 0) {
             for (let value of pamExcludeSuffix) {
-                cmd = [...cmd, value.label];
+                cmd = [...cmd, value];
             }
         } else if (action == "add") {
             cmd = [...cmd, ""];
@@ -409,7 +408,7 @@ class PassthroughAuthentication extends React.Component {
         cmd = [...cmd, "--include-suffix"];
         if (pamIncludeSuffix.length != 0) {
             for (let value of pamIncludeSuffix) {
-                cmd = [...cmd, value.label];
+                cmd = [...cmd, value];
             }
         } else if (action == "add") {
             cmd = [...cmd, ""];
@@ -419,7 +418,7 @@ class PassthroughAuthentication extends React.Component {
         cmd = [...cmd, "--id-attr"];
         if (pamIDAttr.length != 0) {
             for (let value of pamIDAttr) {
-                cmd = [...cmd, value.label];
+                cmd = [...cmd, value];
             }
         } else if (action == "add") {
             cmd = [...cmd, ""];
@@ -642,10 +641,7 @@ class PassthroughAuthentication extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -760,8 +756,8 @@ class PassthroughAuthentication extends React.Component {
                                 <Col sm={12}>
                                     <Form horizontal>
                                         <FormGroup key="pamConfigName" controlId="pamConfigName">
-                                            <Col sm={3}>
-                                                <ControlLabel>Config Name</ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3}>
+                                                Config Name
                                             </Col>
                                             <Col sm={9}>
                                                 <FormControl
@@ -834,10 +830,8 @@ class PassthroughAuthentication extends React.Component {
                                             controlId="pamIDAttr"
                                             disabled={false}
                                         >
-                                            <Col sm={3}>
-                                                <ControlLabel title="Contains the attribute name which is used to hold the PAM user ID (pamIDAttr)">
-                                                    ID Attribute
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={3} title="Contains the attribute name which is used to hold the PAM user ID (pamIDAttr)">
+                                                ID Attribute
                                             </Col>
                                             <Col sm={9}>
                                                 <Typeahead
@@ -905,10 +899,8 @@ class PassthroughAuthentication extends React.Component {
                                         {Object.entries(modalPAMConfigFields).map(
                                             ([id, content]) => (
                                                 <FormGroup key={id} controlId={id}>
-                                                    <Col sm={3}>
-                                                        <ControlLabel title={content.help}>
-                                                            {content.name}
-                                                        </ControlLabel>
+                                                    <Col componentClass={ControlLabel} sm={3} title={content.help}>
+                                                        {content.name}
                                                     </Col>
                                                     <Col sm={9}>
                                                         <FormControl
@@ -922,26 +914,30 @@ class PassthroughAuthentication extends React.Component {
                                         )}
 
                                         <FormGroup key="pamCheckboxes" controlId="pamCheckboxes">
-                                            <Col sm={4}>
-                                                <Checkbox
-                                                    id="pamFallback"
-                                                    checked={pamFallback}
-                                                    onChange={this.handleCheckboxChange}
-                                                    title={`Sets whether to fallback to regular LDAP authentication if PAM authentication fails (pamFallback)`}
-                                                >
-                                                    Fallback
-                                                </Checkbox>
-                                            </Col>
-                                            <Col sm={4}>
-                                                <Checkbox
-                                                    id="pamSecure"
-                                                    checked={pamSecure}
-                                                    onChange={this.handleCheckboxChange}
-                                                    title="Requires secure TLS connection for PAM authentication (pamSecure)"
-                                                >
-                                                    Secure
-                                                </Checkbox>
-                                            </Col>
+                                            <Row>
+                                                <Col smOffset={1} sm={7}>
+                                                    <Checkbox
+                                                        id="pamFallback"
+                                                        checked={pamFallback}
+                                                        onChange={this.handleCheckboxChange}
+                                                        title={`Sets whether to fallback to regular LDAP authentication if PAM authentication fails (pamFallback)`}
+                                                    >
+                                                        Fallback Enabled
+                                                    </Checkbox>
+                                                </Col>
+                                            </Row>
+                                            <Row className="ds-margin-top">
+                                                <Col smOffset={1} sm={7}>
+                                                    <Checkbox
+                                                        id="pamSecure"
+                                                        checked={pamSecure}
+                                                        onChange={this.handleCheckboxChange}
+                                                        title="Requires secure TLS connection for PAM authentication (pamSecure)"
+                                                    >
+                                                        Require Secure Connection
+                                                    </Checkbox>
+                                                </Col>
+                                            </Row>
                                         </FormGroup>
                                     </Form>
                                 </Col>
@@ -976,7 +972,7 @@ class PassthroughAuthentication extends React.Component {
                                 <Icon type="pf" name="close" />
                             </button>
                             <Modal.Title>
-                                {newPAMConfigEntry ? "Add" : "Edit"}
+                                {newPAMConfigEntry ? "Add " : "Edit "}
                                 Passthough Authentication Plugin URL
                             </Modal.Title>
                         </Modal.Header>
@@ -1023,10 +1019,8 @@ class PassthroughAuthentication extends React.Component {
                                         </FormGroup>
                                         {Object.entries(modalURLFields).map(([id, content]) => (
                                             <FormGroup key={id} controlId={id}>
-                                                <Col sm={5}>
-                                                    <ControlLabel title={content.help}>
-                                                        {content.name}
-                                                    </ControlLabel>
+                                                <Col componentClass={ControlLabel} sm={5} title={content.help}>
+                                                    {content.name}
                                                 </Col>
                                                 <Col sm={7}>
                                                     <FormControl
@@ -1076,7 +1070,7 @@ class PassthroughAuthentication extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup key="urlStartTLS" controlId="urlStartTLS">
-                                            <Col sm={4}>
+                                            <Col componentClass={ControlLabel} sm={5}>
                                                 <Checkbox
                                                     id="urlStartTLS"
                                                     checked={urlStartTLS}
@@ -1088,18 +1082,14 @@ class PassthroughAuthentication extends React.Component {
                                             </Col>
                                         </FormGroup>
                                         <FormGroup key="resultURL" controlId="resultURL">
-                                            <Col sm={5}>
-                                                <ControlLabel title="The URL that will be added or modified after you click 'Save'">
-                                                    Result URL
-                                                </ControlLabel>
+                                            <Col componentClass={ControlLabel} sm={5} title="The URL that will be added or modified after you click 'Save'">
+                                                Result URL
                                             </Col>
                                             <Col sm={7}>
-                                                <ControlLabel>
-                                                    {urlConnType}://{urlAuthDS}/{urlSubtree}{" "}
-                                                    {urlMaxConns},{urlMaxOps},{urlTimeout},
-                                                    {urlLDVer},{urlConnLifeTime},
-                                                    {urlStartTLS ? "1" : "0"}
-                                                </ControlLabel>
+                                                {urlConnType}://{urlAuthDS}/{urlSubtree}{" "}
+                                                {urlMaxConns},{urlMaxOps},{urlTimeout},
+                                                {urlLDVer},{urlConnLifeTime},
+                                                {urlStartTLS ? "1" : "0"}
                                             </Col>
                                         </FormGroup>
                                     </Form>
