@@ -20,8 +20,12 @@ import "../../css/ds.css";
 
 class ReferentialIntegrity extends React.Component {
     componentWillMount(prevProps) {
-        this.getAttributes();
-        this.updateFields();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.getAttributes();
+                this.updateFields();
+            }
+        }
     }
 
     componentDidUpdate(prevProps) {
@@ -34,6 +38,7 @@ class ReferentialIntegrity extends React.Component {
         super(props);
 
         this.state = {
+            firstLoad: true,
             updateDelay: "",
             membershipAttr: [],
             entryScope: "",
@@ -138,10 +143,7 @@ class ReferentialIntegrity extends React.Component {
                             this.setState({ configMembershipAttr: [] });
                         } else {
                             for (let value of pluginRow["referint-membership-attr"]) {
-                                membershipAttrList = [
-                                    ...membershipAttrList,
-                                    { id: value, label: value }
-                                ];
+                                membershipAttrList = [...membershipAttrList, value];
                             }
                             this.setState({
                                 configMembershipAttr: membershipAttrList
@@ -206,7 +208,7 @@ class ReferentialIntegrity extends React.Component {
         cmd = [...cmd, "--membership-attr"];
         if (configMembershipAttr.length != 0) {
             for (let value of configMembershipAttr) {
-                cmd = [...cmd, value.label];
+                cmd = [...cmd, value];
             }
         } else if (action == "add") {
             cmd = [...cmd, ""];
@@ -309,17 +311,17 @@ class ReferentialIntegrity extends React.Component {
                         ? ""
                         : pluginRow["referint-update-delay"][0],
                 entryScope:
-                    pluginRow["nsslapd-pluginEntryScope"] === undefined
+                    pluginRow["nsslapd-pluginentryscope"] === undefined
                         ? ""
-                        : pluginRow["nsslapd-pluginEntryScope"][0],
+                        : pluginRow["nsslapd-pluginentryscope"][0],
                 excludeEntryScope:
-                    pluginRow["nsslapd-pluginExcludeEntryScope"] === undefined
+                    pluginRow["nsslapd-pluginexcludeentryscope"] === undefined
                         ? ""
-                        : pluginRow["nsslapd-pluginExcludeEntryScope"][0],
+                        : pluginRow["nsslapd-pluginexcludeentryscope"][0],
                 containerScope:
-                    pluginRow["nsslapd-pluginContainerScope"] === undefined
+                    pluginRow["nsslapd-plugincontainerscope"] === undefined
                         ? ""
-                        : pluginRow["nsslapd-pluginContainerScope"][0],
+                        : pluginRow["nsslapd-plugincontainerscope"][0],
                 referintConfigEntry:
                     pluginRow["nsslapd-pluginConfigArea"] === undefined
                         ? ""
@@ -334,7 +336,7 @@ class ReferentialIntegrity extends React.Component {
                 this.setState({ membershipAttr: [] });
             } else {
                 for (let value of pluginRow["referint-membership-attr"]) {
-                    membershipAttrList = [...membershipAttrList, { id: value, label: value }];
+                    membershipAttrList = [...membershipAttrList, value];
                 }
                 this.setState({ membershipAttr: membershipAttrList });
             }
@@ -342,6 +344,9 @@ class ReferentialIntegrity extends React.Component {
     }
 
     getAttributes() {
+        this.setState({
+            firstLoad: false
+        });
         const attr_cmd = [
             "dsconf",
             "-j",
@@ -357,10 +362,7 @@ class ReferentialIntegrity extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -418,7 +420,7 @@ class ReferentialIntegrity extends React.Component {
         specificPluginCMD = [...specificPluginCMD, "--membership-attr"];
         if (membershipAttr.length != 0) {
             for (let value of membershipAttr) {
-                specificPluginCMD = [...specificPluginCMD, value.label];
+                specificPluginCMD = [...specificPluginCMD, value];
             }
         } else {
             specificPluginCMD = [...specificPluginCMD, "delete"];
@@ -749,10 +751,7 @@ class ReferentialIntegrity extends React.Component {
                                         />
                                     </Col>
                                     <Col sm={2}>
-                                        <Button
-                                            bsStyle="primary"
-                                            onClick={this.openModal}
-                                        >
+                                        <Button bsStyle="primary" onClick={this.openModal}>
                                             Manage
                                         </Button>
                                     </Col>
