@@ -18,8 +18,12 @@ import "../../css/ds.css";
 
 class RetroChangelog extends React.Component {
     componentWillMount(prevProps) {
-        this.getAttributes();
-        this.updateFields();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.getAttributes();
+                this.updateFields();
+            }
+        }
     }
 
     componentDidUpdate(prevProps) {
@@ -32,6 +36,7 @@ class RetroChangelog extends React.Component {
         super(props);
 
         this.state = {
+            firstLoad: true,
             isReplicated: false,
             attribute: [],
             directory: "",
@@ -69,12 +74,7 @@ class RetroChangelog extends React.Component {
                 attribute:
                     pluginRow["nsslapd-attribute"] === undefined
                         ? []
-                        : [
-                            {
-                                id: pluginRow["nsslapd-attribute"][0],
-                                label: pluginRow["nsslapd-attribute"][0]
-                            }
-                        ],
+                        : [pluginRow["nsslapd-attribute"][0]],
                 directory:
                     pluginRow["nsslapd-changelogdir"] === undefined
                         ? ""
@@ -92,6 +92,7 @@ class RetroChangelog extends React.Component {
     }
 
     getAttributes() {
+        this.setState({ firstLoad: false });
         const attr_cmd = [
             "dsconf",
             "-j",
@@ -107,10 +108,7 @@ class RetroChangelog extends React.Component {
                     const attrContent = JSON.parse(content);
                     let attrs = [];
                     for (let content of attrContent["items"]) {
-                        attrs.push({
-                            id: content.name,
-                            label: content.name
-                        });
+                        attrs.push(content.name[0]);
                     }
                     this.setState({
                         attributes: attrs
@@ -142,7 +140,7 @@ class RetroChangelog extends React.Component {
             "--is-replicated",
             isReplicated ? "TRUE" : "FALSE",
             "--attribute",
-            attribute.length != 0 ? attribute[0].label : "delete",
+            attribute.length != 0 ? attribute[0] : "delete",
             "--directory",
             directory || "delete",
             "--max-age",
