@@ -184,21 +184,21 @@ export class Ciphers extends React.Component {
             <option key={name}>{name}</option>
         );
 
+        let eCiphers = '<h4>Enabled Ciphers <font size="2">(' + enabledList.length + ')</font></h4>';
+        let sCiphers = '<h4>Other Available Ciphers <font size="2">(' + supportedList.length + ')</font><h4>';
+
         if (this.state.saving) {
             cipherPage =
-                <div className="ds-loading-spinner ds-center">
-                    <p />
+                <div className="ds-center ds-margin-top-lg">
                     <h4>Saving cipher preferences ...</h4>
                     <Spinner loading size="md" />
                 </div>;
         } else {
             cipherPage =
-                <div className="container-fluid">
+                <div>
                     <div className="ds-container">
                         <div className='ds-inline'>
-                            <div>
-                                <h4>Enabled Ciphers</h4>
-                            </div>
+                            <div dangerouslySetInnerHTML={{__html: eCiphers}} />
                             <div>
                                 <select
                                     className="ds-cipher-width"
@@ -212,7 +212,7 @@ export class Ciphers extends React.Component {
                         <div className="ds-divider-lrg" />
                         <div className='ds-inline'>
                             <div>
-                                <h4>Other Available Ciphers</h4>
+                                <div dangerouslySetInnerHTML={{__html: sCiphers}} />
                             </div>
                             <div>
                                 <select className="ds-cipher-width" size="16">
@@ -223,8 +223,8 @@ export class Ciphers extends React.Component {
                     </div>
                     <hr />
                     <Row>
-                        <Col componentClass={ControlLabel} sm={2}>
-                             Cipher Suite
+                        <Col componentClass={ControlLabel} sm={3}>
+                            Cipher Suite
                         </Col>
                         <Col sm={9}>
                             <select
@@ -239,8 +239,8 @@ export class Ciphers extends React.Component {
                         </Col>
                     </Row>
                     <Row className="ds-margin-top">
-                        <Col componentClass={ControlLabel} sm={2}>
-                             Allow Specific Ciphers
+                        <Col componentClass={ControlLabel} sm={3}>
+                            Allow Specific Ciphers
                         </Col>
                         <Col sm={9}>
                             <Typeahead
@@ -257,8 +257,8 @@ export class Ciphers extends React.Component {
                         </Col>
                     </Row>
                     <Row className="ds-margin-top">
-                        <Col componentClass={ControlLabel} sm={2}>
-                             Deny Specific Ciphers
+                        <Col componentClass={ControlLabel} sm={3}>
+                            Deny Specific Ciphers
                         </Col>
                         <Col sm={9}>
                             <Typeahead
@@ -274,10 +274,9 @@ export class Ciphers extends React.Component {
                             />
                         </Col>
                     </Row>
-                    <p />
                     <Button
                         bsStyle="primary"
-                        className="ds-margin-top"
+                        className="ds-margin-top-lg"
                         onClick={() => {
                             this.saveCipherPref();
                         }}
@@ -288,7 +287,7 @@ export class Ciphers extends React.Component {
         }
 
         return (
-            <div>
+            <div className="container-fluid">
                 {cipherPage}
             </div>
         );
