@@ -2,7 +2,7 @@ import cockpit from "cockpit";
 import React from "react";
 import PropTypes from "prop-types";
 import { log_cmd } from "./lib/tools.jsx";
-import { Col, Row, Tab, Nav, NavItem, Spinner } from "patternfly-react";
+import { Col, Row, Tab, Nav, NavItem, noop, Spinner } from "patternfly-react";
 import PluginEditModal from "./lib/plugins/pluginModal.jsx";
 import { PluginTable } from "./lib/plugins/pluginTables.jsx";
 import AccountPolicy from "./lib/plugins/accountPolicy.jsx";
@@ -18,25 +18,20 @@ import RetroChangelog from "./lib/plugins/retroChangelog.jsx";
 import RootDNAccessControl from "./lib/plugins/rootDNAccessControl.jsx";
 import USN from "./lib/plugins/usn.jsx";
 import WinSync from "./lib/plugins/winsync.jsx";
-import { NotificationController } from "./lib/notifications.jsx";
 import "./css/ds.css";
 
 var cmd;
 
 export class Plugins extends React.Component {
-    componentWillMount() {
-        this.pluginList();
-        this.setState(prevState => ({
-            pluginTabs: {
-                ...prevState.pluginTabs,
-                basicConfig: true
-            }
-        }));
-    }
-
     componentDidUpdate(prevProps) {
-        if (this.props.serverId !== prevProps.serverId) {
-            this.pluginList();
+        if (this.props.wasActiveList.includes(5)) {
+            if (this.state.firstLoad) {
+                this.pluginList();
+            } else {
+                if (this.props.serverId !== prevProps.serverId) {
+                    this.pluginList();
+                }
+            }
         }
     }
 
@@ -48,14 +43,12 @@ export class Plugins extends React.Component {
         this.openPluginModal = this.openPluginModal.bind(this);
         this.closePluginModal = this.closePluginModal.bind(this);
         this.pluginList = this.pluginList.bind(this);
-        this.removeNotification = this.removeNotification.bind(this);
-        this.addNotification = this.addNotification.bind(this);
         this.onChangeTab = this.onChangeTab.bind(this);
         this.savePlugin = this.savePlugin.bind(this);
         this.toggleLoading = this.toggleLoading.bind(this);
 
         this.state = {
-            notifications: [],
+            firstLoad: true,
             loading: false,
             showPluginModal: false,
             currentPluginTab: "",
@@ -81,29 +74,6 @@ export class Plugins extends React.Component {
         this.setState({ currentPluginTab: event.target.value });
     }
 
-    addNotification(type, message, timerdelay, persistent) {
-        this.setState(prevState => ({
-            notifications: [
-                ...prevState.notifications,
-                {
-                    key: prevState.notifications.length + 1,
-                    type: type,
-                    persistent: persistent,
-                    timerdelay: timerdelay,
-                    message: message
-                }
-            ]
-        }));
-    }
-
-    removeNotification(notificationToRemove) {
-        this.setState({
-            notifications: this.state.notifications.filter(
-                notification => notificationToRemove.key !== notification.key
-            )
-        });
-    }
-
     handleFieldChange(e) {
         this.setState({
             [e.target.id]: e.target.value
@@ -124,7 +94,7 @@ export class Plugins extends React.Component {
 
     toggleLoading() {
         this.setState(prevState => ({
-            loading: !prevState.loading
+            loading: !prevState.loading,
         }));
     }
 
@@ -175,23 +145,33 @@ export class Plugins extends React.Component {
             "plugin",
             "list"
         ];
-        this.toggleLoading();
+
         log_cmd("pluginList", "Get plugins for table rows", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
                     var myObject = JSON.parse(content);
-                    this.setState({
-                        rows: myObject.items
-                    });
-                    this.toggleLoading();
+                    if (this.state.firstLoad) {
+                        this.setState(prevState => ({
+                            pluginTabs: {
+                                ...prevState.pluginTabs,
+                                basicConfig: true
+                            },
+                            rows: myObject.items,
+                            firstLoad: false,
+                        }));
+                    } else {
+                        this.setState({
+                            rows: myObject.items
+                        });
+                    }
                 })
                 .fail(err => {
-                    if (err != 0) {
-                        let errMsg = JSON.parse(err);
-                        console.log("pluginList failed: ", errMsg.desc);
-                    }
-                    this.toggleLoading();
+                    let errMsg = JSON.parse(err);
+                    this.props.addNotification(
+                        "error",
+                        `${errMsg.desc} error during plugin loading`
+                    );
                 });
     }
 
@@ -239,7 +219,10 @@ export class Plugins extends React.Component {
                 .done(content => {
                     console.info("savePlugin", "Result", content);
                     basicPluginSuccess = true;
-                    this.addNotification("success", `Plugin ${data.name} was successfully modified`);
+                    this.props.addNotification(
+                        "success",
+                        `Plugin ${data.name} was successfully modified`
+                    );
                     this.pluginList();
                     this.closePluginModal();
                     this.toggleLoading();
@@ -249,7 +232,7 @@ export class Plugins extends React.Component {
                     if (errMsg.desc.indexOf("nothing to set") >= 0) {
                         nothingToSetErr = true;
                     } else {
-                        this.addNotification(
+                        this.props.addNotification(
                             "error",
                             `${errMsg.desc} error during ${data.name} modification`
                         );
@@ -273,7 +256,7 @@ export class Plugins extends React.Component {
                                 .done(content => {
                                     // Notify success only one time
                                     if (!basicPluginSuccess) {
-                                        this.addNotification(
+                                        this.props.addNotification(
                                             "success",
                                             `Plugin ${data.name} was successfully modified`
                                         );
@@ -289,13 +272,13 @@ export class Plugins extends React.Component {
                                 errMsg.desc.indexOf("nothing to set") < 0
                                     ) {
                                         if (basicPluginSuccess) {
-                                            this.addNotification(
+                                            this.props.addNotification(
                                                 "success",
                                                 `Plugin ${data.name} was successfully modified`
                                             );
                                             this.pluginList();
                                         }
-                                        this.addNotification(
+                                        this.props.addNotification(
                                             "error",
                                             `${errMsg.desc} error during ${data.name} modification`
                                         );
@@ -324,7 +307,7 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
                     />
                 )
@@ -337,8 +320,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -350,8 +335,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -363,8 +350,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -376,8 +365,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -389,8 +380,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -402,7 +395,7 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
                     />
                 )
@@ -415,8 +408,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -428,7 +423,7 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
                     />
                 )
@@ -441,8 +436,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -454,8 +451,10 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             },
@@ -467,7 +466,7 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
                     />
                 )
@@ -480,82 +479,89 @@ export class Plugins extends React.Component {
                         serverId={this.props.serverId}
                         savePluginHandler={this.savePlugin}
                         pluginListHandler={this.pluginList}
-                        addNotification={this.addNotification}
+                        addNotification={this.props.addNotification}
                         toggleLoadingHandler={this.toggleLoading}
+                        wasActiveList={this.props.wasActiveList}
+                        key={this.props.wasActiveList}
                     />
                 )
             }
         };
+
         return (
             <div className="container-fluid">
-                <NotificationController
-                    notifications={this.state.notifications}
-                    removeNotificationAction={this.removeNotification}
-                />
-                <Row className="clearfix">
-                    <Col sm={12}>
-                        <Spinner
-                            className="ds-float-left ds-plugin-spinner"
-                            loading={this.state.loading}
-                            size="md"
-                        />
-                    </Col>
-                </Row>
-                <Tab.Container
-                    id="left-tabs-example"
-                    defaultActiveKey={Object.keys(selectPlugins)[0]}
-                >
+                <div className="ds-loading-spinner ds-center" hidden={!this.state.firstLoad}>
+                    <h4>Loading plugins ...</h4>
+                    <Spinner className="ds-margin-top" loading size="md" />
+                </div>
+                <div hidden={this.state.firstLoad}>
                     <Row className="clearfix">
-                        <Col sm={3}>
-                            <Nav bsStyle="pills" stacked>
-                                {Object.entries(selectPlugins).map(([id, item]) => (
-                                    <NavItem key={id} eventKey={id}>
-                                        {item.name}
-                                    </NavItem>
-                                ))}
-                            </Nav>
-                        </Col>
-                        <Col sm={9}>
-                            <Tab.Content animation={false}>
-                                {Object.entries(selectPlugins).map(([id, item]) => (
-                                    <Tab.Pane key={id} eventKey={id}>
-                                        {item.component}
-                                    </Tab.Pane>
-                                ))}
-                            </Tab.Content>
+                        <Col sm={12}>
+                            <Spinner
+                                className="ds-float-left ds-plugin-spinner"
+                                loading={this.state.loading}
+                                size="md"
+                            />
                         </Col>
                     </Row>
-                </Tab.Container>
-                <PluginEditModal
-                    handleChange={this.handleFieldChange}
-                    handleSwitchChange={this.handleSwitchChange}
-                    pluginData={{
-                        currentPluginName: this.state.currentPluginName,
-                        currentPluginType: this.state.currentPluginType,
-                        currentPluginEnabled: this.state.currentPluginEnabled,
-                        currentPluginPath: this.state.currentPluginPath,
-                        currentPluginInitfunc: this.state.currentPluginInitfunc,
-                        currentPluginId: this.state.currentPluginId,
-                        currentPluginVendor: this.state.currentPluginVendor,
-                        currentPluginVersion: this.state.currentPluginVersion,
-                        currentPluginDescription: this.state.currentPluginDescription,
-                        currentPluginDependsOnType: this.state.currentPluginDependsOnType,
-                        currentPluginDependsOnNamed: this.state.currentPluginDependsOnNamed,
-                        currentPluginPrecedence: this.state.currentPluginPrecedence
-                    }}
-                    closeHandler={this.closePluginModal}
-                    showModal={this.state.showPluginModal}
-                    savePluginHandler={this.savePlugin}
-                />
+                    <Tab.Container
+                        id="left-tabs-example"
+                        defaultActiveKey={Object.keys(selectPlugins)[0]}
+                    >
+                        <Row className="clearfix">
+                            <Col sm={3}>
+                                <Nav bsStyle="pills" stacked>
+                                    {Object.entries(selectPlugins).map(([id, item]) => (
+                                        <NavItem key={id} eventKey={id}>
+                                            {item.name}
+                                        </NavItem>
+                                    ))}
+                                </Nav>
+                            </Col>
+                            <Col sm={9}>
+                                <Tab.Content animation={false}>
+                                    {Object.entries(selectPlugins).map(([id, item]) => (
+                                        <Tab.Pane key={id} eventKey={id}>
+                                            {item.component}
+                                        </Tab.Pane>
+                                    ))}
+                                </Tab.Content>
+                            </Col>
+                        </Row>
+                    </Tab.Container>
+                    <PluginEditModal
+                        handleChange={this.handleFieldChange}
+                        handleSwitchChange={this.handleSwitchChange}
+                        pluginData={{
+                            currentPluginName: this.state.currentPluginName,
+                            currentPluginType: this.state.currentPluginType,
+                            currentPluginEnabled: this.state.currentPluginEnabled,
+                            currentPluginPath: this.state.currentPluginPath,
+                            currentPluginInitfunc: this.state.currentPluginInitfunc,
+                            currentPluginId: this.state.currentPluginId,
+                            currentPluginVendor: this.state.currentPluginVendor,
+                            currentPluginVersion: this.state.currentPluginVersion,
+                            currentPluginDescription: this.state.currentPluginDescription,
+                            currentPluginDependsOnType: this.state.currentPluginDependsOnType,
+                            currentPluginDependsOnNamed: this.state.currentPluginDependsOnNamed,
+                            currentPluginPrecedence: this.state.currentPluginPrecedence
+                        }}
+                        closeHandler={this.closePluginModal}
+                        showModal={this.state.showPluginModal}
+                        savePluginHandler={this.savePlugin}
+                    />
+                </div>
             </div>
         );
     }
 }
 
 Plugins.propTypes = {
+    addNotification: PropTypes.func,
     serverId: PropTypes.string
 };
 
 Plugins.defaultProps = {
+    addNotification: noop,
     serverId: ""
 };
