@@ -1,6 +1,5 @@
 import cockpit from "cockpit";
 import React from "react";
-import { NotificationController } from "./lib/notifications.jsx";
 import { log_cmd, searchFilter } from "./lib/tools.jsx";
 import {
     ObjectClassesTable,
@@ -8,6 +7,7 @@ import {
     MatchingRulesTable
 } from "./lib/schema/schemaTables.jsx";
 import { ObjectClassModal, AttributeTypeModal } from "./lib/schema/schemaModals.jsx";
+import { DoubleConfirmModal } from "./lib/notifications.jsx";
 import {
     Nav,
     NavItem,
@@ -16,27 +16,30 @@ import {
     TabContent,
     TabPane,
     Spinner,
+    noop,
     Button
 } from "patternfly-react";
 import PropTypes from "prop-types";
 import "./css/ds.css";
 
 export class Schema extends React.Component {
-    componentWillMount() {
-        this.loadSyntaxesFirst();
-    }
-
     componentDidUpdate(prevProps) {
-        if (this.props.serverId !== prevProps.serverId) {
-            this.loadSyntaxesFirst();
+        if (this.props.wasActiveList.includes(4)) {
+            if (this.state.firstLoad) {
+                this.loadSyntaxesFirst();
+            } else {
+                if (this.props.serverId !== prevProps.serverId) {
+                    this.loadSyntaxesFirst();
+                }
+            }
         }
     }
 
     constructor(props) {
         super(props);
         this.state = {
+            firstLoad: true,
             loading: false,
-            notifications: [],
             activeKey: 1,
 
             objectclassRows: [],
@@ -48,6 +51,7 @@ export class Schema extends React.Component {
             attributes: [],
             objectclasses: [],
             matchingrules: [],
+            deleteName: "",
 
             ocModalViewOnly: false,
             ocName: "",
@@ -84,8 +88,6 @@ export class Schema extends React.Component {
         };
 
         this.handleFieldChange = this.handleFieldChange.bind(this);
-        this.addNotification = this.addNotification.bind(this);
-        this.removeNotification = this.removeNotification.bind(this);
         this.handleNavSelect = this.handleNavSelect.bind(this);
         this.handleTypeaheadChange = this.handleTypeaheadChange.bind(this);
         this.loadSchemaData = this.loadSchemaData.bind(this);
@@ -97,20 +99,24 @@ export class Schema extends React.Component {
         this.showAddObjectclassModal = this.showAddObjectclassModal.bind(this);
         this.openObjectclassModal = this.openObjectclassModal.bind(this);
         this.closeObjectclassModal = this.closeObjectclassModal.bind(this);
-        this.deleteObjectclass = this.deleteObjectclass.bind(this);
+        this.doDeleteOC = this.doDeleteOC.bind(this);
         this.addObjectclass = this.addObjectclass.bind(this);
         this.editObjectclass = this.editObjectclass.bind(this);
         this.cmdOperationObjectclass = this.cmdOperationObjectclass.bind(this);
+        this.showConfirmOCDelete = this.showConfirmOCDelete.bind(this);
+        this.closeConfirmOCDelete = this.closeConfirmOCDelete.bind(this);
 
         this.showViewAttributeModal = this.showViewAttributeModal.bind(this);
         this.showEditAttributeModal = this.showEditAttributeModal.bind(this);
         this.showAddAttributeModal = this.showAddAttributeModal.bind(this);
         this.openAttributeModal = this.openAttributeModal.bind(this);
         this.closeAttributeModal = this.closeAttributeModal.bind(this);
-        this.deleteAttribute = this.deleteAttribute.bind(this);
+        this.doDeleteAttr = this.doDeleteAttr.bind(this);
         this.addAttribute = this.addAttribute.bind(this);
         this.editAttribute = this.editAttribute.bind(this);
         this.cmdOperationAttribute = this.cmdOperationAttribute.bind(this);
+        this.showConfirmAttrDelete = this.showConfirmAttrDelete.bind(this);
+        this.closeConfirmAttrDelete = this.closeConfirmAttrDelete.bind(this);
     }
 
     toggleLoading(item) {
@@ -138,6 +144,12 @@ export class Schema extends React.Component {
     }
 
     loadSyntaxesFirst() {
+        if (this.state.firstLoad) {
+            this.setState({
+                firstLoad: false
+            });
+        }
+        this.toggleLoading("allSchema");
         let cmd = [
             "dsconf",
             "-j",
@@ -172,9 +184,6 @@ export class Schema extends React.Component {
             "schema",
             "list"
         ];
-        if (initialLoading) {
-            this.toggleLoading("allSchema");
-        }
         log_cmd("loadSchemaData", "Get schema objects in one batch", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
@@ -368,8 +377,25 @@ export class Schema extends React.Component {
         this.setState({ objectclassModalShow: false });
     }
 
-    deleteObjectclass(rowData) {
-        let name = rowData.name[0];
+    closeConfirmOCDelete () {
+        // call doDeleteOC
+        this.setState({
+            showConfirmDeleteOC: false,
+            modalChecked: false,
+            modalSpinning: false,
+        });
+    }
+
+    showConfirmOCDelete(oc_name) {
+        this.setState({
+            showConfirmDeleteOC: true,
+            modalChecked: false,
+            modalSpinning: false,
+            deleteName: oc_name
+        });
+    }
+
+    doDeleteOC() {
         let cmd = [
             "dsconf",
             "-j",
@@ -377,10 +403,13 @@ export class Schema extends React.Component {
             "schema",
             "objectclasses",
             "remove",
-            name
+            this.state.deleteName
         ];
 
-        this.toggleLoading("ocTable");
+        this.setState({
+            modalSpinning: true,
+        });
+
         log_cmd("deleteObjectclass", "Delete ObjectClass from schema", cmd);
         cockpit
                 .spawn(cmd, {
@@ -389,18 +418,18 @@ export class Schema extends React.Component {
                 })
                 .done(content => {
                     console.info("deleteObjectclass", "Result", content);
-                    this.addNotification("success", `ObjectClass ${name} was successfully deleted`);
+                    this.props.addNotification("success", `ObjectClass ${this.state.deleteName} was successfully deleted`);
                     this.loadSchemaData();
-                    this.toggleLoading("ocTable");
+                    this.closeConfirmOCDelete();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error during ObjectClass removal operation - ${errMsg.desc}`
                     );
                     this.loadSchemaData();
-                    this.toggleLoading("ocTable");
+                    this.closeConfirmOCDelete();
                 });
     }
 
@@ -415,7 +444,7 @@ export class Schema extends React.Component {
     cmdOperationObjectclass(action) {
         const { ocName, ocDesc, ocOID, ocParent, ocKind, ocMust, ocMay } = this.state;
         if (ocName == "") {
-            this.addNotification("warning", "ObjectClass Name is required.");
+            this.props.addNotification("warning", "ObjectClass Name is required.");
         } else {
             let cmd = [
                 "dsconf",
@@ -461,7 +490,7 @@ export class Schema extends React.Component {
                     })
                     .done(content => {
                         console.info("cmdOperationObjectclass", "Result", content);
-                        this.addNotification(
+                        this.props.addNotification(
                             "success",
                             `ObjectClass ${ocName} - ${action} operation was successfull`
                         );
@@ -471,7 +500,7 @@ export class Schema extends React.Component {
                     })
                     .fail(err => {
                         let errMsg = JSON.parse(err);
-                        this.addNotification(
+                        this.props.addNotification(
                             "error",
                             `Error during the ObjectClass ${action} operation - ${errMsg.desc}`
                         );
@@ -641,11 +670,29 @@ export class Schema extends React.Component {
     }
 
     closeAttributeModal() {
-        this.setState({ attributeModalShow: false });
+        this.setState({
+            attributeModalShow: false
+        });
     }
 
-    deleteAttribute(rowData) {
-        let name = rowData.name[0];
+    closeConfirmAttrDelete () {
+        this.setState({
+            showConfirmAttrDelete: false,
+            modalChecked: false,
+            modalSpinning: false,
+        });
+    }
+
+    showConfirmAttrDelete(attr_name) {
+        this.setState({
+            showConfirmAttrDelete: true,
+            modalChecked: false,
+            modalSpinning: false,
+            deleteName: attr_name
+        });
+    }
+
+    doDeleteAttr() {
         let cmd = [
             "dsconf",
             "-j",
@@ -653,10 +700,13 @@ export class Schema extends React.Component {
             "schema",
             "attributetypes",
             "remove",
-            name
+            this.state.deleteName
         ];
 
-        this.toggleLoading("atTable");
+        this.setState({
+            modalSpinning: true,
+        });
+
         log_cmd("deleteAttribute", "Delete Attribute from schema", cmd);
         cockpit
                 .spawn(cmd, {
@@ -665,18 +715,18 @@ export class Schema extends React.Component {
                 })
                 .done(content => {
                     console.info("deleteAttribute", "Result", content);
-                    this.addNotification("success", `Attribute ${name} was successfully deleted`);
+                    this.props.addNotification("success", `Attribute ${this.state.deleteName} was successfully deleted`);
                     this.loadSchemaData();
-                    this.toggleLoading("atTable");
+                    this.closeConfirmAttrDelete();
                 })
                 .fail(err => {
                     let errMsg = JSON.parse(err);
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error during Attribute removal operation - ${errMsg.desc}`
                     );
                     this.loadSchemaData();
-                    this.toggleLoading("atTable");
+                    this.closeConfirmAttrDelete();
                 });
     }
 
@@ -705,7 +755,7 @@ export class Schema extends React.Component {
         } = this.state;
 
         if (atName == "" || atSyntax.length == 0) {
-            this.addNotification("warning", "Attribute Name and Syntax are required.");
+            this.props.addNotification("warning", "Attribute Name and Syntax are required.");
         } else {
             let cmd = [
                 "dsconf",
@@ -774,7 +824,7 @@ export class Schema extends React.Component {
                     })
                     .done(content => {
                         console.info("cmdOperationAttribute", "Result", content);
-                        this.addNotification(
+                        this.props.addNotification(
                             "success",
                             `Attribute ${atName} - ${action} operation was successfull`
                         );
@@ -784,7 +834,7 @@ export class Schema extends React.Component {
                     })
                     .fail(err => {
                         let errMsg = JSON.parse(err);
-                        this.addNotification(
+                        this.props.addNotification(
                             "error",
                             `Error during the Attribute ${action} operation - ${errMsg.desc}`
                         );
@@ -795,29 +845,6 @@ export class Schema extends React.Component {
         }
     }
 
-    addNotification(type, message, timerdelay, persistent) {
-        this.setState(prevState => ({
-            notifications: [
-                ...prevState.notifications,
-                {
-                    key: prevState.notifications.length + 1,
-                    type: type,
-                    persistent: persistent,
-                    timerdelay: timerdelay,
-                    message: message
-                }
-            ]
-        }));
-    }
-
-    removeNotification(notificationToRemove) {
-        this.setState({
-            notifications: this.state.notifications.filter(
-                notification => notificationToRemove.key !== notification.key
-            )
-        });
-    }
-
     handleNavSelect(key) {
         this.setState({
             activeKey: key
@@ -876,10 +903,6 @@ export class Schema extends React.Component {
         } else {
             schemaPage = (
                 <div className="container-fluid">
-                    <NotificationController
-                        notifications={this.state.notifications}
-                        removeNotificationAction={this.removeNotification}
-                    />
                     <div className="ds-tab-table">
                         <TabContainer
                             id="basic-tabs-pf"
@@ -919,7 +942,7 @@ export class Schema extends React.Component {
                                                 rows={this.state.filteredObjectclassRows}
                                                 viewModalHandler={this.showViewObjectclassModal}
                                                 editModalHandler={this.showEditObjectclassModal}
-                                                deleteHandler={this.deleteObjectclass}
+                                                deleteHandler={this.showConfirmOCDelete}
                                                 loading={this.state.ocTableLoading}
                                             />
                                             <Button
@@ -970,7 +993,7 @@ export class Schema extends React.Component {
                                                 rows={this.state.filteredAttributesRows}
                                                 viewModalHandler={this.showViewAttributeModal}
                                                 editModalHandler={this.showEditAttributeModal}
-                                                deleteHandler={this.deleteAttribute}
+                                                deleteHandler={this.showConfirmAttrDelete}
                                                 syntaxes={this.state.syntaxes}
                                                 loading={this.state.atTableLoading}
                                             />
@@ -1022,6 +1045,32 @@ export class Schema extends React.Component {
                             </div>
                         </TabContainer>
                     </div>
+                    <DoubleConfirmModal
+                        showModal={this.state.showConfirmDeleteOC}
+                        closeHandler={this.closeConfirmOCDelete}
+                        handleChange={this.handleFieldChange}
+                        actionHandler={this.doDeleteOC}
+                        spinning={this.state.modalSpinning}
+                        item={this.state.deleteName}
+                        checked={this.state.modalChecked}
+                        mTitle="Delete An Objectclass"
+                        mMsg="Are you sure you want to delete this Objectclass?"
+                        mSpinningMsg="Deleting objectclass ..."
+                        mBtnName="Delete Objectclass"
+                    />
+                    <DoubleConfirmModal
+                        showModal={this.state.showConfirmAttrDelete}
+                        closeHandler={this.closeConfirmAttrDelete}
+                        handleChange={this.handleFieldChange}
+                        actionHandler={this.doDeleteAttr}
+                        spinning={this.state.modalSpinning}
+                        item={this.state.deleteName}
+                        checked={this.state.modalChecked}
+                        mTitle="Delete An Attribute"
+                        mMsg="Are you sure you want to delete this Attribute?"
+                        mSpinningMsg="Deleting attribute ..."
+                        mBtnName="Delete Attribute"
+                    />
                 </div>
             );
         }
@@ -1032,10 +1081,12 @@ export class Schema extends React.Component {
 // Props and defaultProps
 
 Schema.propTypes = {
+    addNotification: PropTypes.func,
     serverId: PropTypes.string
 };
 
 Schema.defaultProps = {
+    addNotification: noop,
     serverId: ""
 };
 
