@@ -1,25 +1,28 @@
 import cockpit from "cockpit";
 import React from "react";
 import Switch from "react-switch";
-import { NotificationController, ConfirmPopup } from "./lib/notifications.jsx";
-import { log_cmd, valid_port } from "./lib/tools.jsx";
+import { ConfirmPopup } from "./lib/notifications.jsx";
+import { log_cmd } from "./lib/tools.jsx";
 import { Typeahead } from "react-bootstrap-typeahead";
 import { CertificateManagement } from "./lib/security/certificateManagement.jsx";
 import { SecurityEnableModal } from "./lib/security/securityModals.jsx";
 import { Ciphers } from "./lib/security/ciphers.jsx";
 import {
-    Nav,
-    NavItem,
-    TabContainer,
-    TabContent,
-    TabPane,
-    Col,
-    Row,
-    ControlLabel,
     Button,
     Checkbox,
+    Col,
+    ControlLabel,
+    Form,
+    FormControl,
     Icon,
-    Spinner
+    Nav,
+    NavItem,
+    Row,
+    Spinner,
+    TabContainer,
+    TabContent,
+    noop,
+    TabPane
 } from "patternfly-react";
 import PropTypes from "prop-types";
 import "./css/ds.css";
@@ -30,7 +33,6 @@ export class Security extends React.Component {
         this.state = {
             loaded: false,
             saving: false,
-            notifications: [],
             activeKey: 1,
 
             errObj: {},
@@ -46,7 +48,6 @@ export class Security extends React.Component {
             securityEnabled: false,
             requireSecureBinds: false,
             secureListenhost: false,
-            securePort: '636',
             clientAuth: false,
             checkHostname: false,
             validateCert: '',
@@ -54,11 +55,11 @@ export class Security extends React.Component {
             sslVersionMax: '',
             allowWeakCipher: false,
             nssslpersonalityssl: '',
+            nstlsallowclientrenegotiation: true,
             // Original config Settings
             _securityEnabled: false,
             _requireSecureBinds: false,
             _secureListenhost: false,
-            _securePort: '636',
             _clientAuth: false,
             _checkHostname: false,
             _validateCert: '',
@@ -66,11 +67,10 @@ export class Security extends React.Component {
             _sslVersionMax: '',
             _allowWeakCipher: false,
             _nssslpersonalityssl: '',
+            _nstlsallowclientrenegotiation: true,
         };
 
         this.handleChange = this.handleChange.bind(this);
-        this.addNotification = this.addNotification.bind(this);
-        this.removeNotification = this.removeNotification.bind(this);
         this.handleNavSelect = this.handleNavSelect.bind(this);
         this.handleSwitchChange = this.handleSwitchChange.bind(this);
         this.handleTypeaheadChange = this.handleTypeaheadChange.bind(this);
@@ -84,29 +84,7 @@ export class Security extends React.Component {
         this.disableSecurity = this.disableSecurity.bind(this);
         this.saveSecurityConfig = this.saveSecurityConfig.bind(this);
         this.closeSecurityEnableModal = this.closeSecurityEnableModal.bind(this);
-    }
-
-    addNotification(type, message, timerdelay, persistent) {
-        this.setState(prevState => ({
-            notifications: [
-                ...prevState.notifications,
-                {
-                    key: prevState.notifications.length + 1,
-                    type: type,
-                    persistent: persistent,
-                    timerdelay: timerdelay,
-                    message: message,
-                }
-            ]
-        }));
-    }
-
-    removeNotification(notificationToRemove) {
-        this.setState({
-            notifications: this.state.notifications.filter(
-                notification => notificationToRemove.key !== notification.key
-            )
-        });
+        this.reloadConfig = this.reloadConfig.bind(this);
     }
 
     componentWillMount () {
@@ -116,6 +94,22 @@ export class Security extends React.Component {
         }
     }
 
+    componentDidMount () {
+        this.props.enableTree();
+    }
+
+    componentDidUpdate(prevProps) {
+        if (this.props.serverId !== prevProps.serverId) {
+            this.loadSecurityConfig();
+        }
+    }
+
+    reloadConfig () {
+        this.setState({
+            loaded: false
+        }, this.loadSecurityConfig);
+    }
+
     loadSupportedCiphers () {
         const cmd = [
             "dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.props.serverId + ".socket",
@@ -136,7 +130,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading security configuration - ${msg}`
                     );
@@ -163,7 +157,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading security configuration - ${msg}`
                     );
@@ -193,7 +187,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading CA certificates - ${msg}`
                     );
@@ -228,7 +222,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading server certificates - ${msg}`
                     );
@@ -259,7 +253,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading security RSA configuration - ${msg}`
                     );
@@ -283,7 +277,13 @@ export class Security extends React.Component {
                     let validateCert = "warn";
                     let cipherPref = "default";
                     let allowWeak = false;
+                    let renegot = true;
 
+                    if ('nstlsallowclientrenegotiation' in config.items) {
+                        if (config.items['nstlsallowclientrenegotiation'] == "off") {
+                            renegot = false;
+                        }
+                    }
                     if ('nsslapd-security' in attrs) {
                         if (attrs['nsslapd-security'].toLowerCase() == "on") {
                             secEnabled = true;
@@ -320,7 +320,6 @@ export class Security extends React.Component {
                             securityEnabled: secEnabled,
                             requireSecureBinds: secReqSecBinds,
                             secureListenhost: attrs['nsslapd-securelistenhost'],
-                            securePort: attrs['nsslapd-secureport'],
                             clientAuth: clientAuth,
                             checkHostname: attrs['nsslapd-ssl-check-hostname'],
                             validateCert: validateCert,
@@ -328,10 +327,11 @@ export class Security extends React.Component {
                             sslVersionMax: attrs['sslversionmax'],
                             allowWeakCipher: allowWeak,
                             cipherPref: cipherPref,
+                            nstlsallowclientrenegotiation: renegot,
+                            _nstlsallowclientrenegotiation: renegot,
                             _securityEnabled: secEnabled,
                             _requireSecureBinds: secReqSecBinds,
                             _secureListenhost: attrs['nsslapd-securelistenhost'],
-                            _securePort: attrs['nsslapd-secureport'],
                             _clientAuth: clientAuth,
                             _checkHostname: attrs['nsslapd-ssl-check-hostname'],
                             _validateCert: validateCert,
@@ -351,7 +351,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error loading security configuration - ${msg}`
                     );
@@ -377,7 +377,7 @@ export class Security extends React.Component {
                     showSecurityEnableModal: true,
                 });
             } else {
-                this.addNotification(
+                this.props.addNotification(
                     "error",
                     `There must be at least one server certificate present in the security database to enable security`
                 );
@@ -418,7 +418,7 @@ export class Security extends React.Component {
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(() => {
-                    this.addNotification(
+                    this.props.addNotification(
                         "success",
                         `Successfully enabled security.  You must restart the server for this to take effect.`
                     );
@@ -434,7 +434,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error enabling security - ${msg}`
                     );
@@ -454,7 +454,7 @@ export class Security extends React.Component {
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(() => {
-                    this.addNotification(
+                    this.props.addNotification(
                         "success",
                         `Successfully disabled security.  You must restart the server for this to take effect.`
                     );
@@ -468,7 +468,7 @@ export class Security extends React.Component {
                     if ('info' in errMsg) {
                         msg = errMsg.desc + " - " + errMsg.info;
                     }
-                    this.addNotification(
+                    this.props.addNotification(
                         "error",
                         `Error disabling security - ${msg}`
                     );
@@ -487,9 +487,9 @@ export class Security extends React.Component {
         }
 
         if (sslMin > sslMax) {
-            this.addNotification(
+            this.props.addNotification(
                 "error",
-                `The TLS minimum version but be less than or equal to the TLS maximum version`
+                `The TLS minimum version must be less than or equal to the TLS maximum version`
             );
             // Reset page
             this.loadSecurityConfig();
@@ -513,18 +513,6 @@ export class Security extends React.Component {
         if (this.state._clientAuth != this.state.clientAuth) {
             cmd.push("--tls-client-auth=" + this.state.clientAuth);
         }
-        if (this.state._securePort != this.state.securePort) {
-            if (!valid_port(this.state.securePort)) {
-                this.addNotification(
-                    "error",
-                    `The Secure Port is invalid, it must be a number between 1 and 65535`
-                );
-                // Reset page
-                this.loadSecurityConfig();
-                return;
-            }
-            cmd.push("--secure-port=" + this.state.securePort);
-        }
         if (this.state._secureListenhost != this.state.secureListenhost) {
             cmd.push("--listen-host=" + this.state.secureListenhost);
         }
@@ -550,6 +538,14 @@ export class Security extends React.Component {
             cmd.push("--require-secure-authentication=" + val);
         }
 
+        if (this.state._nstlsallowclientrenegotiation != this.state.nstlsallowclientrenegotiation) {
+            let val = "off";
+            if (this.state.nstlsallowclientrenegotiation) {
+                val = "on";
+            }
+            cmd.push("--tls-client-renegotiation=" + val);
+        }
+
         if (cmd.length > 5) {
             log_cmd("saveSecurityConfig", "Applying security config change", cmd);
             let msg = "Successfully updated security configuration.  You must restart the Directory Server for these changes to take effect.";
@@ -563,7 +559,7 @@ export class Security extends React.Component {
                     .spawn(cmd, {superuser: true, "err": "message"})
                     .done(content => {
                         this.loadSecurityConfig(1);
-                        this.addNotification(
+                        this.props.addNotification(
                             "success",
                             msg
                         );
@@ -581,7 +577,7 @@ export class Security extends React.Component {
                         if ('info' in errMsg) {
                             msg = errMsg.desc + " - " + errMsg.info;
                         }
-                        this.addNotification(
+                        this.props.addNotification(
                             "error",
                             `Error updating security configuration - ${msg}`
                         );
@@ -626,28 +622,25 @@ export class Security extends React.Component {
             let configPage = "";
             if (this.state.securityEnabled) {
                 configPage =
-                    <div>
-                        <Row className="ds-margin-top" title="The server's secure port number (nsslapd-secureport).">
-                            <Col componentClass={ControlLabel} sm={3}>
-                                Server Secure Port
-                            </Col>
-                            <Col sm={4}>
-                                <input id="securePort" className="ds-input-auto" onChange={this.handleChange} type="text" value={this.state.securePort} />
-                            </Col>
-                        </Row>
+                    <Form horizontal>
                         <Row className="ds-margin-top" title="This parameter can be used to restrict the Directory Server instance to a single IP interface (hostname, or IP address).  This parameter specifically sets what interface to use for TLS traffic.  Requires restart. (nsslapd-securelistenhost).">
-                            <Col componentClass={ControlLabel} sm={3}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 Secure Listen Host
                             </Col>
-                            <Col sm={4}>
-                                <input id="secureListenhost" className="ds-input-auto" type="text" onChange={this.handleChange} value={this.state.secureListenhost} />
+                            <Col sm={8}>
+                                <FormControl
+                                    id="secureListenhost"
+                                    type="text"
+                                    value={this.state.secureListenhost}
+                                    onChange={this.handleChange}
+                                />
                             </Col>
                         </Row>
                         <Row className="ds-margin-top" title="The name, or nickname, of the server certificate inthe NSS datgabase the server should use (nsSSLPersonalitySSL).">
-                            <Col sm={3}>
-                                <ControlLabel>Server Certificate Name</ControlLabel>
+                            <Col componentClass={ControlLabel} sm={4}>
+                                Server Certificate Name
                             </Col>
-                            <Col sm={4}>
+                            <Col sm={8}>
                                 <Typeahead
                                     id="serverCertNameTypeahead"
                                     onChange={this.handleTypeaheadChange}
@@ -660,10 +653,10 @@ export class Security extends React.Component {
                             </Col>
                         </Row>
                         <Row className="ds-margin-top" title="The minimum SSL/TLS version the server will accept (sslversionmin).">
-                            <Col componentClass={ControlLabel} sm={3}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 Minimum TLS Version
                             </Col>
-                            <Col sm={4}>
+                            <Col sm={8}>
                                 <select id="sslVersionMin" className="btn btn-default dropdown ds-select" onChange={this.handleChange} value={this.state.sslVersionMin}>
                                     <option>TLS1.3</option>
                                     <option>TLS1.2</option>
@@ -674,7 +667,7 @@ export class Security extends React.Component {
                             </Col>
                         </Row>
                         <Row className="ds-margin-top" title="The maximum SSL/TLS version the server will accept (sslversionmax).">
-                            <Col componentClass={ControlLabel} sm={3}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 Maximum TLS Version
                             </Col>
                             <Col sm={4}>
@@ -688,7 +681,7 @@ export class Security extends React.Component {
                             </Col>
                         </Row>
                         <Row className="ds-margin-top" title="Sets how the Directory Server enforces TLS client authentication (nsSSLClientAuth).">
-                            <Col componentClass={ControlLabel} sm={3}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 Client Authentication
                             </Col>
                             <Col sm={4}>
@@ -700,7 +693,7 @@ export class Security extends React.Component {
                             </Col>
                         </Row>
                         <Row className="ds-margin-top" title="Validate server's certificate expiration date (nsslapd-validate-cert).">
-                            <Col componentClass={ControlLabel} sm={3}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 Validate Certificate
                             </Col>
                             <Col sm={4}>
@@ -711,9 +704,8 @@ export class Security extends React.Component {
                                 </select>
                             </Col>
                         </Row>
-                        <p />
-                        <Row>
-                            <Col sm={5}>
+                        <Row className="ds-margin-top">
+                            <Col componentClass={ControlLabel} sm={4}>
                                 <Checkbox
                                     id="requireSecureBinds"
                                     defaultChecked={this.state.requireSecureBinds}
@@ -725,7 +717,7 @@ export class Security extends React.Component {
                             </Col>
                         </Row>
                         <Row>
-                            <Col sm={5}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 <Checkbox
                                     id="checkHostname"
                                     defaultChecked={this.state.checkHostname}
@@ -737,7 +729,7 @@ export class Security extends React.Component {
                             </Col>
                         </Row>
                         <Row>
-                            <Col sm={5}>
+                            <Col componentClass={ControlLabel} sm={4}>
                                 <Checkbox
                                     id="allowWeakCipher"
                                     defaultChecked={this.state.allowWeakCipher}
@@ -748,25 +740,44 @@ export class Security extends React.Component {
                                 </Checkbox>
                             </Col>
                         </Row>
-                        <p />
+                        <Row>
+                            <Col componentClass={ControlLabel} sm={4}>
+                                <Checkbox
+                                    id="nstlsallowclientrenegotiation"
+                                    defaultChecked={this.state.nstlsallowclientrenegotiation}
+                                    onChange={this.handleChange}
+                                    title="Allow client-initiated renegotiation (nsTLSAllowClientRenegotiation)."
+                                >
+                                    Allow Client Renegotiation
+                                </Checkbox>
+                            </Col>
+                        </Row>
                         <Button
                             bsStyle="primary"
-                            className="ds-margin-top-med"
+                            className="ds-margin-top-lg"
                             onClick={() => {
                                 this.saveSecurityConfig();
                             }}
                         >
                             Save Configuration
                         </Button>
-                    </div>;
+                    </Form>;
             }
 
             securityPage =
                 <div className="container-fluid">
-                    <NotificationController
-                        notifications={this.state.notifications}
-                        removeNotificationAction={this.removeNotification}
-                    />
+                    <Row>
+                        <Col sm={11}>
+                            <ControlLabel className="ds-suffix-header">
+                                Security Settings
+                                <Icon className="ds-left-margin ds-refresh"
+                                    type="fa" name="refresh" title="Refresh configuration settings"
+                                    onClick={this.reloadConfig}
+                                />
+                            </ControlLabel>
+                        </Col>
+                    </Row>
+
                     <div className="ds-tab-table">
                         <TabContainer id="basic-tabs-pf" onSelect={this.handleNavSelect} activeKey={this.state.activeKey}>
                             <div>
@@ -785,23 +796,17 @@ export class Security extends React.Component {
                                     <TabPane eventKey={1}>
                                         <div className="ds-margin-top-xlg ds-indent">
                                             <Row>
-                                                <Col componentClass={ControlLabel} sm={2}>
-                                                    Security Enabled
-                                                </Col>
-                                                <Col sm={1}>
+                                                <Col sm={11}>
+                                                    <ControlLabel>
+                                                        Security Enabled
+                                                    </ControlLabel>
                                                     <Switch
-                                                        className="ds-switch"
+                                                        className="ds-switch ds-margin-left-sm ds-lower-field"
                                                         onChange={this.handleSwitchChange}
                                                         checked={this.state.securityEnabled}
                                                         height={20}
                                                     />
                                                 </Col>
-                                                <Col>
-                                                    <Icon className="ds-left-margin ds-refresh"
-                                                        type="fa" name="refresh" title="Refresh security settings"
-                                                        onClick={this.loadSecurityConfig}
-                                                    />
-                                                </Col>
                                             </Row>
                                             <hr />
                                             {configPage}
@@ -814,7 +819,7 @@ export class Security extends React.Component {
                                                 serverId={this.props.serverId}
                                                 CACerts={this.state.CACerts}
                                                 ServerCerts={this.state.serverCerts}
-                                                addNotification={this.addNotification}
+                                                addNotification={this.props.addNotification}
                                             />
                                         </div>
                                     </TabPane>
@@ -826,7 +831,7 @@ export class Security extends React.Component {
                                                 supportedCiphers={this.state.supportedCiphers}
                                                 cipherPref={this.state.cipherPref}
                                                 enabledCiphers={this.state.enabledCiphers}
-                                                addNotification={this.addNotification}
+                                                addNotification={this.props.addNotification}
                                             />
                                         </div>
                                     </TabPane>
@@ -877,10 +882,12 @@ export class Security extends React.Component {
 // Props and defaultProps
 
 Security.propTypes = {
+    addNotification: PropTypes.func,
     serverId: PropTypes.string,
 };
 
 Security.defaultProps = {
+    addNotification: noop,
     serverId: "",
 };
 
