@@ -24,15 +24,8 @@ var info = {
         index: ["./index.es6"]
     },
     files: [
-        "banner.html",
         "css",
-        "ds.js",
-        "fonts",
-        "images",
         "index.html",
-        "servers.html",
-        "servers.js",
-        "static",
         "manifest.json"
     ]
 };
@@ -174,5 +167,9 @@ module.exports = {
             }
         ]
     },
-    plugins: plugins
+    plugins: plugins,
+    watchOptions: {
+        poll: true,
+        ignored: /node_modules/
+    }
 };
