@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2016 Red Hat, Inc.
+# Copyright (C) 2019 Red Hat, Inc.
 # Copyright (C) 2019 William Brown <william@blackhats.net.au>
 # All rights reserved.
 #
@@ -13,12 +13,11 @@ from ldap import filter as ldap_filter
 import logging
 import json
 from functools import partial
-
 from lib389._entry import Entry
-from lib389._constants import DIRSRV_STATE_ONLINE, SER_ROOT_DN, SER_ROOT_PW
+from lib389._constants import DIRSRV_STATE_ONLINE
 from lib389.utils import (
         ensure_bytes, ensure_str, ensure_int, ensure_list_bytes, ensure_list_str,
-        ensure_list_int
+        ensure_list_int, display_log_value, display_log_data
         )
 
 # This function filter and term generation provided thanks to
@@ -56,6 +55,8 @@ def _gen_not(extra=None):
 
 def _gen_filter(attrtypes, values, extra=None):
     filt = ''
+    if attrtypes is None:
+        raise ValueError("Attempting to filter on type that doesn't support filtering!")
     for attr, value in zip(attrtypes, values):
         if attr is not None and value is not None:
             filt += '(%s=%s)' % (attr, ldap_filter.escape_filter_chars(value))
@@ -105,7 +106,7 @@ class DSLdapObject(DSLogging):
         self._rdn_attribute = None
         self._must_attributes = None
         # attributes, we don't want to compare
-        self._compare_exclude = ['entryid']
+        self._compare_exclude = ['entryid', 'modifytimestamp', 'nsuniqueid']
         self._lint_functions = None
         self._server_controls = None
         self._client_controls = None
@@ -121,13 +122,15 @@ class DSLdapObject(DSLogging):
     def __str__(self):
         return self.__unicode__()
 
-    def raw_entry(self):
+    def _unsafe_raw_entry(self):
         """Get an Entry object
 
         :returns: Entry object
         """
 
-        return self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=["*"], serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+        return self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=["*"],
+                                           serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                           escapehatch='i am sure')[0]
 
     def exists(self):
         """Check if the entry exists
@@ -136,19 +139,22 @@ class DSLdapObject(DSLogging):
         """
 
         try:
-            self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrsonly=1, serverctrls=self._server_controls, clientctrls=self._client_controls)
+            self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrsonly=1,
+                                        serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                        escapehatch='i am sure')
         except ldap.NO_SUCH_OBJECT:
             return False
 
         return True
 
-    def display(self):
+    def display(self, attrlist=['*']):
         """Get an entry but represent it as a string LDIF
 
         :returns: LDIF formatted string
         """
-
-        e = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=["*"], serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+        e = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=attrlist,
+                                        serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                        escapehatch='i am sure')[0]
         return e.__repr__()
 
     def display_attr(self, attr):
@@ -172,7 +178,7 @@ class DSLdapObject(DSLogging):
         # ensure all the keys are lowercase
         str_attrs = dict((k.lower(), v) for k, v in list(str_attrs.items()))
 
-        response = json.dumps({"type": "entry", "dn": ensure_str(self._dn), "attrs": str_attrs})
+        response = json.dumps({"type": "entry", "dn": ensure_str(self._dn), "attrs": str_attrs}, indent=4)
 
         return response
 
@@ -189,6 +195,8 @@ class DSLdapObject(DSLogging):
             int_name = name.replace('_json', '')
             pfunc = partial(self._jsonify, getattr(self, int_name))
             return pfunc
+        else:
+            raise AttributeError("'%s' object has no attribute '%s'" % (self.__class__.__name__, name))
 
     # We make this a property so that we can over-ride dynamically if needed
     @property
@@ -210,6 +218,17 @@ class DSLdapObject(DSLogging):
         # How can we be sure this returns the primary one?
         return ensure_str(self.get_attr_val(self._rdn_attribute))
 
+    def get_basedn(self):
+        """Get the suffix this entry belongs to
+        """
+        from lib389.backend import Backends
+        backends = Backends(self._instance).list()
+        for backend in backends:
+            suffix = backend.get_suffix()
+            if self._dn.endswith(suffix):
+                return suffix
+        return ""
+
     def present(self, attr, value=None):
         """Assert that some attr, or some attr / value exist on the entry.
 
@@ -225,7 +244,9 @@ class DSLdapObject(DSLogging):
             raise ValueError("Invalid state. Cannot get presence on instance that is not ONLINE")
         self._log.debug("%s present(%r) %s" % (self._dn, attr, value))
 
-        e = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=[attr, ], serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+        self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=[attr, ],
+                                        serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                        escapehatch='i am sure')[0]
         values = self.get_attr_vals_bytes(attr)
         self._log.debug("%s contains %s" % (self._dn, values))
 
@@ -273,12 +294,13 @@ class DSLdapObject(DSLogging):
 
         mods = []
         for arg in args:
-            if isinstance(arg[1], list):
+            if isinstance(arg[1], list) or isinstance(arg[1], tuple):
                 value = ensure_list_bytes(arg[1])
             else:
                 value = [ensure_bytes(arg[1])]
             mods.append((ldap.MOD_REPLACE, ensure_str(arg[0]), value))
-        return self._instance.modify_ext_s(self._dn, mods, serverctrls=self._server_controls, clientctrls=self._client_controls)
+        return self._instance.modify_ext_s(self._dn, mods, serverctrls=self._server_controls,
+                                           clientctrls=self._client_controls, escapehatch='i am sure')
 
     # This needs to work on key + val, and key
     def remove(self, key, value):
@@ -332,6 +354,55 @@ class DSLdapObject(DSLogging):
         if self.present(attr, value):
             self.remove(attr, value)
 
+    def ensure_attr_state(self, state):
+        """
+        Given a dict of attr-values, ensure they are in the same state on the entry. This is
+        a stateful assertion, generally used by things like PATCH in a REST api.
+
+        The format is:
+            {
+                'attr_1': ['value', 'value'],
+                'attr_2': [],
+            }
+
+        If a value is present in the list, but not in the entry it is ADDED.
+        If a value is NOT present in the list, and is on the entry, it is REMOVED.
+        If a value is an empty list [], the attr is REMOVED from the entry.
+        If an attr is not named in the dictionary, it is not altered.
+
+        This function is atomic - all changes are applied or none are. There are no
+        partial updates.
+
+        This function is idempotent - submitting the same request twice will cause no
+        action to be taken as we are ensuring a state, not listing actions to take.
+
+        :param state: The entry ava state
+        :type state: dict
+        """
+        self._log.debug('ensure_state')
+        # Get all our entry/attrs in a single batch
+        entry_state = self.get_attrs_vals_utf8(state.keys())
+
+        # Check what is present/is not present to work out what has to change.
+        modlist = []
+        for (attr, values) in state.items():
+            value_set = set(values)
+            entry_set = set(entry_state.get(attr, []))
+
+            # Set difference, is "all items in s but not t".
+            value_add = value_set - entry_set
+            value_rem = entry_set - value_set
+
+            for value in value_add:
+                modlist.append((ldap.MOD_ADD, attr, value))
+            for value in value_rem:
+                modlist.append((ldap.MOD_DELETE, attr, value))
+
+        self._log.debug('Applying modlist: %s' % modlist)
+        # Apply it!
+        if len(modlist) > 0:
+            self.apply_mods(modlist)
+
     # maybe this could be renamed?
     def set(self, key, value, action=ldap.MOD_REPLACE):
         """Perform a specified action on a key with value
@@ -360,7 +431,7 @@ class DSLdapObject(DSLogging):
             action_txt = "UNKNOWN"
 
         if value is None or len(value) < 512:
-            self._log.debug("%s set %s: (%r, %r)" % (self._dn, action_txt, key, value))
+            self._log.debug("%s set %s: (%r, %r)" % (self._dn, action_txt, key, display_log_value(key, value)))
         else:
             self._log.debug("%s set %s: (%r, value too large)" % (self._dn, action_txt, key))
         if self._instance.state != DIRSRV_STATE_ONLINE:
@@ -373,7 +444,8 @@ class DSLdapObject(DSLogging):
             value = [ensure_bytes(value)]
 
         return self._instance.modify_ext_s(self._dn, [(action, key, value)],
-             serverctrls=self._server_controls, clientctrls=self._client_controls)
+                                           serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                           escapehatch='i am sure')
 
     def apply_mods(self, mods):
         """Perform modification operation using several mods at once
@@ -411,7 +483,24 @@ class DSLdapObject(DSLogging):
             else:
                 # Error too many items
                 raise ValueError('Too many arguments in the mod op')
-        return self._instance.modify_ext_s(self._dn, mod_list, serverctrls=self._server_controls, clientctrls=self._client_controls)
+        return self._instance.modify_ext_s(self._dn, mod_list, serverctrls=self._server_controls, clientctrls=self._client_controls, escapehatch='i am sure')
+
+    def _unsafe_compare_attribute(self, other):
+        """Compare two attributes from two objects. This is currently marked unsafe as it's
+        not complete yet.
+
+        The idea is to use the native ldap compare operation, rather than simple comparison of
+        values due to schema awareness. LDAP doesn't normalise values, so two objects with:
+
+        cn: value
+        cn: VaLuE
+
+        This will fail to compare in python, but would succeed in LDAP beacuse CN is case
+        insensitive.
+
+        To allow schema aware checking, we need to call ldap compare extop here.
+        """
+        pass
 
     @classmethod
     def compare(cls, obj1, obj2):
@@ -442,16 +531,20 @@ class DSLdapObject(DSLogging):
             raise ValueError("Invalid arguments: Expecting object types that inherits 'DSLdapObject' class")
         # check if RDN of objects is same
         if obj1.rdn != obj2.rdn:
+            obj1._log.debug("%s != %s" % (obj1.rdn, obj2.rdn))
             return False
         obj1_attrs = obj1.get_compare_attrs()
         obj2_attrs = obj2.get_compare_attrs()
         # Bail fast if the keys don't match
         if set(obj1_attrs.keys()) != set(obj2_attrs.keys()):
+            obj1._log.debug("%s != %s" % (obj1_attrs.keys(), obj2_attrs.keys()))
             return False
         # Check the values of each key
         # using obj1_attrs.keys() because obj1_attrs.iterkleys() is not supported in python3
         for key in obj1_attrs.keys():
             if set(obj1_attrs[key]) != set(obj2_attrs[key]):
+                obj1._log.debug("  v-- %s != %s" % (key, key))
+                obj1._log.debug("%s != %s" % (obj1_attrs[key], obj2_attrs[key]))
                 return False
         return True
 
@@ -461,10 +554,18 @@ class DSLdapObject(DSLogging):
         """
 
         self._log.debug("%s get_compare_attrs" % (self._dn))
+
         all_attrs_dict = self.get_all_attrs()
+        all_attrs_lower = {}
+        for k in all_attrs_dict:
+            all_attrs_lower[k.lower()] = all_attrs_dict[k]
+
         # removing _compate_exclude attrs from all attrs
-        compare_attrs = set(all_attrs_dict.keys()) - set(self._compare_exclude)
-        compare_attrs_dict = {attr:all_attrs_dict[attr] for attr in compare_attrs}
+        cx = [x.lower() for x in self._compare_exclude]
+        compare_attrs = set(all_attrs_lower.keys()) - set(cx)
+
+        compare_attrs_dict = {attr.lower(): all_attrs_lower[attr] for attr in compare_attrs}
+
         return compare_attrs_dict
 
     def get_all_attrs(self, use_json=False):
@@ -478,19 +579,58 @@ class DSLdapObject(DSLogging):
             raise ValueError("Invalid state. Cannot get properties on instance that is not ONLINE")
         else:
             # retrieving real(*) and operational attributes(+)
-            attrs_entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=["*", "+"], serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+            attrs_entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter,
+                                                      attrlist=["*", "+"], serverctrls=self._server_controls,
+                                                      clientctrls=self._client_controls, escapehatch='i am sure')[0]
             # getting dict from 'entry' object
             attrs_dict = attrs_entry.data
+            # Should we normalise the attr names here to lower()?
+            # This could have unforseen consequences ...
             return attrs_dict
 
+    def get_all_attrs_utf8(self, use_json=False):
+        """Get a dictionary having all the attributes of the entry
+
+        :returns: Dict with real attributes and operational attributes
+        """
+
+        self._log.debug("%s get_all_attrs" % (self._dn))
+        if self._instance.state != DIRSRV_STATE_ONLINE:
+            raise ValueError("Invalid state. Cannot get properties on instance that is not ONLINE")
+        else:
+            # retrieving real(*) and operational attributes(+)
+            attrs_entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter,
+                                                      attrlist=["*", "+"], serverctrls=self._server_controls,
+                                                      clientctrls=self._client_controls, escapehatch='i am sure')[0]
+            # getting dict from 'entry' object
+            r = {}
+            for (k, vo) in attrs_entry.data.items():
+                r[k] = ensure_list_str(vo)
+            return r
+
     def get_attrs_vals(self, keys, use_json=False):
         self._log.debug("%s get_attrs_vals(%r)" % (self._dn, keys))
         if self._instance.state != DIRSRV_STATE_ONLINE:
             raise ValueError("Invalid state. Cannot get properties on instance that is not ONLINE")
         else:
-            entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=keys, serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+            entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter,
+                                                attrlist=keys, serverctrls=self._server_controls,
+                                                clientctrls=self._client_controls, escapehatch='i am sure')[0]
             return entry.getValuesSet(keys)
 
+    def get_attrs_vals_utf8(self, keys, use_json=False):
+        self._log.debug("%s get_attrs_vals_utf8(%r)" % (self._dn, keys))
+        if self._instance.state != DIRSRV_STATE_ONLINE:
+            raise ValueError("Invalid state. Cannot get properties on instance that is not ONLINE")
+        entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=keys,
+                                            serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                            escapehatch='i am sure')[0]
+        vset = entry.getValuesSet(keys)
+        r = {}
+        for (k, vo) in vset.items():
+            r[k] = ensure_list_str(vo)
+        return r
+
     def get_attr_vals(self, key, use_json=False):
         self._log.debug("%s get_attr_vals(%r)" % (self._dn, key))
         # We might need to add a state check for NONE dn.
@@ -501,7 +641,9 @@ class DSLdapObject(DSLogging):
         else:
             # It would be good to prevent the entry code intercepting this ....
             # We have to do this in this method, because else we ignore the scope base.
-            entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=[key], serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+            entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter,
+                                                attrlist=[key], serverctrls=self._server_controls,
+                                                clientctrls=self._client_controls, escapehatch='i am sure')[0]
             vals = entry.getValues(key)
             if use_json:
                 result = {key: []}
@@ -519,7 +661,9 @@ class DSLdapObject(DSLogging):
             # In the future, I plan to add a mode where if local == true, we
             # can use get on dse.ldif to get values offline.
         else:
-            entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter, attrlist=[key], serverctrls=self._server_controls, clientctrls=self._client_controls)[0]
+            entry = self._instance.search_ext_s(self._dn, ldap.SCOPE_BASE, self._object_filter,
+                                                attrlist=[key], serverctrls=self._server_controls,
+                                                clientctrls=self._client_controls, escapehatch='i am sure')[0]
             return entry.getValue(key)
 
     def get_attr_val_bytes(self, key, use_json=False):
@@ -626,7 +770,7 @@ class DSLdapObject(DSLogging):
         pass
 
     # Modifies the DN of an entry to the new fqdn provided
-    def rename(self, new_rdn, newsuperior=None):
+    def rename(self, new_rdn, newsuperior=None, deloldrdn=True):
         """Renames the object within the tree.
 
         If you provide a newsuperior, this will move the object in the tree.
@@ -647,9 +791,11 @@ class DSLdapObject(DSLogging):
         # and the superior as the base (if it changed)
         if self._protected:
             return
-        self._instance.rename_s(self._dn, new_rdn, newsuperior, serverctrls=self._server_controls, clientctrls=self._client_controls)
-        search_base = self._basedn
-        if newsuperior != None:
+
+        self._instance.rename_s(self._dn, new_rdn, newsuperior,
+                                serverctrls=self._server_controls, clientctrls=self._client_controls,
+                                delold=deloldrdn, escapehatch='i am sure')
+        if newsuperior is not None:
             # Well, the new DN should be rdn + newsuperior.
             self._dn = '%s,%s' % (new_rdn, newsuperior)
         else:
@@ -661,7 +807,7 @@ class DSLdapObject(DSLogging):
 
         # assert we actually got the change right ....
 
-    def delete(self):
+    def delete(self, recursive=False):
         """Deletes the object defined by self._dn.
         This can be changed with the self._protected flag!
         """
@@ -669,7 +815,13 @@ class DSLdapObject(DSLogging):
         self._log.debug("%s delete" % (self._dn))
         if not self._protected:
             # Is there a way to mark this as offline and kill it
-            self._instance.delete_ext_s(self._dn, serverctrls=self._server_controls, clientctrls=self._client_controls)
+            if recursive:
+                filterstr = "(|(objectclass=*)(objectclass=ldapsubentry))"
+                ents = self._instance.search_s(self._dn, ldap.SCOPE_SUBTREE, filterstr, escapehatch='i am sure')
+                for ent in sorted(ents, key=lambda e: len(e.dn), reverse=True):
+                    self._instance.delete_ext_s(ent.dn, serverctrls=self._server_controls, clientctrls=self._client_controls, escapehatch='i am sure')
+            else:
+                self._instance.delete_ext_s(self._dn, serverctrls=self._server_controls, clientctrls=self._client_controls, escapehatch='i am sure')
 
     def _validate(self, rdn, properties, basedn):
         """Used to validate a create request.
@@ -712,14 +864,19 @@ class DSLdapObject(DSLogging):
                 # Turn it into a list instead.
                 properties[k] = [v, ]
 
-        # This change here, means we can pre-load a full dn to _dn, or we can
-        # accept based on the rdn
+        # If we were created with a dn= in the object init, we set tdn now, and skip
+        # any possible dn derivation steps that follow.
         tdn = self._dn
 
+        # However, if no DN was provided, we attempt to derive the DN from the relevant
+        # properties of the object. The idea being that by defining only the attributes
+        # of the object, we can just solve a possible rdn instead of asking for the same
+        # data twice.
         if tdn is None:
             if basedn is None:
                 raise ldap.UNWILLING_TO_PERFORM('Invalid request to create. basedn cannot be None')
 
+            # Were we given a relative component? Yes? Go ahead!
             if rdn is not None:
                 tdn = ensure_str('%s,%s' % (rdn, basedn))
             elif properties.get(self._rdn_attribute, None) is not None:
@@ -750,19 +907,22 @@ class DSLdapObject(DSLogging):
         """
         assert(len(self._create_objectclasses) > 0)
         basedn = ensure_str(basedn)
-        self._log.debug('Checking "%s" under %s : %s' % (rdn, basedn, properties))
+        self._log.debug('Checking "%s" under %s : %s' % (rdn, basedn, display_log_data(properties)))
         # Add the objectClasses to the properties
         (dn, valid_props) = self._validate(rdn, properties, basedn)
         # Check if the entry exists or not? .add_s is going to error anyway ...
-        self._log.debug('Validated dn %s : valid_props %s' % (dn, valid_props))
+        self._log.debug('Validated dn {}'.format(dn))
 
         exists = False
 
-        try:
-            self._instance.search_ext_s(dn, ldap.SCOPE_BASE, self._object_filter, attrsonly=1, serverctrls=self._server_controls, clientctrls=self._client_controls)
-            exists = True
-        except ldap.NO_SUCH_OBJECT:
-            pass
+        if ensure:
+            # If we are running in stateful ensure mode, we need to check if the object exists, and
+            # we can see the state that it is in.
+            try:
+                self._instance.search_ext_s(dn, ldap.SCOPE_BASE, self._object_filter, attrsonly=1, serverctrls=self._server_controls, clientctrls=self._client_controls, escapehatch='i am sure')
+                exists = True
+            except ldap.NO_SUCH_OBJECT:
+                pass
 
         if exists and ensure:
             # update properties
@@ -772,20 +932,28 @@ class DSLdapObject(DSLogging):
             mods = []
             for k, v in list(valid_props.items()):
                 mods.append((ldap.MOD_REPLACE, k, v))
-            self._instance.modify_ext_s(self._dn, mods, serverctrls=self._server_controls, clientctrls=self._client_controls)
-        elif exists and not ensure:
-            # raise "already exists."
-            raise ldap.ALREADY_EXISTS("Entry %s already exists" % dn)
-        if not exists:
+            self._instance.modify_ext_s(self._dn, mods, serverctrls=self._server_controls, clientctrls=self._client_controls, escapehatch='i am sure')
+        elif not exists:
+            # This case is reached in two cases. One is we are in ensure mode, and we KNOW the entry
+            # doesn't exist.
+            # The alternate, is that we are in a non-stateful create, so we "just create" and see
+            # what happens. I believe the technical term is "yolo create".
             self._log.debug('Creating %s' % dn)
             e = Entry(dn)
             e.update({'objectclass': ensure_list_bytes(self._create_objectclasses)})
             e.update(valid_props)
             # We rely on exceptions here to indicate failure to the parent.
-            self._log.debug('Creating entry %s : %s' % (dn, e))
-            self._instance.add_ext_s(e, serverctrls=self._server_controls, clientctrls=self._client_controls)
-            # If it worked, we need to fix our instance dn
+            self._instance.add_ext_s(e, serverctrls=self._server_controls, clientctrls=self._client_controls, escapehatch='i am sure')
+            self._log.debug('Created entry %s : %s' % (dn, display_log_data(e.data)))
+            # If it worked, we need to fix our instance dn for the object's self reference. Because
+            # we may not have a self reference yet (just created), it may have changed (someone
+            # set dn, but validate altered it).
             self._dn = dn
+        else:
+            # This case can't be reached now that we only check existance on ensure.
+            # However, it's good to keep it for "complete" behaviour, exhausting all states.
+            # We could highlight bugs ;)
+            raise AssertionError("Impossible State Reached in _create")
         return self
 
     def create(self, rdn=None, properties=None, basedn=None):
@@ -840,9 +1008,9 @@ class DSLdapObject(DSLogging):
             return None
         results = []
         for fn in self._lint_functions:
-            result = fn()
-            if result:
-                results.append(result)
+            for result in fn():
+                if result is not None:
+                    results.append(result)
         return results
 
 
@@ -857,7 +1025,7 @@ class DSLdapObjects(DSLogging):
     :type instance: lib389.DirSrv
     """
 
-    def __init__(self, instance):
+    def __init__(self, instance, basedn=""):
         self._childobject = DSLdapObject
         self._instance = instance
         super(DSLdapObjects, self).__init__(self._instance.verbose)
@@ -865,7 +1033,7 @@ class DSLdapObjects(DSLogging):
         self._filterattrs = []
         self._list_attrlist = ['dn']
         # Copy this from the child if we need.
-        self._basedn = ""
+        self._basedn = basedn
         self._scope = ldap.SCOPE_SUBTREE
         self._server_controls = None
         self._client_controls = None
@@ -875,6 +1043,16 @@ class DSLdapObjects(DSLogging):
             _gen_filter(_term_gen('objectclass'), self._objectclasses)
         )
 
+    def _get_selector_filter(self, selector):
+        return _gen_and([
+            self._get_objectclass_filter(),
+            _gen_or(
+                # This will yield all combinations of selector to filterattrs.
+                # This won't work with multiple values in selector (yet)
+                _gen_filter(self._filterattrs, _term_gen(selector))
+            ),
+        ])
+
     def _entry_to_instance(self, dn=None, entry=None):
         # Normally this won't be used. But for say the plugin type where we
         # have "many" possible child types, this allows us to overload
@@ -900,7 +1078,8 @@ class DSLdapObjects(DSLogging):
                 scope=self._scope,
                 filterstr=filterstr,
                 attrlist=self._list_attrlist,
-                serverctrls=self._server_controls, clientctrls=self._client_controls
+                serverctrls=self._server_controls, clientctrls=self._client_controls,
+                escapehatch='i am sure'
             )
             # def __init__(self, instance, dn=None):
             insts = [self._entry_to_instance(dn=r.dn, entry=r) for r in results]
@@ -909,6 +1088,25 @@ class DSLdapObjects(DSLogging):
             insts = []
         return insts
 
+    def exists(self, selector=[], dn=None):
+        """Check if a child entry exists
+
+        :returns: True if it exists
+        """
+        results = []
+        try:
+            if dn is not None:
+                results = self._get_dn(dn)
+            else:
+                results = self._get_selector(selector)
+        except:
+            return False
+
+        if len(results) == 1:
+            return True
+        else:
+            return False
+
     def get(self, selector=[], dn=None, json=False):
         """Get a child entry (DSLdapObject, Replica, etc.) with dn or selector
         using a base DN and objectClasses of our object (DSLdapObjects, Replicas, etc.)
@@ -948,28 +1146,23 @@ class DSLdapObjects(DSLogging):
             scope=ldap.SCOPE_BASE,
             filterstr=filterstr,
             attrlist=self._list_attrlist,
-            serverctrls=self._server_controls, clientctrls=self._client_controls
+            serverctrls=self._server_controls, clientctrls=self._client_controls,
+            escapehatch='i am sure'
         )
 
     def _get_selector(self, selector):
         # Filter based on the objectclasses and the basedn
         # Based on the selector, we should filter on that too.
         # This will yield and & filter for objectClass with as many terms as needed.
-        filterstr=_gen_and([
-            self._get_objectclass_filter(),
-            _gen_or(
-                # This will yield all combinations of selector to filterattrs.
-                # This won't work with multiple values in selector (yet)
-                _gen_filter(self._filterattrs, _term_gen(selector))
-            ),
-        ])
+        filterstr = self._get_selector_filter(selector)
         self._log.debug('_gen_selector filter = %s' % filterstr)
         return self._instance.search_ext_s(
             base=self._basedn,
             scope=self._scope,
             filterstr=filterstr,
             attrlist=self._list_attrlist,
-            serverctrls=self._server_controls, clientctrls=self._client_controls
+            serverctrls=self._server_controls, clientctrls=self._client_controls,
+            escapehatch='i am sure'
         )
 
     def _validate(self, rdn, properties):
@@ -1025,4 +1218,26 @@ class DSLdapObjects(DSLogging):
         # Now actually commit the creation req
         return co.ensure_state(rdn, properties, self._basedn)
 
-
+    def filter(self, search, scope=None):
+        # This will yield and & filter for objectClass with as many terms as needed.
+        if search:
+            search_filter = _gen_and([self._get_objectclass_filter(), search])
+        else:
+            search_filter = self._get_objectclass_filter()
+        if scope is None:
+            scope = self._scope
+        self._log.debug(f'list filter = {search_filter} with scope {scope}')
+        try:
+            results = self._instance.search_ext_s(
+                base=self._basedn,
+                scope=scope,
+                filterstr=search_filter,
+                attrlist=self._list_attrlist,
+                serverctrls=self._server_controls, clientctrls=self._client_controls
+            )
+            # def __init__(self, instance, dn=None):
+            insts = [self._entry_to_instance(dn=r.dn, entry=r) for r in results]
+        except ldap.NO_SUCH_OBJECT:
+            # There are no objects to select from, se we return an empty array
+            insts = []
+        return insts
