@@ -61,8 +61,8 @@ class Agreement(DSLdapObject):
         self.set('nsds5BeginReplicaRefresh', 'start')
 
     def check_reinit(self):
-        """Check the status of a reinit. Returns done and error. A correct
-        reinit will return (True, False).
+        """Check the status of a reinit. Returns done, inprogress, and error text. A correct
+        reinit will return (True, False, False).
 
         :returns: tuple(done, error), where done, error are bool.
         """
@@ -74,16 +74,16 @@ class Agreement(DSLdapObject):
         if not status:
             pass
         elif 'replica busy' in status:
-            error = True
+            error = status
         elif 'Total update succeeded' in status:
             done = True
             inprogress = False
         elif 'Replication error' in status:
-            error = True
+            error = status
         elif 'Total update in progress' in status:
             inprogress = True
         elif 'LDAP error' in status:
-            error = True
+            error = status
 
         return (done, inprogress, error)
 
@@ -105,6 +105,9 @@ class Agreement(DSLdapObject):
             time.sleep(2)
         return (done, error)
 
+    def get_name(self):
+        return self.get_attr_val_utf8_l('cn')
+
     def get_agmt_maxcsn(self):
         """Get the agreement maxcsn from the database RUV entry
         :returns: CSN string if found, otherwise None is returned
@@ -173,8 +176,10 @@ class Agreement(DSLdapObject):
         consumer.allocate(args_standalone)
         try:
             consumer.open()
+        except ldap.INVALID_CREDENTIALS as e:
+            raise(e)
         except ldap.LDAPError as e:
-            self._instance.log.debug('Connection to consumer ({}:{}) failed, error: {}'.format(host, port, e))
+            self._log.debug('Connection to consumer ({}:{}) failed, error: {}'.format(host, port, e))
             return result_msg
 
         # Search for the tombstone RUV entry
@@ -182,7 +187,7 @@ class Agreement(DSLdapObject):
             entry = consumer.search_s(suffix, ldap.SCOPE_SUBTREE,
                                       REPLICA_RUV_FILTER, ['nsds50ruv'])
             if not entry:
-                self.log.error("Failed to retrieve database RUV entry from consumer")
+                self._log.debug("Failed to retrieve database RUV entry from consumer")
             else:
                 elements = ensure_list_str(entry[0].getValues('nsds50ruv'))
                 for ruv in elements:
@@ -191,14 +196,16 @@ class Agreement(DSLdapObject):
                         if len(ruv_parts) == 5:
                             result_msg = ruv_parts[4]
                         break
+        except ldap.INVALID_CREDENTIALS as e:
+            raise(e)
         except ldap.LDAPError as e:
-            self._instance.log.debug('Failed to search for the suffix ' +
+            self._log.debug('Failed to search for the suffix ' +
                                      '({}) consumer ({}:{}) failed, error: {}'.format(
                                          suffix, host, port, e))
         consumer.close()
         return result_msg
 
-    def get_agmt_status(self, binddn=None, bindpw=None):
+    def get_agmt_status(self, binddn=None, bindpw=None, return_json=False):
         """Return the status message
         :param binddn: Specifies a specific bind DN to use when contacting the remote consumer
         :type binddn: str
@@ -207,28 +214,55 @@ class Agreement(DSLdapObject):
         :returns: A status message about the replication agreement
         """
         status = "Unknown"
+        con_maxcsn = "Unknown"
+        try:
+            agmt_maxcsn = self.get_agmt_maxcsn()
+            agmt_status = json.loads(self.get_attr_val_utf8_l(AGMT_UPDATE_STATUS_JSON))
+            if agmt_maxcsn is not None:
+                try:
+                    con_maxcsn = self.get_consumer_maxcsn(binddn=binddn, bindpw=bindpw)
+                    if con_maxcsn:
+                        if agmt_maxcsn == con_maxcsn:
+                            if return_json:
+                                return json.dumps({
+                                    'msg': "In Synchronization",
+                                    'agmt_maxcsn': agmt_maxcsn,
+                                    'con_maxcsn': con_maxcsn,
+                                    'state': agmt_status['state'],
+                                    'reason': agmt_status['message']
+                                })
+                            else:
+                                return "In Synchronization"
+                except:
+                    pass
+            else:
+                agmt_maxcsn = "Unknown"
 
-        agmt_maxcsn = self.get_agmt_maxcsn()
-        if agmt_maxcsn is not None:
-            con_maxcsn = self.get_consumer_maxcsn(binddn=binddn, bindpw=bindpw)
-            if con_maxcsn:
-                if agmt_maxcsn == con_maxcsn:
-                    status = "In Synchronization"
-                else:
-                    # Not in sync - attempt to discover the cause
-                    repl_msg = "Unknown"
-                    if self.get_attr_val_utf8(AGMT_UPDATE_IN_PROGRESS) == 'TRUE':
-                        # Replication is on going - this is normal
-                        repl_msg = "Replication still in progress"
-                    elif "Can't Contact LDAP" in \
-                         self.get_attr_val_utf8(AGMT_UPDATE_STATUS):
-                        # Consumer is down
-                        repl_msg = "Consumer can not be contacted"
+            # Not in sync - attempt to discover the cause
+            repl_msg = agmt_status['message']
+            if self.get_attr_val_utf8_l(AGMT_UPDATE_IN_PROGRESS) == 'true':
+                # Replication is on going - this is normal
+                repl_msg = "Replication still in progress"
+            elif "can't contact ldap" in agmt_status['message']:
+                    # Consumer is down
+                    repl_msg = "Consumer can not be contacted"
 
-                    status = ("Not in Synchronization: supplier " +
-                              "(%s) consumer (%s)  Reason(%s)" %
-                              (agmt_maxcsn, con_maxcsn, repl_msg))
-        return status
+            if return_json:
+                return json.dumps({
+                    'msg': "Not in Synchronization",
+                    'agmt_maxcsn': agmt_maxcsn,
+                    'con_maxcsn': con_maxcsn,
+                    'state': agmt_status['state'],
+                    'reason': repl_msg
+                })
+            else:
+                return ("Not in Synchronization: supplier " +
+                        "(%s) consumer (%s) State (%s) Reason (%s)" %
+                        (agmt_maxcsn, con_maxcsn, agmt_status['state'], repl_msg))
+        except ldap.INVALID_CREDENTIALS as e:
+            raise(e)
+        except ldap.LDAPError as e:
+            raise ValueError(str(e))
 
     def get_lag_time(self, suffix, agmt_name, binddn=None, bindpw=None):
         """Get the lag time between the supplier and the consumer
@@ -243,15 +277,21 @@ class Agreement(DSLdapObject):
         :returns: A time-formated string of the the replication lag (HH:MM:SS).
         :raises: ValueError - if unable to get consumer's maxcsn
         """
-        agmt_time = 0
-        agmt_maxcsn = self.get_agmt_maxcsn()
-        con_maxcsn = self.get_consumer_maxcsn(binddn=binddn, bindpw=bindpw)
+
+        try:
+            agmt_maxcsn = self.get_agmt_maxcsn()
+            con_maxcsn = self.get_consumer_maxcsn(binddn=binddn, bindpw=bindpw)
+        except ldap.LDAPError as e:
+            raise ValueError("Unable to get lag time: " + str(e))
+
         if con_maxcsn is None:
             raise ValueError("Unable to get consumer's max csn")
-        if con_maxcsn == "Unavailable":
+        if con_maxcsn.lower() == "unavailable":
             return con_maxcsn
 
         # Extract the csn timstamps and compare them
+        agmt_time = 0
+        con_time = 0
         match = Agreement.csnre.match(agmt_maxcsn)
         if match:
             agmt_time = int(match.group(1), 16)
@@ -292,6 +332,8 @@ class Agreement(DSLdapObject):
         if not winsync:
             try:
                 status = self.get_agmt_status(binddn=binddn, bindpw=bindpw)
+            except ldap.INVALID_CREDENTIALS as e:
+                raise(e)
             except ValueError as e:
                 status = str(e)
             if just_status:
@@ -305,6 +347,7 @@ class Agreement(DSLdapObject):
             agmt_name = ensure_str(status_attrs_dict['cn'][0])
             lag_time = self.get_lag_time(suffix, agmt_name, binddn=binddn, bindpw=bindpw)
         else:
+            lag_time = "Not available for Winsync agreements"
             status = "Not available for Winsync agreements"
 
         # handle the attributes that are not always set in the agreement
@@ -323,28 +366,33 @@ class Agreement(DSLdapObject):
         if ensure_str(status_attrs_dict['nsds5replicachangessentsincestartup'][0]) == '':
             status_attrs_dict['nsds5replicachangessentsincestartup'] = ['0']
 
+        consumer = "{}:{}".format(ensure_str(status_attrs_dict['nsds5replicahost'][0]),
+                                  ensure_str(status_attrs_dict['nsds5replicaport'][0]))
+
         # Case sensitive?
         if use_json:
-            result = {'replica-enabled': ensure_str(status_attrs_dict['nsds5replicaenabled'][0]),
-                      'update-in-progress': ensure_str(status_attrs_dict['nsds5replicaupdateinprogress'][0]),
-                      'last-update-start': ensure_str(status_attrs_dict['nsds5replicalastupdatestart'][0]),
-                      'last-update-end': ensure_str(status_attrs_dict['nsds5replicalastupdateend'][0]),
-                      'number-changes-sent': ensure_str(status_attrs_dict['nsds5replicachangessentsincestartup'][0]),
-                      'number-changes-skipped:': ensure_str(status_attrs_dict['nsds5replicachangesskippedsince'][0]),
-                      'last-update-status': ensure_str(status_attrs_dict['nsds5replicalastupdatestatus'][0]),
-                      'init-in-progress': ensure_str(status_attrs_dict['nsds5beginreplicarefresh'][0]),
-                      'last-init-start': ensure_str(status_attrs_dict['nsds5replicalastinitstart'][0]),
-                      'last-init-end': ensure_str(status_attrs_dict['nsds5replicalastinitend'][0]),
-                      'last-init-status': ensure_str(status_attrs_dict['nsds5replicalastinitstatus'][0]),
-                      'reap-active': ensure_str(status_attrs_dict['nsds5replicareapactive'][0]),
-                      'replication-status': status,
-                      'replication-lag-time': lag_time
+            result = {
+                      'agmt-name': ensure_list_str(status_attrs_dict['cn']),
+                      'replica': [consumer],
+                      'replica-enabled': ensure_list_str(status_attrs_dict['nsds5replicaenabled']),
+                      'update-in-progress': ensure_list_str(status_attrs_dict['nsds5replicaupdateinprogress']),
+                      'last-update-start': ensure_list_str(status_attrs_dict['nsds5replicalastupdatestart']),
+                      'last-update-end': ensure_list_str(status_attrs_dict['nsds5replicalastupdateend']),
+                      'number-changes-sent': ensure_list_str(status_attrs_dict['nsds5replicachangessentsincestartup']),
+                      'number-changes-skipped': ensure_list_str(status_attrs_dict['nsds5replicachangesskippedsince']),
+                      'last-update-status': ensure_list_str(status_attrs_dict['nsds5replicalastupdatestatus']),
+                      'last-init-start': ensure_list_str(status_attrs_dict['nsds5replicalastinitstart']),
+                      'last-init-end': ensure_list_str(status_attrs_dict['nsds5replicalastinitend']),
+                      'last-init-status': ensure_list_str(status_attrs_dict['nsds5replicalastinitstatus']),
+                      'reap-active': ensure_list_str(status_attrs_dict['nsds5replicareapactive']),
+                      'replication-status': [status],
+                      'replication-lag-time': [lag_time]
                 }
             return (json.dumps(result))
         else:
             retstr = (
-                "Status for %(cn)s agmt %(nsDS5ReplicaHost)s:"
-                "%(nsDS5ReplicaPort)s" "\n"
+                "Status For Agreement: \"%(cn)s\" (%(nsDS5ReplicaHost)s:"
+                "%(nsDS5ReplicaPort)s)" "\n"
                 "Replica Enabled: %(nsds5ReplicaEnabled)s" "\n"
                 "Update In Progress: %(nsds5replicaUpdateInProgress)s" "\n"
                 "Last Update Start: %(nsds5replicaLastUpdateStart)s" "\n"
@@ -354,7 +402,6 @@ class Agreement(DSLdapObject):
                 "Number Of Changes Skipped: %(nsds5replicaChangesSkippedSince"
                 "Startup)s" "\n"
                 "Last Update Status: %(nsds5replicaLastUpdateStatus)s" "\n"
-                "Init In Progress: %(nsds5BeginReplicaRefresh)s" "\n"
                 "Last Init Start: %(nsds5ReplicaLastInitStart)s" "\n"
                 "Last Init End: %(nsds5ReplicaLastInitEnd)s" "\n"
                 "Last Init Status: %(nsds5ReplicaLastInitStatus)s" "\n"
@@ -944,7 +991,7 @@ class AgreementLegacy(object):
         # we can just raise ALREADY_EXISTS
         try:
             entry = self.conn.getEntry(dn_agreement, ldap.SCOPE_BASE)
-            self.log.warn("Agreement already exists: %r", dn_agreement)
+            self.log.warning("Agreement already exists: %r", dn_agreement)
             return dn_agreement
         except ldap.NO_SUCH_OBJECT:
             entry = None
