@@ -7,10 +7,11 @@
 # --- END COPYRIGHT BLOCK ---
 
 from datetime import datetime
+import copy
 import ldap
 from lib389._constants import *
 from lib389.properties import *
-from lib389.utils import normalizeDN, ensure_str, ensure_bytes
+from lib389.utils import normalizeDN, ensure_str, ensure_bytes,  assert_c
 from lib389 import Entry
 
 # Need to fix this ....
@@ -18,6 +19,9 @@ from lib389 import Entry
 from lib389._mapped_object import DSLdapObjects, DSLdapObject
 from lib389.mappingTree import MappingTrees
 from lib389.exceptions import NoSuchEntryError, InvalidArgumentError
+from lib389.replica import Replicas
+from lib389.cos import (CosTemplates, CosIndirectDefinitions,
+                        CosPointerDefinitions, CosClassicDefinitions)
 
 # We need to be a factor to the backend monitor
 from lib389.monitor import MonitorBackend
@@ -29,7 +33,7 @@ from lib389.encrypted_attributes import EncryptedAttr, EncryptedAttrs
 # This is for sample entry creation.
 from lib389.configurations import get_sample_entries
 
-from lib389.lint import DSBLE0001
+from lib389.lint import DSBLE0001, DSBLE0002, DSBLE0003, DSVIRTLE0001
 
 
 class BackendLegacy(object):
@@ -337,11 +341,11 @@ class BackendLegacy(object):
 
     def getProperties(self, suffix=None, backend_dn=None, bename=None,
                       properties=None):
-        raise NotImplemented
+        raise NotImplementedError
 
     def setProperties(self, suffix=None, backend_dn=None, bename=None,
                       properties=None):
-        raise NotImplemented
+        raise NotImplementedError
 
     def toSuffix(self, entry=None, name=None):
         '''
@@ -409,10 +413,92 @@ class Backend(DSLdapObject):
         self._must_attributes = ['nsslapd-suffix', 'cn']
         self._create_objectclasses = ['top', 'extensibleObject', BACKEND_OBJECTCLASS_VALUE]
         self._protected = False
-        self._lint_functions = [self._lint_mappingtree]
+        self._lint_functions = [self._lint_mappingtree, self._lint_search, self._lint_virt_attrs]
         # Check if a mapping tree for this suffix exists.
         self._mts = MappingTrees(self._instance)
 
+    def _lint_virt_attrs(self):
+        """Check if any virtual attribute are incorrectly indexed"""
+        indexes = self.get_indexes()
+        suffix = self.get_attr_val_utf8('nsslapd-suffix')
+
+        # First check nsrole
+        try:
+            indexes.get('nsrole')
+            report = copy.deepcopy(DSVIRTLE0001)
+            report['detail'] = report['detail'].replace('ATTR', 'nsrole')
+            report['fix'] = report['fix'].replace('ATTR', 'nsrole')
+            report['fix'] = report['fix'].replace('SUFFIX', suffix)
+            report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+            report['items'].append(suffix)
+            report['items'].append('nsrole')
+            yield report
+        except:
+            pass
+
+        # Check COS next
+        for cosDefType in [CosIndirectDefinitions, CosPointerDefinitions, CosClassicDefinitions]:
+            defs = cosDefType(self._instance, suffix).list()
+            for cosDef in defs:
+                attrs = cosDef.get_attr_val_utf8_l("cosAttribute").split()
+                for attr in attrs:
+                    if attr in ["default", "override", "operational", "operational-default", "merge-schemes"]:
+                        # We are at the end, just break out
+                        break
+                    try:
+                        indexes.get(attr)
+                        # If we got here there is an index (bad)
+                        report = copy.deepcopy(DSVIRTLE0001)
+                        report['detail'] = report['detail'].replace('ATTR', attr)
+                        report['fix'] = report['fix'].replace('ATTR', attr)
+                        report['fix'] = report['fix'].replace('SUFFIX', suffix)
+                        report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+                        report['items'].append(suffix)
+                        report['items'].append("Class Of Service (COS)")
+                        report['items'].append("cosAttribute: " + attr)
+                        yield report
+                    except:
+                        # this is what we hope for
+                        pass
+
+    def _lint_search(self):
+        """Perform a search and make sure an entry is accessible
+        """
+        dn = self.get_attr_val_utf8('nsslapd-suffix')
+        suffix = DSLdapObject(self._instance, dn=dn)
+        try:
+            suffix.get_attr_val('objectclass')
+        except ldap.NO_SUCH_OBJECT:
+            # backend root entry not created yet
+            DSBLE0003['items'] = [dn, ]
+            yield DSBLE0003
+        except ldap.LDAPError as e:
+            # Some other error
+            DSBLE0002['detail'] = DSBLE0002['detail'].replace('ERROR', str(e))
+            DSBLE0002['items'] = [dn, ]
+            yield DSBLE0002
+
+    def _lint_mappingtree(self):
+        """Backend lint
+
+        This should check for:
+        * missing mapping tree entries for the backend
+        * missing indices if we are local and have log access?
+        """
+
+        # Check for the missing mapping tree.
+        suffix = self.get_attr_val_utf8('nsslapd-suffix')
+        bename = self.get_attr_val_bytes('cn')
+        try:
+            mt = self._mts.get(suffix)
+            if mt.get_attr_val_bytes('nsslapd-backend') != bename and mt.get_attr_val('nsslapd-state') != ensure_bytes('backend'):
+                raise ldap.NO_SUCH_OBJECT("We have a matching suffix, but not a backend or correct database name.")
+        except ldap.NO_SUCH_OBJECT:
+            result = DSBLE0001
+            result['items'] = [bename, ]
+            yield result
+        return None
+
     def create_sample_entries(self, version):
         """Creates sample entries under nsslapd-suffix value
 
@@ -420,12 +506,14 @@ class Backend(DSLdapObject):
         :type version: str
         """
 
-        self._log.debug('Creating sample entries at version %s....' % version)
-        # Grab the correct sample entry config
+        self._log.debug('Requested sample entries at version %s....' % version)
+        # Grab the correct sample entry config - remember this is a function ptr.
         centries = get_sample_entries(version)
         # apply it.
         basedn = self.get_attr_val('nsslapd-suffix')
         cent = centries(self._instance, basedn)
+        # Now it's built, we can get the version for logging.
+        self._log.debug('Creating sample entries at version %s' % cent.version)
         cent.apply()
 
     def _validate(self, rdn, properties, basedn):
@@ -530,44 +618,24 @@ class Backend(DSLdapObject):
             mt = self._mts.get(selector=bename)
             # Assert the type is "backend"
             # Are these the right types....?
-            if mt.get_attr_val('nsslapd-state').lower() != ensure_bytes('backend'):
+            if mt.get_attr_val_utf8('nsslapd-state').lower() != 'backend':
                 raise ldap.UNWILLING_TO_PERFORM('Can not delete the mapping tree, not for a backend! You may need to delete this backend via cn=config .... ;_; ')
+
+            # Delete replicas first
+            try:
+                Replicas(self._instance).get(mt.get_attr_val_utf8('cn')).delete()
+            except ldap.NO_SUCH_OBJECT:
+                # No replica, no problem
+                pass
+
             # Delete our mapping tree if it exists.
             mt.delete()
         except ldap.NO_SUCH_OBJECT:
             # Righto, it's already gone! Do nothing ...
             pass
-        # Delete all our related indices
-        self._instance.index.delete_all(bename)
 
         # Now remove our children, this is all ldbm config
-
-        configs = self._instance.search_s(self._dn, ldap.SCOPE_ONELEVEL)
-        for c in configs:
-            self._instance.delete_branch_s(c.dn, ldap.SCOPE_SUBTREE)
-        # The super will actually delete ourselves.
-        super(Backend, self).delete()
-
-    def _lint_mappingtree(self):
-        """Backend lint
-
-        This should check for:
-        * missing mapping tree entries for the backend
-        * missing indices if we are local and have log access?
-        """
-
-        # Check for the missing mapping tree.
-        suffix = self.get_attr_val_utf8('nsslapd-suffix')
-        bename = self.get_attr_val_bytes('cn')
-        try:
-            mt = self._mts.get(suffix)
-            if mt.get_attr_val_bytes('nsslapd-backend') != bename and mt.get_attr_val('nsslapd-state') != ensure_bytes('backend'):
-                raise ldap.NO_SUCH_OBJECT("We have a matching suffix, but not a backend or correct database name.")
-        except ldap.NO_SUCH_OBJECT:
-            result = DSBLE0001
-            result['items'] = [bename, ]
-            return result
-        return None
+        self._instance.delete_branch_s(self._dn, ldap.SCOPE_SUBTREE)
 
     def get_suffix(self):
         return self.get_attr_val_utf8_l('nsslapd-suffix')
@@ -749,6 +817,18 @@ class Backend(DSLdapObject):
                         break
         return subsuffixes
 
+    def get_cos_indirect_defs(self):
+        return CosIndirectDefinitions(self._instance, self._dn).list()
+
+    def get_cos_pointer_defs(self):
+        return CosPointerDefinitions(self._instance, self._dn).list()
+
+    def get_cos_classic_defs(self):
+        return CosClassicDefinitions(self._instance, self._dn).list()
+
+    def get_cos_templates(self):
+        return CosTemplates(self._instance, self._dn).list()
+
 
 class Backends(DSLdapObjects):
     """DSLdapObjects that represents DN_LDBM base DN
@@ -853,9 +933,12 @@ class Backends(DSLdapObjects):
 
 
 class DatabaseConfig(DSLdapObject):
-    """Chaining Default Config settings DSLdapObject with:
-    - must attributes = ['cn']
-    - RDN attribute is 'cn'
+    """Backend Database configuration
+
+    The entire database configuration consists of the  main global configuration entry,
+    and the underlying DB library configuration: whither BDB or LMDB.  The combined
+    configuration should be presented as a single entity so the end user does not need
+    to worry about what library is being used, and just focus on the configuration.
 
     :param instance: An instance
     :type instance: lib389.DirSrv
@@ -863,13 +946,97 @@ class DatabaseConfig(DSLdapObject):
     :type dn: str
     """
 
-    _must_attributes = ['cn']
-
-    def __init__(self, instance, dn=None):
+    def __init__(self, instance, dn="cn=config,cn=ldbm database,cn=plugins,cn=config"):
         super(DatabaseConfig, self).__init__(instance, dn)
         self._rdn_attribute = 'cn'
         self._must_attributes = ['cn']
+        self._global_attrs = [
+            'nsslapd-lookthroughlimit',
+            'nsslapd-mode',
+            'nsslapd-idlistscanlimit',
+            'nsslapd-directory',
+            'nsslapd-import-cachesize',
+            'nsslapd-idl-switch',
+            'nsslapd-search-bypass-filter-test',
+            'nsslapd-search-use-vlv-index',
+            'nsslapd-exclude-from-export',
+            'nsslapd-serial-lock',
+            'nsslapd-subtree-rename-switch',
+            'nsslapd-pagedlookthroughlimit',
+            'nsslapd-pagedidlistscanlimit',
+            'nsslapd-rangelookthroughlimit',
+            'nsslapd-backend-opt-level',
+            'nsslapd-backend-implement',
+        ]
+        self._db_attrs = {
+            'bdb':
+                [
+                    'nsslapd-dbcachesize',
+                    'nsslapd-db-logdirectory',
+                    'nsslapd-db-home-directory',
+                    'nsslapd-db-durable-transaction',
+                    'nsslapd-db-transaction-wait',
+                    'nsslapd-db-checkpoint-interval',
+                    'nsslapd-db-compactdb-interval',
+                    'nsslapd-db-page-size',
+                    'nsslapd-db-transaction-batch-val',
+                    'nsslapd-db-transaction-batch-min-wait',
+                    'nsslapd-db-transaction-batch-max-wait',
+                    'nsslapd-db-logbuf-size',
+                    'nsslapd-db-locks',
+                    'nsslapd-db-private-import-mem',
+                    'nsslapd-import-cache-autosize',
+                    'nsslapd-cache-autosize',
+                    'nsslapd-cache-autosize-split',
+                    'nsslapd-import-cachesize',
+                    'nsslapd-search-bypass-filter-test',
+                    'nsslapd-serial-lock',
+                    'nsslapd-db-deadlock-policy',
+                ],
+            'lmdb': []
+        }
         self._create_objectclasses = ['top', 'extensibleObject']
         self._protected = True
+        # This could be "bdb" or "lmdb", use what we have configured in the global config
+        self._db_lib = self.get_attr_val_utf8_l('nsslapd-backend-implement')
         self._dn = "cn=config,cn=ldbm database,cn=plugins,cn=config"
+        self._db_dn = f"cn={self._db_lib},cn=config,cn=ldbm database,cn=plugins,cn=config"
+        self._globalObj = DSLdapObject(self._instance, dn=self._dn)
+        self._dbObj = DSLdapObject(self._instance, dn=self._db_dn)
+        # Assert there is no overlap in different config sets
+        assert_c(len(set(self._global_attrs).intersection(set(self._db_attrs['bdb']), set(self._db_attrs['lmdb']))) == 0)
 
+    def get(self):
+        """Get the combined config entries"""
+        # Get and combine both sets of attributes
+        global_attrs = self._globalObj.get_attrs_vals_utf8(self._global_attrs)
+        db_attrs = self._dbObj.get_attrs_vals_utf8(self._db_attrs[self._db_lib])
+        combined_attrs = {**global_attrs, **db_attrs}
+        return combined_attrs
+
+    def display(self):
+        """Display the combined configuration"""
+        global_attrs = self._globalObj.get_attrs_vals_utf8(self._global_attrs)
+        db_attrs = self._dbObj.get_attrs_vals_utf8(self._db_attrs[self._db_lib])
+        combined_attrs = {**global_attrs, **db_attrs}
+        for (k, vo) in combined_attrs.items():
+            if len(vo) == 0:
+                vo = ""
+            else:
+                vo = vo[0]
+            self._instance.log.info(f'{k}: {vo}')
+
+    def set(self, value_pairs):
+        for attr, val in value_pairs:
+            attr = attr.lower()
+            if attr in self._global_attrs:
+                global_config = DSLdapObject(self._instance, dn=self._dn)
+                global_config.replace(attr, val)
+            elif attr in self._db_attrs['bdb']:
+                db_config = DSLdapObject(self._instance, dn=self._db_dn)
+                db_config.replace(attr, val)
+            elif attr in self._db_attrs['lmdb']:
+                pass
+            else:
+                # Unknown attribute
+                raise ValueError("Can not update database configuration with unknown attribute: " + attr)
