@@ -7,15 +7,17 @@
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 
+import ast
 import logging
 import sys
 import json
 import ldap
+from ldap.dn import is_dn
 
 from getpass import getpass
 from lib389 import DirSrv
 from lib389.utils import assert_c, get_ldapurl_from_serverid
-from lib389.properties import *
+from lib389.properties import SER_ROOT_PW, SER_ROOT_DN
 
 
 def _get_arg(args, msg=None, hidden=False, confirm=False):
@@ -37,6 +39,13 @@ def _get_arg(args, msg=None, hidden=False, confirm=False):
             return input("%s : " % msg)
 
 
+def _get_dn_arg(args, msg=None):
+    dn_arg = _get_arg(args, msg)
+    if not is_dn(dn_arg):
+        raise ValueError(f"{dn_arg} is not a valid DN")
+    return dn_arg
+
+
 def _get_args(args, kws):
     kwargs = {}
     while len(kws) > 0:
@@ -120,14 +129,18 @@ def connect_instance(dsrc_inst, verbose, args):
             # No password or we chose to prompt
             dsargs[SER_ROOT_PW] = getpass("Enter password for {} on {}: ".format(dsrc_inst['binddn'], dsrc_inst['uri']))
     elif not ds.can_autobind():
-        # No LDAPI, prompt for password
+        # No LDAPI, prompt for password, and bind DN if necessary
+        if dsrc_inst['binddn'] is None:
+            dn = ""
+            while dn == "":
+                dn = input("Enter Bind DN: ")
+            dsrc_inst['binddn'] = dn
         dsargs[SER_ROOT_PW] = getpass("Enter password for {} on {}: ".format(dsrc_inst['binddn'], dsrc_inst['uri']))
 
-    if 'binddn' in dsrc_inst:
-        # Allocate is an awful interface that we should stop using, but for now
-        # just directly map the dsrc_inst args in (remember, dsrc_inst DOES
-        # overlay cli args into the map ...)
-        dsargs[SER_ROOT_DN] = dsrc_inst['binddn']
+    # Allocate is an awful interface that we should stop using, but for now
+    # just directly map the dsrc_inst args in (remember, dsrc_inst DOES
+    # overlay cli args into the map ...)
+    dsargs[SER_ROOT_DN] = dsrc_inst['binddn']
 
     ds = DirSrv(verbose=verbose)
     ds.allocate(dsargs)
@@ -137,6 +150,8 @@ def connect_instance(dsrc_inst, verbose, args):
             usercert=dsrc_inst['tls_cert'],
             userkey=dsrc_inst['tls_key'],
             starttls=dsrc_inst['starttls'], connOnly=True)
+    if ds.serverid is not None and ds.serverid.startswith("slapd-"):
+        ds.serverid = ds.serverid.replace("slapd-", "", 1)
     return ds
 
 
@@ -150,12 +165,24 @@ def populate_attr_arguments(parser, attributes):
         parser.add_argument('--%s' % attr, nargs='?', help="Value of %s" % attr)
 
 
+def _format_status(log, mtype, json=False):
+    if json:
+        print(mtype.get_status_json())
+    else:
+        status_dict = mtype.get_status()
+        log.info('dn: ' + mtype._dn)
+        for k, v in list(status_dict.items()):
+            # For each value in the multivalue attr
+            for vi in v:
+                log.info('{}: {}'.format(k, vi))
+
+
 def _generic_list(inst, basedn, log, manager_class, args=None):
     mc = manager_class(inst, basedn)
     ol = mc.list()
     if len(ol) == 0:
         if args and args.json:
-            print(json.dumps({"type": "list", "items": []}))
+            print(json.dumps({"type": "list", "items": []}, indent=4))
         else:
             log.info("No objects to display")
     elif len(ol) > 0:
@@ -169,7 +196,7 @@ def _generic_list(inst, basedn, log, manager_class, args=None):
             else:
                 print(o_str)
         if args and args.json:
-            print(json.dumps(json_result))
+            print(json.dumps(json_result, indent=4))
 
 
 # Display these entries better!
@@ -201,7 +228,7 @@ def _generic_get_attr(inst, basedn, log, manager_class, args=None):
         else:
             print(mc.display_attr(attr).rstrip())
     if args.json:
-        print(json.dumps({"type": "entry", "dn": mc._dn, "attrs": vals}))
+        print(json.dumps({"type": "entry", "dn": mc._dn, "attrs": vals}, indent=4))
 
 
 def _generic_get_dn(inst, basedn, log, manager_class, dn, args=None):
@@ -398,3 +425,24 @@ def setup_script_logger(name, verbose=False):
     root.addHandler(log_handler)
 
     return log
+
+
+def format_error_to_dict(exception):
+    """python-ldap str(exception) processing is not consistent.
+    This function makes sure that the result is dict
+
+    :param exception: Exception you need to print
+    :type exception: ldap.LDAPError
+    :returns: dict
+    """
+
+    # The issue was raise on python-ldap repo: https://github.com/python-ldap/python-ldap/issues/304
+    # We should fix the code here after the issue is fixed
+    errmsg = str(exception)
+    try:
+        # The function literal_eval parses the string and returns only if it's a literal.
+        # Also, the code is never executed. So there is no reason for a security risk.
+        msg = ast.literal_eval(errmsg)
+    except Exception:
+        msg = {'desc': errmsg}
+    return msg
