@@ -11,6 +11,7 @@ import json
 import os
 from lib389.config import Config, Encryption, RSA
 from lib389.nss_ssl import NssSsl
+from lib389.cli_base import _warn
 
 
 Props = namedtuple('Props', ['cls', 'attr', 'help', 'values'])
@@ -30,6 +31,9 @@ SECURITY_ATTRS_MAP = OrderedDict([
     ('tls-client-auth', Props(Encryption, 'nsSSLClientAuth',
                               'Client authentication requirement',
                               ('off', 'allowed', 'required'))),
+    ('tls-client-renegotiation', Props(Encryption, 'nsTLSAllowClientRenegotiation',
+                                       'Allow client TLS renegotiation',
+                                       onoff)),
     ('require-secure-authentication', Props(Config, 'nsslapd-require-secure-binds',
                                             'Require binds over LDAPS, StartTLS, or SASL',
                                             onoff)),
@@ -80,7 +84,7 @@ def _security_generic_get(inst, basedn, logs, args, attrs_map):
             val = ""
         result[props.attr.lower()] = val
     if args.json:
-        print(json.dumps({'type': 'list', 'items': result}))
+        print(json.dumps({'type': 'list', 'items': result}, indent=4))
     else:
         print('\n'.join([f'{attr}: {value or ""}' for attr, value in result.items()]))
 
@@ -91,7 +95,10 @@ def _security_generic_set(inst, basedn, logs, args, attrs_map):
         if arg is None:
             continue
         dsobj = props.cls(inst)
-        dsobj.replace(props.attr, arg)
+        if arg != "":
+            dsobj.replace(props.attr, arg)
+        else:
+            dsobj.remove_all(props.attr)
 
 
 def _security_generic_get_parser(parent, attrs_map, help):
@@ -189,7 +196,7 @@ def security_ciphers_list(inst, basedn, log, args):
         lst = enc.ciphers
 
     if args.json:
-        print(json.dumps({'type': 'list', 'items': lst}))
+        print(json.dumps({'type': 'list', 'items': lst}, indent=4))
     else:
         if lst == []:
             log.getChild('security').warn('List of ciphers is empty')
@@ -197,6 +204,14 @@ def security_ciphers_list(inst, basedn, log, args):
             print(*lst, sep='\n')
 
 
+def security_disable_plaintext_port(inst, basedn, log, args, warn=True):
+    if warn and args.json is False:
+        _warn(True, msg="Disabling plaintext ldap port - you must have ldaps configured")
+    inst.config.disable_plaintext_port()
+    log.info("Plaintext port disabled - please restart your instance to take effect")
+    log.info("To undo this change run the subcommand - 'dsconf <instance> config replace nsslapd-port=<port number>'")
+
+
 def cert_add(inst, basedn, log, args):
     """Add server certificate
     """
@@ -268,7 +283,7 @@ def cert_list(inst, basedn, log, args):
             log.info('Expires: {}'.format(cert[3]))
             log.info('Trust Flags: {}\n'.format(cert[4]))
     if args.json:
-        log.info(json.dumps(cert_list))
+        log.info(json.dumps(cert_list, indent=4))
 
 
 def cacert_list(inst, basedn, log, args):
@@ -298,7 +313,7 @@ def cacert_list(inst, basedn, log, args):
             log.info('Expires: {}'.format(cert[3]))
             log.info('Trust Flags: {}\n'.format(cert[4]))
     if args.json:
-        log.info(json.dumps(cert_list))
+        log.info(json.dumps(cert_list, indent=4))
 
 
 def cert_get(inst, basedn, log, args):
@@ -317,7 +332,7 @@ def cert_get(inst, basedn, log, args):
                                 'expires': details[3],
                                 'flags': details[4],
                             }
-                }
+                }, indent=4
             )
         )
     else:
@@ -361,6 +376,10 @@ def create_parser(subparsers):
         'Turn off security functionality. The rest of the configuration will be left untouched.'))
     security_disable_p.set_defaults(func=security_disable)
 
+    security_disable_plain_parser = security_sub.add_parser('disable_plain_port',
+        help="Disables the plain text LDAP port, allowing only LDAPS to function")
+    security_disable_plain_parser.set_defaults(func=security_disable_plaintext_port)
+
     # Server certificate management
     certs = security_sub.add_parser('certificate', help='Manage TLS certificates')
     certs_sub = certs.add_subparsers(help='certificate')
