@@ -8,7 +8,7 @@
 
 import argparse
 from lib389.idm.user import nsUserAccount, nsUserAccounts
-from lib389.cli_base import populate_attr_arguments
+from lib389.cli_base import populate_attr_arguments, _generic_modify
 from lib389.cli_idm import (
     _generic_list,
     _generic_get,
@@ -48,6 +48,10 @@ def delete(inst, basedn, log, args, warn=True):
         _warn(dn, msg="Deleting %s %s" % (SINGULAR.__name__, dn))
     _generic_delete(inst, basedn, log.getChild('_generic_delete'), SINGULAR, dn, args)
 
+def modify(inst, basedn, log, args, warn=True):
+    rdn = _get_arg( args.selector, msg="Enter %s to retrieve" % RDN)
+    _generic_modify(inst, basedn, log.getChild('_generic_modify'), MANY, rdn, args)
+
 def status(inst, basedn, log, args):
     uid = _get_arg( args.uid, msg="Enter %s to check" % RDN)
     uas = MANY(inst, basedn)
@@ -90,6 +94,11 @@ def create_parser(subparsers):
     create_parser.set_defaults(func=create)
     populate_attr_arguments(create_parser, SINGULAR._must_attributes)
 
+    modify_parser = subcommands.add_parser('modify', help='modify <add|delete|replace>:<attribute>:<value> ...')
+    modify_parser.set_defaults(func=modify)
+    modify_parser.add_argument('selector', nargs=1, help='The %s to modify' % RDN)
+    modify_parser.add_argument('changes', nargs='+', help="A list of changes to apply in format: <add|delete|replace>:<attribute>:<value>")
+
     delete_parser = subcommands.add_parser('delete', help='deletes the object')
     delete_parser.set_defaults(func=delete)
     delete_parser.add_argument('dn', nargs='?', help='The dn to delete')
