@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2019 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -16,6 +16,7 @@
    DirSrv.backend.methodName()
 """
 
+import copy
 import ldap
 from lib389._constants import *
 from lib389 import Entry
@@ -64,7 +65,7 @@ class Config(DSLdapObject):
         return DN_CONFIG
 
     def replace(self, key, value):
-        if key.lower() == 'nsslapd-secureport' and selinux_present():
+        if selinux_present() and (key.lower() == 'nsslapd-secureport' or key.lower() == 'nsslapd-port'):
             # Get old port and remove label
             old_port = self.get_attr_val_utf8(key)
             self.log.debug("Removing old port's selinux label...")
@@ -199,16 +200,30 @@ class Config(DSLdapObject):
     def _lint_hr_timestamp(self):
         hr_timestamp = self.get_attr_val('nsslapd-logging-hr-timestamps-enabled')
         if ensure_bytes('on') != hr_timestamp:
-            return DSCLE0001
-        pass # nsslapd-logging-hr-timestamps-enabled
+            report = copy.deepcopy(DSCLE0001)
+            report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+            yield report
 
     def _lint_passwordscheme(self):
         allowed_schemes = ['SSHA512', 'PBKDF2_SHA256']
         u_password_scheme = self.get_attr_val_utf8('passwordStorageScheme')
         u_root_scheme = self.get_attr_val_utf8('nsslapd-rootpwstoragescheme')
         if u_root_scheme not in allowed_schemes or u_password_scheme not in allowed_schemes:
-            return DSCLE0002
-        return None
+            report = copy.deepcopy(DSCLE0002)
+            report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+            yield report
+
+    def disable_plaintext_port(self):
+        """
+        Configure the server to not-provide the plaintext port.
+        """
+        self.set('nsslapd-port', '0')
+
+    def enable_plaintext_port(self, port):
+        """
+        Configure the server to provide the plaintext port on the specified port number.
+        """
+        self.set('nsslapd-port', port)
 
 
 class Encryption(DSLdapObject):
@@ -236,9 +251,11 @@ class Encryption(DSLdapObject):
 
     def _lint_check_tls_version(self):
         tls_min = self.get_attr_val('sslVersionMin')
-        if tls_min < ensure_bytes('TLS1.1'):
-            return DSELE0001
-        return None
+        if tls_min is not None and tls_min < ensure_bytes('TLS1.1'):
+            report = copy.deepcopy(DSELE0001)
+            report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+            yield report
+        yield None
 
     @property
     def ciphers(self):
@@ -472,3 +489,22 @@ class LDBMConfig(DSLdapObject):
         self._rdn_attribute = 'cn'
         self._lint_functions = []
         self._protected = True
+
+
+class BDB_LDBMConfig(DSLdapObject):
+    """
+        Manage "cn=bdb,cn=config,cn=ldbm database,cn=plugins,cn=config" including:
+        - Performance related tunings
+        - BDB specific DB backend settings
+
+        :param instance: An instance
+        :type instance: lib389.DirSrv
+    """
+
+    def __init__(self, conn):
+        super(BDB_LDBMConfig, self).__init__(instance=conn)
+        self._dn = DN_CONFIG_LDBM_BDB
+        self._config_compare_exclude = []
+        self._rdn_attribute = 'cn'
+        self._lint_functions = []
+        self._protected = True
