@@ -32,6 +32,7 @@ format_keys = [
     'inst_dir',
     'backup_dir',
     'db_dir',
+    'db_home_dir',
     'ldif_dir',
     'lock_dir',
     'log_dir',
@@ -114,7 +115,7 @@ class General2Base(Options2):
         self._type['full_machine_name'] = str
         self._helptext['full_machine_name'] = "Sets the fully qualified hostname (FQDN) of this system. When installing this instance with GSSAPI authentication behind a load balancer, set this parameter to the FQDN of the load balancer and, additionally, set \"strict_host_checking\" to \"false\"."
 
-        self._options['strict_host_checking'] = True
+        self._options['strict_host_checking'] = False
         self._type['strict_host_checking'] = bool
         self._helptext['strict_host_checking'] = "Sets whether the server verifies the forward and reverse record set in the \"full_machine_name\" parameter. When installing this instance with GSSAPI authentication behind a load balancer, set this parameter to \"false\". Container installs imply \"false\"."
 
@@ -166,8 +167,9 @@ class Slapd2Base(Options2):
         self._helptext['root_password'] = ("Sets the password of the account specified in the \"root_dn\" parameter. " +
                                            "You can either set this parameter to a plain text password dscreate hashes " +
                                            "during the installation or to a \"{algorithm}hash\" string generated by the " +
-                                           "pwdhash utility. Note that setting a plain text password can be a security " +
-                                           "risk if unprivileged users can read this INF file!")
+                                           "pwdhash utility. The password must be at least 8 characters long.  Note " +
+                                           "that setting a plain text password can be a security risk if unprivileged " +
+                                           "users can read this INF file!")
 
         self._options['prefix'] = ds_paths.prefix
         self._type['prefix'] = str
@@ -239,6 +241,10 @@ class Slapd2Base(Options2):
         self._type['db_dir'] = str
         self._helptext['db_dir'] = "Sets the database directory of the instance."
 
+        self._options['db_home_dir'] = ds_paths.db_home_dir
+        self._type['db_home_dir'] = str
+        self._helptext['db_home_dir'] = "Sets the memory-mapped database files location of the instance."
+
         self._options['ldif_dir'] = ds_paths.ldif_dir
         self._type['ldif_dir'] = str
         self._helptext['ldif_dir'] = "Sets the LDIF export and import directory of the instance."
