@@ -9,6 +9,7 @@
 """Helpers for managing NSS databases in Directory Server
 """
 
+import copy
 import os
 import re
 import socket
@@ -17,10 +18,10 @@ import shutil
 import logging
 # from nss import nss
 import subprocess
-from datetime import datetime, timedelta
-from subprocess import check_output
+from datetime import datetime, timedelta, date
+from subprocess import check_output, run, PIPE
 from lib389.passwd import password_generate
-
+from lib389.lint import DSCERTLE0001, DSCERTLE0002
 from lib389.utils import ensure_str, format_cmd_list
 import uuid
 
@@ -34,7 +35,7 @@ CERT_SUFFIX = 'O=testing,L=389ds,ST=Queensland,C=AU'
 ISSUER = 'CN=ssca.389ds.example.com,%s' % CERT_SUFFIX
 SELF_ISSUER = 'CN={HOSTNAME},givenName={GIVENNAME},%s' % CERT_SUFFIX
 USER_ISSUER = 'CN={HOSTNAME},%s' % CERT_SUFFIX
-VALID = 24
+VALID = 24 # Months
 VALID_MIN = 61  # Days
 
 # My logger
@@ -58,6 +59,38 @@ class NssSsl(object):
         self.db_files = {"dbm_backend": ["%s/%s" % (self._certdb, f) for f in ("key3.db", "cert8.db", "secmod.db")],
                          "sql_backend": ["%s/%s" % (self._certdb, f) for f in ("key4.db", "cert9.db", "pkcs11.txt")],
                          "support": ["%s/%s" % (self._certdb, f) for f in ("noise.txt", PIN_TXT, PWD_TXT)]}
+        self._lint_functions = [self._lint_certificate_expiration,]
+
+    def lint(self):
+        results = []
+        for fn in self._lint_functions:
+            for result in fn():
+                if result is not None:
+                    results.append(result)
+        return results
+
+    def _lint_certificate_expiration(self):
+        """Check all the certificates in the db if they will expire within 30 days
+        or have already expired.
+        """
+        cert_list = []
+        all_certs = self._rsa_cert_list()
+        for cert in all_certs:
+            cert_list.append(self.get_cert_details(cert[0]))
+
+        for cert in cert_list:
+            cert_date = cert[3].split()[0]
+            diff_date = datetime.strptime(cert_date, '%Y-%m-%d').date() - datetime.today().date()
+            if diff_date < timedelta(days=0):
+                # Expired
+                report = copy.deepcopy(DSCERTLE0002)
+                report['detail'] = report['detail'].replace('CERT', cert[0])
+                yield report
+            elif diff_date < timedelta(days=30):
+                # Expiring within 30 days
+                report = copy.deepcopy(DSCERTLE0001)
+                report['detail'] = report['detail'].replace('CERT', cert[0])
+                yield report
 
     def detect_alt_names(self, alt_names=[]):
         """Attempt to determine appropriate subject alternate names for a host.
@@ -68,9 +101,9 @@ class NssSsl(object):
         :returns: list[str]
         """
         if self.dirsrv and self.dirsrv.host not in alt_names:
-            alt_names.append(self.dirsrv.host)
+            alt_names.append(ensure_str(self.dirsrv.host))
         if len(alt_names) == 0:
-            alt_names.append(socket.gethostname())
+            alt_names.append(ensure_str(socket.gethostname()))
         return alt_names
 
     def generate_cert_subject(self, alt_names=[]):
@@ -120,18 +153,19 @@ class NssSsl(object):
         except FileExistsError:
             pass
 
-        # Write a README to let people know what this is
-        readme_file = '%s/%s' % (self._certdb, 'README.txt')
-        if not os.path.exists(readme_file):
-            with open(readme_file, 'w') as f:
-                f.write("""
+        if self.dirsrv is None:
+            # Write a README to let people know what this is
+            readme_file = '%s/%s' % (self._certdb, 'README.txt')
+            if not os.path.exists(readme_file):
+                with open(readme_file, 'w') as f:
+                    f.write("""
 SSCA - Simple Self-Signed Certificate Authority
 
 This is part of the 389 Directory Server project's lib389 toolkit. It
 creates a simple, standalone certificate authority for testing and
 development purposes. It's suitable for evaluation and testing purposes
 only.
-                """)
+                    """)
 
         # In the future we may add the needed option to avoid writing the pin
         # files.
@@ -208,6 +242,7 @@ only.
             'CT,,',
             '-v',
             '%s' % months,
+            '-2',
             '--keyUsage',
             'certSigning',
             '-d',
@@ -217,8 +252,9 @@ only.
             '-f',
             '%s/%s' % (self._certdb, PWD_TXT),
         ]
+        cmd_input = b'y\n\n'  # responses to certutil questions
         self.log.debug("nss cmd: %s", format_cmd_list(cmd))
-        result = ensure_str(check_output(cmd, stderr=subprocess.STDOUT))
+        result = ensure_str(run(cmd, check=True, stderr=PIPE, stdout=PIPE, input=cmd_input).stdout)
         self.log.debug("nss output: %s", result)
         # Now extract the CAcert to a well know place.
         # This allows us to point the cacert dir here and it "just works"
@@ -361,6 +397,9 @@ only.
         for line in lines:
             if line == '':
                 continue
+            if line == 'Database needs user init':
+                # There are no certs, abort...
+                return []
             cert_values.append(re.match(r'^(.+[^\s])[\s]+([^\s]+)$', line.rstrip()).groups())
         return cert_values
 
@@ -389,6 +428,11 @@ only.
         (ssl_flag, mime_flag, jar_flag) = trust_flags.split(',')
         return 'C' in ssl_flag
 
+    def _rsa_cert_is_caclienttrust(self, cert_tuple):
+        trust_flags = cert_tuple[1]
+        (ssl_flag, mime_flag, jar_flag) = trust_flags.split(',')
+        return 'T' in ssl_flag
+
     def _rsa_cert_is_user(self, cert_tuple):
         """
         Check an RSA cert is user trust
@@ -480,15 +524,20 @@ only.
         self.log.debug("nss output: %s", result)
         return True
 
-    def create_rsa_key_and_csr(self, alt_names=[]):
+    def create_rsa_key_and_csr(self, alt_names=[], subject=None):
         """Create a new RSA key and the certificate signing request. This
         request can be submitted to a CA for signing. The returned certifcate
         can be added with import_rsa_crt.
         """
         csr_path = os.path.join(self._certdb, '%s.csr' % CERT_NAME)
 
-        alt_names = self.detect_alt_names(alt_names)
-        subject = self.generate_cert_subject(alt_names)
+        if len(alt_names) == 0:
+            alt_names = self.detect_alt_names(alt_names)
+        if subject is None:
+            subject = self.generate_cert_subject(alt_names)
+
+        self.log.debug(f"CSR subject -> {subject}")
+        self.log.debug(f"CSR alt_names -> {alt_names}")
 
         # Wait a second to avoid an NSS bug with serial ids based on time.
         time.sleep(1)
@@ -755,6 +804,19 @@ only.
         check_output(cmd, stderr=subprocess.STDOUT)
 
 
+    def display_cert_details(self, nickname):
+        cmd = [
+            '/usr/bin/certutil',
+            '-d', self._certdb,
+            '-n', nickname,
+            '-L',
+            '-f',
+            '%s/%s' % (self._certdb, PWD_TXT),
+        ]
+        self.log.debug("display_cert_details cmd: %s", format_cmd_list(cmd))
+        return check_output(cmd, stderr=subprocess.STDOUT, encoding='utf-8')
+
+
     def get_cert_details(self, nickname):
         """Get the trust flags, subject DN, issuer, and expiration date
 
@@ -769,18 +831,7 @@ only.
         for cert in all_certs:
             if cert[0] == nickname:
                 trust_flags = cert[1]
-                cmd = [
-                    '/usr/bin/certutil',
-                    '-d', self._certdb,
-                    '-n', nickname,
-                    '-L',
-                    '-f',
-                    '%s/%s' % (self._certdb, PWD_TXT),
-                ]
-                self.log.debug("get_cert_details cmd: %s", format_cmd_list(cmd))
-
-                # Expiration date
-                certdetails = check_output(cmd, stderr=subprocess.STDOUT, encoding='utf-8')
+                certdetails = self.display_cert_details(nickname)
                 end_date_str = certdetails.split("Not After : ")[1].split("\n")[0]
                 date_format = '%a %b %d %H:%M:%S %Y'
                 end_date = datetime.strptime(end_date_str, date_format)
@@ -817,7 +868,6 @@ only.
         # Did not find cert with that name
         raise ValueError("Certificate '{}' not found in NSS database".format(nickname))
 
-
     def list_certs(self, ca=False):
         all_certs = self._rsa_cert_list()
         certs = []
@@ -827,6 +877,20 @@ only.
                 certs.append(self.get_cert_details(cert[0]))
         return certs
 
+    def list_ca_certs(self):
+        return [
+            cert
+            for cert in self._rsa_cert_list()
+            if self._rsa_cert_is_catrust(cert)
+        ]
+
+    def list_client_ca_certs(self):
+        return [
+            cert
+            for cert in self._rsa_cert_list()
+            if self._rsa_cert_is_caclienttrust(cert)
+        ]
+
 
     def add_cert(self, nickname, input_file, ca=False):
         """Add server or CA cert
@@ -854,3 +918,55 @@ only.
         ]
         self.log.debug("add_cert cmd: %s", format_cmd_list(cmd))
         check_output(cmd, stderr=subprocess.STDOUT)
+
+    def add_server_key_and_cert(self, input_key, input_cert):
+        if not os.path.exists(input_key):
+            raise ValueError("The key file ({}) does not exist".format(input_key))
+        if not os.path.exists(input_cert):
+            raise ValueError("The cert file ({}) does not exist".format(input_cert))
+
+        self.log.debug(f"Importing key and cert -> {input_key}, {input_cert}")
+
+        p12_bundle = "%s/temp_server_key_cert.p12" % self._certdb
+
+        # Remove the p12 if it exists
+        if os.path.exists(p12_bundle):
+            os.remove(p12_bundle)
+
+        # Transform to p12
+        cmd = [
+            'openssl',
+            'pkcs12',
+            '-export',
+            '-in', input_cert,
+            '-inkey', input_key,
+            '-out', p12_bundle,
+            '-name', CERT_NAME,
+            '-passout', 'pass:',
+            '-aes128'
+        ]
+        self.log.debug("nss cmd: %s", format_cmd_list(cmd))
+        check_output(cmd, stderr=subprocess.STDOUT)
+        # Remove the server-cert if it exists, because else the import name fails.
+        try:
+            self.del_cert(CERT_NAME)
+        except:
+            pass
+        try:
+            # Import it
+            cmd = [
+                'pk12util',
+                '-v',
+                '-i', p12_bundle,
+                '-d', self._certdb,
+                '-k', '%s/%s' % (self._certdb, PWD_TXT),
+                '-W', "",
+            ]
+            self.log.debug("nss cmd: %s", format_cmd_list(cmd))
+            check_output(cmd, stderr=subprocess.STDOUT)
+        finally:
+            # Remove the p12
+            if os.path.exists(p12_bundle):
+                os.remove(p12_bundle)
+
+
