@@ -22,7 +22,7 @@ from lib389._constants import *
 from lib389._constants import DN_SCHEMA
 from lib389.utils import ds_is_newer
 from lib389._mapped_object import DSLdapObject
-from lib389.tasks import SchemaReloadTask
+from lib389.tasks import SchemaReloadTask, SyntaxValidateTask
 
 # Count should start with 0 because of the python-ldap API
 ObjectclassKind = Enum("Objectclass kind",
@@ -90,9 +90,9 @@ class Schema(DSLdapObject):
 
     @staticmethod
     def _validate_ldap_schema_value(value):
-        """Validate the values that we suppl to ldap.schema.models
+        """Validate the values that we supply to ldap.schema.models
         because it expects some exact values.
-        It should tuple, not list.
+        It should be tuple, not list.
         It should be None or () if we don't want """
 
         if type(value) == list:
@@ -110,7 +110,7 @@ class Schema(DSLdapObject):
         if json:
             attr_syntaxes_list = []
             for id, name in ATTR_SYNTAXES.items():
-                attr_syntaxes_list.append({'name': name, 'id': id})
+                attr_syntaxes_list.append({'label': name, 'id': id})
             result = {'type': 'list', 'items': attr_syntaxes_list}
         else:
             result = ATTR_SYNTAXES
@@ -129,7 +129,7 @@ class Schema(DSLdapObject):
                 obj_i = vars(object_model(obj))
                 if len(obj_i["names"]) == 1:
                     obj_i['name'] = obj_i['names'][0].lower()
-                    obj_i['aliases'] = ""
+                    obj_i['aliases'] = None
                 elif len(obj_i["names"]) > 1:
                     obj_i['name'] = obj_i['names'][0].lower()
                     obj_i['aliases'] = obj_i['names'][1:]
@@ -153,6 +153,12 @@ class Schema(DSLdapObject):
                 object_insts.append(obj_i)
 
             object_insts = sorted(object_insts, key=itemgetter('name'))
+            # Ensure that the string values are in list so we can use React filter component with it
+            for obj_i in object_insts:
+                for key, value in obj_i.items():
+                    if isinstance(value, str):
+                        obj_i[key] = (value, )
+
             return {'type': 'list', 'items': object_insts}
         else:
             object_insts = [object_model(obj_i) for obj_i in results]
@@ -227,7 +233,19 @@ class Schema(DSLdapObject):
                 raise ValueError('Wrong parameter name was specified: %s' % oc_param)
             if value is not None:
                 value = self._validate_ldap_schema_value(value)
-                setattr(schema_object, oc_param.lower(), value)
+                setattr(schema_object, oc_param, value)
+            else:
+                if getattr(schema_object, oc_param, False):
+                    # Need to set the correct "type" for the empty value
+                    if oc_param in ['may', 'must',  'x-origin', 'sup']:
+                        # Expects tuple
+                        setattr(schema_object, oc_param, ())
+                    elif oc_param in ['desc', 'oid']:
+                        # Expects None
+                        setattr(schema_object, oc_param, None)
+                    elif oc_param in ['obsolete', 'kind']:
+                        # Expects numberic
+                        setattr(schema_object, oc_param, 0)
 
         schema_object_str = str(schema_object)
         if schema_object_str == schema_object_str_old:
@@ -485,6 +503,25 @@ class Schema(DSLdapObject):
         else:
             return str(attributetype), may, must
 
+    def validate_syntax(self, basedn, _filter=None):
+        """Create a validate syntax task
+
+        :param basedn: Basedn to validate
+        :type basedn: str
+        :param _filter: a filter for entries to validate
+        :type _filter: str
+
+        :returns: an instance of Task(DSLdapObject)
+        """
+
+        task = SyntaxValidateTask(self._instance)
+        task_properties = {'basedn': basedn}
+        if _filter is not None:
+            task_properties['filter'] = _filter
+        task.create(properties=task_properties)
+
+        return task
+
 
 class SchemaLegacy(object):
 
