@@ -39,8 +39,14 @@ class Task(DSLdapObject):
         self._exit_code = None
         self._task_log = ""
 
+    def status(self):
+        """Return the decoded status of the task
+        """
+        return self.get_attr_val_utf8('nsTaskStatus')
+
     def is_complete(self):
         """Return True if task is complete, else False."""
+
         self._exit_code = self.get_attr_val_utf8("nsTaskExitCode")
         self._task_log = self.get_attr_val_utf8("nsTaskLog")
         if not self.exists():
@@ -133,6 +139,21 @@ class FixupLinkedAttributesTask(Task):
         super(FixupLinkedAttributesTask, self).__init__(instance, dn)
 
 
+class MemberUidFixupTask(Task):
+    """A single instance of memberOf task entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    """
+
+    def __init__(self, instance, dn=None):
+        self.cn = 'memberUid_fixup_' + Task._get_task_date()
+        dn = f"cn={self.cn},cn=memberuid task,cn=tasks,cn=config"
+
+        super(MemberUidFixupTask, self).__init__(instance, dn)
+        self._must_attributes.extend(['basedn'])
+
+
 class MemberOfFixupTask(Task):
     """A single instance of memberOf task entry
 
@@ -182,6 +203,21 @@ class SchemaReloadTask(Task):
         super(SchemaReloadTask, self).__init__(instance, dn)
 
 
+class SyntaxValidateTask(Task):
+    """A single instance of schema reload task entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    """
+
+    def __init__(self, instance, dn=None):
+        self.cn = 'syntax_validate_' + Task._get_task_date()
+        dn = f"cn={self.cn},cn=syntax validate,cn=tasks,cn=config"
+
+        super(SyntaxValidateTask, self).__init__(instance, dn)
+        self._must_attributes.extend(['basedn'])
+
+
 class AbortCleanAllRUVTask(Task):
     """Abort the Clean All Ruv task on all masters. You should
     call this from "CleanAllRUVTask.abort()" instead to provide
@@ -257,11 +293,25 @@ class ImportTask(Task):
 
     def __init__(self, instance, dn=None):
         self.cn = 'import_' + Task._get_task_date()
-        dn = "cn=" + self.cn + ",cn=import," + DN_TASKS
+        dn = "cn=%s,%s" % (self.cn, DN_IMPORT_TASK)
         self._properties = None
 
         super(ImportTask, self).__init__(instance, dn)
 
+    # We can add all the needed and valid option combos here.
+    def import_suffix_from_ldif(self, ldiffile, suffix):
+        # TODO: Check that the arguments we were given are valid combinations.
+        # Write out new ones.
+        _properties = {
+            'nsFilename': ldiffile,
+            'nsIncludeSuffix': suffix,
+            'ttl': TTL_DEFAULT_VAL,
+        }
+        self.create(properties=_properties)
+
+    # The correlating function would be import_backend_from_ldif which
+    # would list a bename not suffix
+
 
 class ExportTask(Task):
     """Create the export to ldif task
@@ -272,11 +322,19 @@ class ExportTask(Task):
 
     def __init__(self, instance, dn=None):
         self.cn = 'export_' + Task._get_task_date()
-        dn = "cn=" + self.cn + ",cn=export," + DN_TASKS
+        dn = "cn=%s,%s" % (self.cn, DN_EXPORT_TASK)
         self._properties = None
 
         super(ExportTask, self).__init__(instance, dn)
 
+    def export_suffix_to_ldif(self, ldiffile, suffix):
+        _properties = {
+            'nsFilename': ldiffile,
+            'nsIncludeSuffix': suffix,
+            'ttl': TTL_DEFAULT_VAL,
+        }
+        self.create(properties=_properties)
+
 
 class BackupTask(Task):
     """Create the backup DB task
