@@ -63,7 +63,6 @@ setup(
             'cli/dsconf',
             'cli/dscreate',
             'cli/dsidm',
-            'cli/dscontainer',
             ]),
         ('/usr/share/man/man8', [
             'man/dsctl.8',
@@ -71,6 +70,9 @@ setup(
             'man/dscreate.8',
             'man/dsidm.8',
             ]),
+        ('/usr/libexec/dirsrv/', [
+            'cli/dscontainer',
+            ]),
     ],
 
     install_requires=[
@@ -82,6 +84,8 @@ setup(
         'argcomplete',
         'argparse-manpage',
         'python-ldap',
+        'setuptools',
+        'distro',
         ],
 
     cmdclass={
